@@ -7,6 +7,10 @@
 #   ifndef	TED_COLUMN_TOOL_H
 #   define	TED_COLUMN_TOOL_H
 
+#   include	"tedBorderTool.h"
+#   include	<docSelectionDescription.h>
+#   include	<docSelectionGeometry.h>
+
 /************************************************************************/
 /*									*/
 /*  Resources for the 'Column' page.					*/
@@ -15,10 +19,10 @@
 
 typedef struct ColumnPageResources
     {
-    char *		cprRow;
     char *		cprColumn;
 
     char *		cprWidth;
+    char *		cprBorders;
     char *		cprLeftBorder;
     char *		cprRightBorder;
 
@@ -41,12 +45,23 @@ typedef struct ColumnTool
 
     int				ctBlockFrameWide;
 
-    RowProperties		ctPropertiesSet;
-    RowProperties		ctPropertiesChosen;
+    CellProperties		ctPropertiesSet;
+    CellProperties		ctPropertiesChosen;
+    int				ctWidthSet;
+    int				ctWidthChosen;
+    int				ctHalfGapWidthTwips;
+    unsigned char		ctCanChange;
 
-    APP_WIDGET			ctNumberText;
+    APP_WIDGET			ctColumnRow;
+    APP_WIDGET			ctColumnLabel;
+    APP_WIDGET			ctColumnText;
+
+    APP_WIDGET			ctWidthRow;
+    APP_WIDGET			ctWidthLabel;
     APP_WIDGET			ctWidthText;
 
+    APP_WIDGET			ctBordersFrame;
+    APP_WIDGET			ctBordersPaned;
     BorderTool			ctLeftBorderTool;
     BorderTool			ctRightBorderTool;
     } ColumnTool;
@@ -72,7 +87,8 @@ extern void tedRefreshColumnTool(
 				InspectorSubject *		is,
 				const DocumentSelection *	ds,
 				const SelectionGeometry *	sg,
-				const SelectionDescription *	sd );
+				const SelectionDescription *	sd,
+				const unsigned char *		cmdEnabled );
 
 extern void tedInitColumnTool(	ColumnTool *	ct );
 extern void tedCleanColumnTool(	ColumnTool *	ct );
@@ -80,4 +96,12 @@ extern void tedCleanColumnTool(	ColumnTool *	ct );
 extern void tedFormatFinishColumnPage(	ColumnTool *			ct,
 					const ColumnPageResources *	cpr );
 
+extern void tedColumnToolFillChoosers( ColumnTool *			ct,
+					const ColumnPageResources *	cpr );
+
+extern void tedFormatToolGetColumnResourceTable(
+					EditApplication *		ea,
+					ColumnPageResources *		cpr,
+					InspectorSubjectResources *	isr );
+
 #   endif	/*  TED_COLUMN_TOOL_H */
