@@ -8,12 +8,12 @@
 
 #   include	<stddef.h>
 #   include	<stdlib.h>
-#   include	<stdio.h>
-#   include	<math.h>
 
-#   include	"tedApp.h"
-#   include	"docScreenLayout.h"
+#   include	<docScreenLayout.h>
 #   include	"tedDraw.h"
+#   include	<geoGrid.h>
+#   include	<docShape.h>
+#   include	<docDrawShapeArrow.h>
 
 #   include	<appDebugon.h>
 
@@ -23,165 +23,120 @@
 /*									*/
 /************************************************************************/
 
-static int tedShapeDrawArrowHead(	AppDrawingData *	add,
-					int			xTo,
-					int			yTo,
-					int			xFrom,
-					int			yFrom,
+static int tedShapeDrawArrowHead(	const LayoutContext *	lc,
 					int			widthPixels,
-					const ShapeArrow *	sa )
+					const DrawShapeArrow *	dsa )
     {
-    double		xfac= add->addMagnifiedPixelsPerTwip;
-    AffineTransform2D	at;
-    AffineTransform2D	att;
-    APP_POINT		points[5];
-
-    int			length;
-    int			length2;
-    int			width;
-
-    docShapeArrowSizesTwips( &length, &length2, &width, sa );
-
-    length= X_PIXELS( add, length );
-    length2= X_PIXELS( add, length2 );
-    width= COORDtoGRID( xfac, width );
-
-    geoRotationAffineTransform2DAtan( &at, yTo- yFrom, xTo- xFrom );
-    geoTranslationAffineTransform2D( &att, xTo, yTo );
-    geoAffineTransform2DProduct( &at, &att, &at );
-
-    points[0].x= xTo;
-    points[0].y= yTo;
+    const ShapeArrow *	sa= &(dsa->dsaArrow);
+    DrawingSurface	ds= lc->lcDrawingSurface;
+    Point2DI		points[7];
+    Arc2DI		arc;
 
     switch( sa->saArrowHead )
 	{
+	int	i;
+
 	case DSarrowNONE:
-	    return 0;
+	    break;
+
 	case DSarrowARROW:
-	    points[1].x= AT2_X( -length,  width, &at );
-	    points[1].y= AT2_Y( -length,  width, &at );
-	    points[2].x= AT2_X( -length, -width, &at );
-	    points[2].y= AT2_Y( -length, -width, &at );
-	    points[3]= points[0];
-	    appDrawFillPolygon( add, points, 3 );
-	    break;
-
 	case DSarrowSTEALTH_ARROW:
-	    points[1].x= AT2_X( -length2,  width, &at );
-	    points[1].y= AT2_Y( -length2,  width, &at );
-	    points[2].x= AT2_X( -length,  0, &at );
-	    points[2].y= AT2_Y( -length,  0, &at );
-	    points[3].x= AT2_X( -length2, -width, &at );
-	    points[3].y= AT2_Y( -length2, -width, &at );
-	    points[4]= points[0];
-	    appDrawFillPolygon( add, points, 4 );
-	    break;
-
 	case DSarrowDIAMOND:
-	    points[1].x= AT2_X( -length/ 2,  width, &at );
-	    points[1].y= AT2_Y( -length/ 2,  width, &at );
-	    points[2].x= AT2_X( -length,  0, &at );
-	    points[2].y= AT2_Y( -length,  0, &at );
-	    points[3].x= AT2_X( -length/ 2, -width, &at );
-	    points[3].y= AT2_Y( -length/ 2, -width, &at );
-	    points[4]= points[0];
-	    appDrawFillPolygon( add, points, 4 );
+	    for ( i= 0; i <= dsa->dsaPathLength; i++ )
+		{
+		points[i].x= dsa->dsaPath[i].x;
+		points[i].y= dsa->dsaPath[i].y;
+		}
+	    drawFillPolygon( ds, points, dsa->dsaPathLength );
 	    break;
 
 	case DSarrowOPEN_ARROW:
-	    points[0].x= AT2_X( -length,  width, &at );
-	    points[0].y= AT2_Y( -length,  width, &at );
-	    points[1].x= AT2_X( 0, 0, &at );
-	    points[1].y= AT2_Y( 0, 0, &at );
-	    points[2].x= AT2_X( -length, -width, &at );
-	    points[2].y= AT2_Y( -length, -width, &at );
+	    for ( i= 0; i <= dsa->dsaPathLength; i++ )
+		{
+		points[i].x= dsa->dsaPath[i].x;
+		points[i].y= dsa->dsaPath[i].y;
+		}
 
-	    appDrawSetLineAttributes( add,
-		    widthPixels, LINEstyleSOLID, LINEcapBUTT, LINEjoinMITER,
+	    drawSetLineAttributes( ds,
+		    widthPixels, LineStyleSolid, LineCapButt, LineJoinMiter,
 		    (unsigned char *)0, 0 );
 
-	    appDrawDrawLines( add, points, 3, 0 );
+	    drawLines( ds, points, dsa->dsaPathLength, 0 );
 	    break;
 
 	case DSarrowOVAL:
-	    points[0].x= AT2_X( -length/ 2,  width, &at );
-	    points[0].y= AT2_Y( -length/ 2,  width, &at );
-	    points[1].x= AT2_X(  length/ 2, -width, &at );
-	    points[1].y= AT2_Y(  length/ 2, -width, &at );
-	    if  ( points[0].x > points[1].x )
-		{
-		int x= points[0].x;
-		       points[0].x= points[1].x;
-		                    points[1].x= x;
-		}
-	    if  ( points[0].y > points[1].y )
-		{
-		int y= points[0].y;
-		       points[0].y= points[1].y;
-		                    points[1].y= y;
-		}
-	    appDrawFillArc( add, points[0].x, points[0].y,
-					    points[1].x- points[0].x+ 1,
-					    points[1].y- points[0].y+ 1,
-					    64* 0, 64* 360 );
+	    arc.a2diRect.drX0= dsa->dsaArrowRectangle.x0;
+	    arc.a2diRect.drY0= dsa->dsaArrowRectangle.y0;
+	    arc.a2diRect.drX1= dsa->dsaArrowRectangle.x1;
+	    arc.a2diRect.drY1= dsa->dsaArrowRectangle.y1;
+
+	    geoNormalizeRectangle( &(arc.a2diRect), &(arc.a2diRect) );
+	    arc.a2diAngleFrom= 64* 0;
+	    arc.a2diAngleStep= 64* 360;
+
+	    drawFillArc( ds, &arc );
 	    break;
 
 	case DSarrowCHEVRON_ARROW:
 	case DSarrow2CHEVRON_ARROW:
 	default:
-	    LDEB(sa->saArrowHead); return 0;
+	    LDEB(sa->saArrowHead); break;
 	}
 
     return 0;
     }
 
-static APP_POINT * tedDrawGetVertices(
+static Point2DI * tedDrawGetVertices(
 				const DocumentRectangle *	drTwips,
 				const DrawingShape *		ds,
 				const LayoutContext *		lc,
 				ScreenDrawingData *		sdd )
     {
-    double		xfac= lc->lcAdd->addMagnifiedPixelsPerTwip;
-    int			x0Ref= drTwips->drX0;
-    int			y0Ref= drTwips->drY0;
+    const ShapeDrawing *	sd= &(ds->dsDrawing);
+    double			xfac= lc->lcPixelsPerTwip;
+    int				x0Ref= drTwips->drX0;
+    int				y0Ref= drTwips->drY0;
 
-    int			i;
-    const ShapeVertex *	sv;
+    int				i;
+    const Point2DI *		sv;
 
-    APP_POINT *		xp;
-    APP_POINT *		xpret;
+    Point2DI *			xp;
+    Point2DI *			xpret;
 
-    xp= xpret= malloc( ( ds->dsVertexCount+ 1)* sizeof(APP_POINT) );
+    xp= xpret= malloc( ( sd->sdVertexCount+ 1)* sizeof(Point2DI) );
     if  ( ! xp )
-	{ LXDEB(ds->dsVertexCount,xp); return (APP_POINT *)0;	}
+	{ LXDEB(sd->sdVertexCount,xp); return (Point2DI *)0;	}
 
-    sv= ds->dsVertices;
-    for ( i= 0; i < ds->dsVertexCount; xp++, sv++, i++ )
+    sv= sd->sdVertices;
+    for ( i= 0; i < sd->sdVertexCount; xp++, sv++, i++ )
 	{
-	xp->x= X_PIXELS( lc->lcAdd, x0Ref+ sv->svX )- lc->lcOx;
-	xp->y= COORDtoGRID( xfac, y0Ref+ sv->svY )- lc->lcOy;
+	xp->x= docLayoutXPixels( lc, x0Ref+ sv->x )- lc->lcOx;
+	xp->y= COORDtoGRID( xfac, y0Ref+ sv->y )- lc->lcOy;
 	}
 
-    if  ( ds->dsVertexCount > 0 )
-	{ xpret[ds->dsVertexCount]= xpret[0]; }
+    if  ( sd->sdVertexCount > 0 && xpret )
+	{ xpret[sd->sdVertexCount]= xpret[0]; }
 
     return xpret;
     }
 
 static void tedShapeGetLine(	int *				pLine,
 				int *				pWidthPixels,
+				int *				pWidthTwips,
 				const DrawingShape *		ds,
 				DrawingContext *		dc,
 				ScreenDrawingData *		sdd )
     {
-    docShapeGetLine( pLine, ds, dc, sdd );
+    const ShapeDrawing *	sd= &(ds->dsDrawing);
+    RGB8Color			rgb8Stroke;
+
+    docDrawShapeGetLine( pLine, &rgb8Stroke, ds, dc, sdd );
 
     if  ( *pLine )
 	{
 	const LayoutContext *	lc= &(dc->dcLayoutContext);
-	AppDrawingData *	add= lc->lcAdd;
-	int			widthTwips= EMUtoTWIPS( ds->dsLineWidthEmu );
-	int			widthPixels= X_PIXELS( add, widthTwips );
+	int			widthTwips= EMUtoTWIPS( sd->sdLineWidthEmu );
+	int			widthPixels= docLayoutXPixels( lc, widthTwips );
 
 	static unsigned char	dash[]= { 3, 2 };
 	static unsigned char	dot[]= { 1, 2 };
@@ -190,21 +145,21 @@ static void tedShapeGetLine(	int *				pLine,
 
 	const unsigned char *	dashList= (const unsigned char *)0;
 	int			dashCount= 0;
-	int			lineStyle= LINEstyleSOLID;
-	int			capStyle= LINEcapBUTT;
-	int			joinStyle= LINEjoinMITER;
+	int			lineStyle= LineStyleSolid;
+	int			capStyle= LineCapButt;
+	int			joinStyle= LineJoinMiter;
 
 	if  ( widthPixels < 1 )
 	    { widthPixels=  1;	}
 
-	switch( ds->dsLineDashing )
+	switch( sd->sdLineDashing )
 	    {
 	    case DSdashSOLID:
 		dashList= (const unsigned char *)0;
 		dashCount= 0;
-		lineStyle= LINEstyleSOLID;
-		capStyle= LINEcapBUTT;
-		joinStyle= LINEjoinMITER;
+		lineStyle= LineStyleSolid;
+		capStyle= LineCapButt;
+		joinStyle= LineJoinMiter;
 		break;
 
 	    case DSdashDASHED:
@@ -212,18 +167,18 @@ static void tedShapeGetLine(	int *				pLine,
 	    case DSdashDASHED_L:
 		dashList= dash;
 		dashCount= sizeof( dash );
-		lineStyle= LINEstyleON_OFF_DASH;
-		capStyle= LINEcapBUTT;
-		joinStyle= LINEjoinMITER;
+		lineStyle= LineStyleSingleDash;
+		capStyle= LineCapButt;
+		joinStyle= LineJoinMiter;
 		break;
 
 	    case DSdashDOT:
 	    case DSdashDOT_X:
 		dashList= dot;
 		dashCount= sizeof( dot );
-		lineStyle= LINEstyleON_OFF_DASH;
-		capStyle= LINEcapBUTT;
-		joinStyle= LINEjoinMITER;
+		lineStyle= LineStyleSingleDash;
+		capStyle= LineCapButt;
+		joinStyle= LineJoinMiter;
 		break;
 
 	    case DSdashDASHDOT:
@@ -231,91 +186,136 @@ static void tedShapeGetLine(	int *				pLine,
 	    case DSdashDASHDOT_L:
 		dashList= dashdot;
 		dashCount= sizeof( dashdot );
-		lineStyle= LINEstyleON_OFF_DASH;
-		capStyle= LINEcapBUTT;
-		joinStyle= LINEjoinMITER;
+		lineStyle= LineStyleSingleDash;
+		capStyle= LineCapButt;
+		joinStyle= LineJoinMiter;
 		break;
 
 	    case DSdashDASHDOTDOT:
 	    case DSdashDASHDOTDOT_L:
 		dashList= dashdotdot;
 		dashCount= sizeof( dashdotdot );
-		lineStyle= LINEstyleON_OFF_DASH;
-		capStyle= LINEcapBUTT;
-		joinStyle= LINEjoinMITER;
+		lineStyle= LineStyleSingleDash;
+		capStyle= LineCapButt;
+		joinStyle= LineJoinMiter;
 		break;
 
 	    default:
-		LDEB(ds->dsLineDashing);
+		LDEB(sd->sdLineDashing);
 		dashList= (const unsigned char *)0;
 		dashCount= 0;
 	    }
 
-	appDrawSetLineAttributes( add,
+	drawSetLineAttributes( lc->lcDrawingSurface,
 		    widthPixels, lineStyle, capStyle, joinStyle,
 		    dashList, dashCount );
 
-	*pWidthPixels= widthPixels;
+	if  ( pWidthPixels )
+	    { *pWidthPixels= widthPixels;	}
+	if  ( pWidthTwips )
+	    { *pWidthTwips= widthTwips;		}
 	}
     }
 
 static int tedShapeDrawPoints(	const DrawingShape *		ds,
-				const APP_POINT *		xp,
+				Point2DI *			xp,
 				int				np,
 				int				closed,
 				DrawingContext *		dc,
 				ScreenDrawingData *		sdd )
     {
+    const ShapeDrawing *	sd= &(ds->dsDrawing);
     const LayoutContext *	lc= &(dc->dcLayoutContext);
-    AppDrawingData *		add= lc->lcAdd;
+    double			xfac= lc->lcPixelsPerTwip;
 
-    int			line= 0;
-    int			widthPixels;
+    int				line= 0;
+    int				widthPixels;
+    int				widthTwips;
+
+    int				drawStartArrow= 0;
+    DrawShapeArrow		dsaStart;
+    Point2DD			shaftStart[2];
+    int				drawEndArrow= 0;
+    DrawShapeArrow		dsaEnd;
+    Point2DD			shaftEnd[2];
+
+    tedShapeGetLine( &line, &widthPixels, &widthTwips, ds, dc, sdd );
+
+    if  ( line && ! closed && np >= 2 )
+	{
+	if  ( sd->sdLineHeadArrow.saArrowHead != DSarrowNONE )
+	    {
+	    drawStartArrow= 1;
+
+	    shaftStart[0].x= xp[1].x;
+	    shaftStart[0].y= xp[1].y;
+	    shaftStart[1].x= xp[0].x;
+	    shaftStart[1].y= xp[0].y;
+
+	    docShapeArrowSizesTwips( &dsaStart, widthTwips, xfac,
+					shaftStart, &(sd->sdLineHeadArrow) );
+	    }
+
+	if  ( sd->sdLineTailArrow.saArrowHead != DSarrowNONE )
+	    {
+	    drawEndArrow= 1;
+
+	    shaftEnd[0].x= xp[np-2].x;
+	    shaftEnd[0].y= xp[np-2].y;
+	    shaftEnd[1].x= xp[np-1].x;
+	    shaftEnd[1].y= xp[np-1].y;
+
+	    docShapeArrowSizesTwips( &dsaEnd, widthTwips, xfac,
+					shaftEnd, &(sd->sdLineTailArrow) );
+	    }
+	}
 
     if  ( closed )
 	{
 	int		fill= 0;
+	RGB8Color	rgb8Fill;
 
-	docShapeGetFill( &fill, ds, dc, sdd );
+	docDrawShapeGetFill( &fill, &rgb8Fill, ds, dc, sdd );
 	if  ( fill )
-	    { appDrawFillPolygon( add, xp, np ); }
+	    { drawFillPolygon( lc->lcDrawingSurface, xp, np ); }
 	}
 
-    tedShapeGetLine( &line, &widthPixels, ds, dc, sdd );
     if  ( line )
-	{ appDrawDrawLines( add, xp, np, closed ); }
-
-    if  ( line && ! closed && np >= 2 )
 	{
-	if  ( ds->dsLineStartArrow.saArrowHead != DSarrowNONE )
+	if  ( drawStartArrow )
 	    {
-	    tedShapeDrawArrowHead( add, xp[0].x, xp[0].y,
-					xp[1].x, xp[1].y,
-					widthPixels,
-					&(ds->dsLineStartArrow) );
+	    xp[0].x= dsaStart.dsaShaft[1].x;
+	    xp[0].y= dsaStart.dsaShaft[1].y;
 	    }
-	if  ( ds->dsLineEndArrow.saArrowHead != DSarrowNONE )
+
+	if  ( drawEndArrow )
 	    {
-	    tedShapeDrawArrowHead( add, xp[np-1].x, xp[np-1].y,
-					xp[np-2].x, xp[np-2].y,
-					widthPixels,
-					&(ds->dsLineEndArrow) );
+	    xp[np-1].x= dsaEnd.dsaShaft[1].x;
+	    xp[np-1].y= dsaEnd.dsaShaft[1].y;
 	    }
+
+	drawLines( lc->lcDrawingSurface, xp, np, closed );
 	}
 
+    if  ( drawStartArrow )
+	{ tedShapeDrawArrowHead( lc, widthPixels, &dsaStart );	}
+    if  ( drawEndArrow )
+	{ tedShapeDrawArrowHead( lc, widthPixels, &dsaEnd );	}
+
     return 0;
     }
 
-static void tedDrawSetShapePath(APP_POINT *			xp,
+static void tedDrawSetShapePath(Point2DI *			xp,
 				const DrawingShape *		ds,
 				const ShapePath *		sp,
 				const DocumentRectangle *	dr )
     {
-    int			np= sp->spVertexCount;
-    const ShapeVertex *	sv= sp->spVertices;
-    int			i;
+    const ShapeDrawing *	sd= &(ds->dsDrawing);
+    int				np= sp->spVertexCount;
+    const Point2DI *		sv= sp->spVertices;
+    int				i;
 
-    if  ( ds->dsRotation == 0 )
+    if  ( sd->sdRotation == 0 )
 	{
 	int			xs= sp->spXSize;
 	int			ys= sp->spYSize;
@@ -332,8 +332,8 @@ static void tedDrawSetShapePath(APP_POINT *			xp,
 
 	for ( i= 0; i < np; sv++, i++ )
 	    {
-	    xp[i].x= ( ( xs- sv->svX )* x0+ sv->svX* x1 )/ xs;
-	    xp[i].y= ( ( ys- sv->svY )* y0+ sv->svY* y1 )/ ys;
+	    xp[i].x= ( ( xs- sv->x )* x0+ sv->x* x1 )/ xs;
+	    xp[i].y= ( ( ys- sv->y )* y0+ sv->y* y1 )/ ys;
 	    }
 	}
     else{
@@ -350,8 +350,8 @@ static void tedDrawSetShapePath(APP_POINT *			xp,
 	    double	x;
 	    double	y;
 
-	    x= ( ( xs- sv->svX )* dr->drX0+ sv->svX* dr->drX1 )/ xs -xm;
-	    y= ( ( ys- sv->svY )* dr->drY0+ sv->svY* dr->drY1 )/ ys- ym;
+	    x= ( ( xs- sv->x )* dr->drX0+ sv->x* dr->drX1 )/ xs -xm;
+	    y= ( ( ys- sv->y )* dr->drY0+ sv->y* dr->drY1 )/ ys- ym;
 
 	    xp[i].x= AT2_X( x, y, &at )+ xm;
 	    xp[i].y= AT2_Y( x, y, &at )+ ym;
@@ -371,9 +371,9 @@ static int tedDrawShapePath(	const DrawingShape *		ds,
     {
     int			rval= 0;
     int			np= sp->spVertexCount;
-    APP_POINT *		xp;
+    Point2DI *		xp;
 
-    xp= malloc( ( np+ 1 )* sizeof(APP_POINT) );
+    xp= malloc( ( np+ 1 )* sizeof(Point2DI) );
     if  ( ! xp )
 	{ LXDEB(np,xp); return -1;	}
 
@@ -393,35 +393,38 @@ static int tedDrawPictureFrame( DrawingShape *			ds,
 				const DocumentRectangle *	drPixels )
     {
     const LayoutContext *	lc= &(dc->dcLayoutContext);
-    AppDrawingData *		add= lc->lcAdd;
 
-    const ShapePath *	sp= &SP_RECTANGLE;
-    int			np= sp->spVertexCount;
-    APP_POINT *		xp;
+    const ShapePath *		sp= &SP_RECTANGLE;
+    int				np= sp->spVertexCount;
+    Point2DI *			xp;
 
-    int			fill= 0;
-    int			line= 0;
-    int			widthPixels= 0;
+    int				fill= 0;
+    int				line= 0;
+    int				widthPixels= 0;
 
-    xp= malloc( ( np+ 1 )* sizeof(APP_POINT) );
+    RGB8Color			rgb8Fill;
+    DocumentRectangle		drSrc;
+
+    xp= malloc( ( np+ 1 )* sizeof(Point2DI) );
     if  ( ! xp )
 	{ LXDEB(np,xp); return -1;	}
 
     tedDrawSetShapePath( xp, ds, sp, drPixels );
 
-    docShapeGetFill( &fill, ds, dc, sdd );
+    docDrawShapeGetFill( &fill, &rgb8Fill, ds, dc, sdd );
     if  ( fill )
-	{ appDrawFillPolygon( add, xp, np ); }
+	{ drawFillPolygon( lc->lcDrawingSurface, xp, np ); }
 
-    tedDrawPixmap( lc, ds->dsScreenPixmap,
-		0, 0, /* src: x,y */
-		drPixels->drX1- drPixels->drX0+ 1, /* wide */
-		drPixels->drY1- drPixels->drY0+ 1, /* high */
-		drPixels->drX0, drPixels->drY0 ); /* dest: x,y */
+    drSrc= *drPixels;
+    geoShiftRectangle( &drSrc, -drPixels->drX0, -drPixels->drY0 );
 
-    tedShapeGetLine( &line, &widthPixels, ds, dc, sdd );
+    drawChildSurface( lc->lcDrawingSurface, ds->dsDrawingSurface,
+					    drPixels->drX0, drPixels->drY0,
+					    &drSrc );
+
+    tedShapeGetLine( &line, &widthPixels, (int *)0, ds, dc, sdd );
     if  ( line )
-	{ appDrawDrawLines( add, xp, np+ 1, 0 ); }
+	{ drawLines( lc->lcDrawingSurface, xp, np+ 1, 0 ); }
 
     free( xp );
 
@@ -434,63 +437,62 @@ static int tedDrawOnlineStorage( DrawingShape *			ds,
 				const DocumentRectangle *	drPixels )
     {
     const LayoutContext *	lc= &(dc->dcLayoutContext);
-    AppDrawingData *		add= lc->lcAdd;
+    DrawingSurface		drsf= lc->lcDrawingSurface;
 
-    const ShapePath *	sp= &SP_RECTANGLE;
-    int			np= sp->spVertexCount;
-    APP_POINT *		xp;
+    const ShapePath *		sp= &SP_RECTANGLE;
+    int				np= sp->spVertexCount;
+    Point2DI *			xp;
+    Arc2DI			arc;
 
-    int			fill= 0;
-    int			line= 0;
-    int			widthPixels= 0;
+    int				fill= 0;
+    int				line= 0;
+    int				widthPixels= 0;
 
-    int			wide;
-    int			high;
-    int			rx0;
-    int			rx1;
+    int				wide;
+    int				rx0;
+    int				rx1;
 
-    xp= malloc( ( np+ 1 )* sizeof(APP_POINT) );
+    RGB8Color			rgb8Fill;
+
+    xp= malloc( ( np+ 1 )* sizeof(Point2DI) );
     if  ( ! xp )
 	{ LXDEB(np,xp); return -1;	}
 
     tedDrawSetShapePath( xp, ds, sp, drPixels );
 
     wide= drPixels->drX1- drPixels->drX0;
+    /*
     high= drPixels->drY1- drPixels->drY0;
+    */
     rx0= ( 5* drPixels->drX0+ 1* drPixels->drX1 )/ 6;
     rx1= ( 1* drPixels->drX0+ 5* drPixels->drX1 )/ 6;
 
-    docShapeGetFill( &fill, ds, dc, sdd );
+    arc.a2diRect= *drPixels;
+    arc.a2diRect.drX1= drPixels->drX0+ ( wide+ 2 )/ 3;
+    arc.a2diAngleFrom= 64* 90;
+    arc.a2diAngleStep= 64* 180;
+
+    docDrawShapeGetFill( &fill, &rgb8Fill, ds, dc, sdd );
     if  ( fill )
 	{
-	appDrawFillArc( add, drPixels->drX0, drPixels->drY0,
-			    ( wide+ 2 )/ 3, high+ 1,
-			    64* 90, 64* 180 );
+	DocumentRectangle	drFill= *drPixels;
 
-	appDrawFillRectangle( add, rx0, drPixels->drY0,
-			    rx1- rx0+ 1, high );
+	drawFillArc( drsf, &arc );
 
-	/*
-	appDrawFillArc( add, drPixels->drX0,
-			    ( 1* drPixels->drY0+ 2* drPixels->drY1 )/ 3,
-			    wide+ 1, ( high+ 2 )/ 3,
-			    64* 180, 64* 180 );
-	*/
+	drFill.drX0= rx0;
+	drFill.drX1= rx1;
+	drawFillRectangle( drsf, &drFill );
 	}
-    tedShapeGetLine( &line, &widthPixels, ds, dc, sdd );
+
+    tedShapeGetLine( &line, &widthPixels, (int *)0, ds, dc, sdd );
     if  ( line )
 	{
-	appDrawDrawArc( add, drPixels->drX0, drPixels->drY0,
-			    ( wide+ 2 )/ 3, high+ 1,
-			    64* 90, 64* 180 );
+	drawArc( drsf, &arc );
 
-	appDrawDrawLine( add, rx0,  drPixels->drY0, rx1,  drPixels->drY0 );
-	appDrawDrawLine( add, rx0,  drPixels->drY1, rx1,  drPixels->drY1 );
+	drawLine( drsf, rx0, drPixels->drY0, rx1, drPixels->drY0 );
+	drawLine( drsf, rx0, drPixels->drY1, rx1, drPixels->drY1 );
 
-	appDrawDrawArc( add, ( 1* drPixels->drX0+ 2* drPixels->drX1 )/ 3,
-			    drPixels->drY0,
-			    ( wide+ 2 )/ 3, high+ 1,
-			    64* 90, 64* 180 );
+	drawArc( drsf, &arc );
 	}
 
     free( xp );
@@ -498,73 +500,66 @@ static int tedDrawOnlineStorage( DrawingShape *			ds,
     return 0;
     }
 
-static int tedDrawMagneticDisk( DrawingShape *			ds,
+static int tedDrawCan( 		DrawingShape *			ds,
 				DrawingContext *		dc,
 				ScreenDrawingData *		sdd,
 				const DocumentRectangle *	drPixels )
     {
     const LayoutContext *	lc= &(dc->dcLayoutContext);
-    AppDrawingData *		add= lc->lcAdd;
+    DrawingSurface		drsf= lc->lcDrawingSurface;
 
-    const ShapePath *		sp= &SP_RECTANGLE;
-    int				np= sp->spVertexCount;
-    APP_POINT *			xp;
+    Arc2DI			topArc;
+    Arc2DI			botArc;
 
     int				fill= 0;
     int				line= 0;
     int				widthPixels= 0;
 
-    int				wide;
-    int				high;
     int				ry0;
     int				ry1;
 
-    xp= malloc( ( np+ 1 )* sizeof(APP_POINT) );
-    if  ( ! xp )
-	{ LXDEB(np,xp); return -1;	}
+    RGB8Color			rgb8Fill;
 
-    tedDrawSetShapePath( xp, ds, sp, drPixels );
-
-    wide= drPixels->drX1- drPixels->drX0;
-    high= drPixels->drY1- drPixels->drY0;
     ry0= ( 5* drPixels->drY0+ 1* drPixels->drY1 )/ 6;
     ry1= ( 1* drPixels->drY0+ 5* drPixels->drY1 )/ 6;
 
-    docShapeGetFill( &fill, ds, dc, sdd );
+    topArc.a2diRect= *drPixels;
+    topArc.a2diRect.drY0= drPixels->drY0;
+    topArc.a2diRect.drY1= ( 2* drPixels->drY0+ 1* drPixels->drY1 )/ 3;
+    topArc.a2diAngleFrom= 64* 0;
+    topArc.a2diAngleStep= 64* 360;
+
+    botArc.a2diRect= *drPixels;
+    botArc.a2diRect.drY0= ( 1* drPixels->drY0+ 2* drPixels->drY1 )/ 3;
+    botArc.a2diRect.drY1= drPixels->drY1;
+    botArc.a2diAngleFrom= 64* 180;
+    botArc.a2diAngleStep= 64* 180;
+
+    docDrawShapeGetFill( &fill, &rgb8Fill, ds, dc, sdd );
     if  ( fill )
 	{
-	appDrawFillArc( add, drPixels->drX0, drPixels->drY0,
-			    wide+ 1, ( high+ 2 )/ 3,
-			    64* 0, 64* 360 );
+	DocumentRectangle	drFill= *drPixels;
 
-	appDrawFillRectangle( add, drPixels->drX0, ry0,
-			    wide, ry1- ry0+ 1 );
+	drawFillArc( drsf, &topArc );
 
-	appDrawFillArc( add, drPixels->drX0,
-			    ( 1* drPixels->drY0+ 2* drPixels->drY1 )/ 3,
-			    wide+ 1, ( high+ 2 )/ 3,
-			    64* 180, 64* 180 );
+	drFill.drY0= ry0;
+	drFill.drY1= ry1;
+	drawFillRectangle( drsf, &drFill );
+
+	drawFillArc( drsf, &botArc );
 	}
 
-    tedShapeGetLine( &line, &widthPixels, ds, dc, sdd );
+    tedShapeGetLine( &line, &widthPixels, (int *)0, ds, dc, sdd );
     if  ( line )
 	{
-	appDrawDrawArc( add, drPixels->drX0, drPixels->drY0,
-			    wide+ 1, ( high+ 2 )/ 3,
-			    64* 0, 64* 360 );
+	drawArc( drsf, &topArc );
 
-	appDrawDrawLine( add, drPixels->drX0, ry0,
-			    drPixels->drX0, ry1 );
-	appDrawDrawLine( add, drPixels->drX1, ry0,
-			    drPixels->drX1, ry1 );
+	drawLine( drsf, drPixels->drX0, ry0, drPixels->drX0, ry1 );
+	drawLine( drsf, drPixels->drX1, ry0, drPixels->drX1, ry1 );
 
-	appDrawDrawArc( add, drPixels->drX0,
-			    ( 1* drPixels->drY0+ 2* drPixels->drY1 )/ 3,
-			    wide+ 1, ( high+ 2 )/ 3,
-			    64* 180, 64* 180 );
+	drawArc( drsf, &botArc );
 	}
 
-    free( xp );
     return 0;
     }
 
@@ -574,31 +569,34 @@ static int tedDrawCallout(	DrawingShape *			ds,
 				ScreenDrawingData *		sdd,
 				const DocumentRectangle *	drPixels )
     {
+    const ShapeDrawing *	sd= &(ds->dsDrawing);
     const LayoutContext *	lc= &(dc->dcLayoutContext);
-    AppDrawingData *		add= lc->lcAdd;
+    DrawingSurface		drsf= lc->lcDrawingSurface;
 
     const ShapePath *	sp= &SP_RECTANGLE;
     int			np= sp->spVertexCount;
-    APP_POINT *		xp;
+    Point2DI *		xp;
 
     int			fill= 0;
     int			line= 0;
     int			widthPixels= 0;
 
+    RGB8Color		rgb8Fill;
+
     if  ( np != 4 )
 	{ LDEB(np); return -1;	}
 
-    xp= malloc( ( np+ 1+ 2+ 1 )* sizeof(APP_POINT) );
+    xp= malloc( ( np+ 1+ 2+ 1 )* sizeof(Point2DI) );
     if  ( ! xp )
 	{ LXDEB(np,xp); return -1;	}
 
     tedDrawSetShapePath( xp, ds, sp, drPixels );
 
-    docShapeGetFill( &fill, ds, dc, sdd );
+    docDrawShapeGetFill( &fill, &rgb8Fill, ds, dc, sdd );
     if  ( fill )
-	{ appDrawFillPolygon( add, xp, np ); }
+	{ drawFillPolygon( drsf, xp, np ); }
 
-    tedShapeGetLine( &line, &widthPixels, ds, dc, sdd );
+    tedShapeGetLine( &line, &widthPixels, (int *)0, ds, dc, sdd );
     if  ( line )
 	{
 	int		pp0= 5;
@@ -607,19 +605,19 @@ static int tedDrawCallout(	DrawingShape *			ds,
 
 	const int	SC= 21600; /* adjust to geoLeft etc? */
 
-	a2= ds->dsAdjustValue; a0= SC- a2;
+	a2= sd->sdAdjustValue; a0= SC- a2;
 	xp[pp1].x= ( a0* xp[0].x+ a2* xp[2].x )/ SC;
-	a2= ds->dsAdjust2Value; a0= SC- a2;
+	a2= sd->sdAdjust2Value; a0= SC- a2;
 	xp[pp1].y= ( a0* xp[0].y+ a2* xp[2].y )/ SC;
 	pp1++;
 
-	a2= ds->dsAdjust3Value; a0= SC- a2;
+	a2= sd->sdAdjust3Value; a0= SC- a2;
 	xp[pp1].x= ( a0* xp[0].x+ a2* xp[2].x )/ SC;
-	a2= ds->dsAdjust4Value; a0= SC- a2;
+	a2= sd->sdAdjust4Value; a0= SC- a2;
 	xp[pp1].y= ( a0* xp[0].y+ a2* xp[2].y )/ SC;
 	pp1++;
 
-	appDrawDrawLines( add, xp+ pp0, pp1- pp0, 0 );
+	drawLines( drsf, xp+ pp0, pp1- pp0, 0 );
 	}
 
     free( xp );
@@ -633,39 +631,36 @@ int tedDrawDrawingShape(	const DocumentRectangle *	drTwips,
 				DrawingContext *		dc,
 				void *				vsdd )
     {
+    const ShapeDrawing *	sd= &(ds->dsDrawing);
     const LayoutContext *	lc= &(dc->dcLayoutContext);
-    AppDrawingData *		add= lc->lcAdd;
+    DrawingSurface		drsf= lc->lcDrawingSurface;
     ScreenDrawingData *		sdd= (ScreenDrawingData *)vsdd;
 
     int				rval= 0;
 
     DocumentRectangle		drPixels;
+    DocumentRectangle		drNorm;
     int				fill= 0;
     int				line= 0;
     int				widthPixels= 0;
 
-    int				wide;
-    int				high;
-
-    APP_POINT *			xp= (APP_POINT *)0;
+    Point2DI *			xp= (Point2DI *)0;
 
     docGetPixelRect( &drPixels, lc, drTwips, page );
+    geoNormalizeRectangle( &drNorm, &drPixels );
 
     if  ( dc->dcClipRect						&&
 	  ! geoIntersectRectangle( (DocumentRectangle *)0,
-					    &drPixels, dc->dcClipRect ) )
+					    &drNorm, dc->dcClipRect )	)
 	{ return 0;	}
 
-    drPixels.drX0 -= lc->lcOx;
-    drPixels.drX1 -= lc->lcOx;
-    drPixels.drY0 -= lc->lcOy;
-    drPixels.drY1 -= lc->lcOy;
+    geoShiftRectangle( &drPixels, -lc->lcOx, -lc->lcOy );
 
-    switch( ds->dsShapeType )
+    switch( sd->sdShapeType )
 	{
 	case SHPtyGROUP:
 	    /* Done by docDrawDrawingShape(). */
-	    LSDEB(ds->dsShapeType,docShapeTypeString(ds->dsShapeType));
+	    LSDEB(sd->sdShapeType,docShapeTypeString(sd->sdShapeType));
 	    break;
 
 	case 33:
@@ -700,55 +695,57 @@ int tedDrawDrawingShape(	const DocumentRectangle *	drTwips,
 	case SHPtyROUND_RECTANGLE:
 	case SHPtyFLOW_CHART_ALTERNATE_PROCESS:
 	    {
+	    RGB8Color		rgb8Fill;
+
 	    const int	w= ( drPixels.drX1- drPixels.drX0 )/ 4;
 	    const int	h= ( drPixels.drY1- drPixels.drY0 )/ 4;
 
-	    docShapeGetFill( &fill, ds, dc, sdd );
+	    docDrawShapeGetFill( &fill, &rgb8Fill, ds, dc, sdd );
 	    if  ( fill )
-		{ appDrawFillRoundRectX11( add, &drPixels, w, h );	}
-	    tedShapeGetLine( &line, &widthPixels, ds, dc, sdd );
+		{ drawFillRoundedRect( drsf, &drPixels, w, h );	}
+	    tedShapeGetLine( &line, &widthPixels, (int *)0, ds, dc, sdd );
 	    if  ( line )
-		{ appDrawDrawRoundRectX11( add, &drPixels, w, h );	}
+		{ drawRoundedRect( drsf, &drPixels, w, h );	}
 	    }
 	    break;
 
 	case SHPtyELLIPSE:
 	case SHPtyFLOW_CHART_CONNECTOR:
-	    wide= drPixels.drX1- drPixels.drX0;
-	    high= drPixels.drY1- drPixels.drY0;
-	    docShapeGetFill( &fill, ds, dc, sdd );
+	    {
+	    RGB8Color		rgb8Fill;
+	    Arc2DI		arc;
+
+	    arc.a2diRect= drPixels;
+	    arc.a2diAngleFrom= 64* 0;
+	    arc.a2diAngleStep= 64* 360;
+
+	    docDrawShapeGetFill( &fill, &rgb8Fill, ds, dc, sdd );
 	    if  ( fill )
-		{
-		appDrawFillArc( add, drPixels.drX0, drPixels.drY0,
-					    wide+ 1, high+ 1,
-					    64* 0, 64* 360 );
-		}
-	    tedShapeGetLine( &line, &widthPixels, ds, dc, sdd );
+		{ drawFillArc( drsf, &arc );	}
+
+	    tedShapeGetLine( &line, &widthPixels, (int *)0, ds, dc, sdd );
 	    if  ( line )
-		{
-		appDrawDrawArc( add, drPixels.drX0, drPixels.drY0,
-					    wide+ 1, high+ 1,
-					    64* 0, 64* 360 );
-		}
+		{ drawArc( drsf, &arc );	}
+	    }
 	    break;
 
 	case SHPtyARC:
-	    wide= drPixels.drX1- drPixels.drX0;
-	    high= drPixels.drY1- drPixels.drY0;
-	    docShapeGetFill( &fill, ds, dc, sdd );
+	    {
+	    RGB8Color		rgb8Fill;
+	    Arc2DI		arc;
+
+	    arc.a2diRect= drPixels;
+	    arc.a2diAngleFrom= 64* 0;
+	    arc.a2diAngleStep= 64* 90;
+
+	    docDrawShapeGetFill( &fill, &rgb8Fill, ds, dc, sdd );
 	    if  ( fill )
-		{
-		appDrawFillArc( add, drPixels.drX0- wide, drPixels.drY0,
-					    2* wide+ 1, 2* high+ 1,
-					    64* 0, 64* 90 );
-		}
-	    tedShapeGetLine( &line, &widthPixels, ds, dc, sdd );
+		{ drawFillArc( drsf, &arc );	}
+
+	    tedShapeGetLine( &line, &widthPixels, (int *)0, ds, dc, sdd );
 	    if  ( line )
-		{
-		appDrawDrawArc( add, drPixels.drX0- wide, drPixels.drY0,
-					    2* wide+ 1, 2* high+ 1,
-					    64* 0, 64* 90 );
-		}
+		{ drawArc( drsf, &arc );	}
+	    }
 	    break;
 
 	case SHPtyDIAMOND:
@@ -949,7 +946,7 @@ int tedDrawDrawingShape(	const DocumentRectangle *	drTwips,
 
 	case SHPtyCAN:
 	case SHPtyFLOW_CHART_MAGNETIC_DISK:
-	    if  ( tedDrawMagneticDisk( ds, dc, sdd, &drPixels ) )
+	    if  ( tedDrawCan( ds, dc, sdd, &drPixels ) )
 		{ LDEB(1); rval= -1;	}
 	    break;
 
@@ -957,31 +954,35 @@ int tedDrawDrawingShape(	const DocumentRectangle *	drTwips,
 	    {
 	    const ShapePath *	sp= &SP_RECTANGLE;
 	    int			np= sp->spVertexCount;
-	    APP_POINT *		xp;
+	    Point2DI *		xp;
 
 	    int			wide;
-	    int			high;
 
-	    xp= malloc( ( np+ 1 )* sizeof(APP_POINT) );
+	    xp= malloc( ( np+ 1 )* sizeof(Point2DI) );
 	    if  ( ! xp )
 		{ LXDEB(np,xp); return -1;	}
 
 	    tedDrawSetShapePath( xp, ds, sp, &drPixels );
 
 	    wide= xp[2].x- xp[0].x;
+	    /*
 	    high= xp[2].y- xp[0].y;
+	    */
 
-	    tedShapeGetLine( &line, &widthPixels, ds, dc, sdd );
+	    tedShapeGetLine( &line, &widthPixels, (int *)0, ds, dc, sdd );
 
+# if 0
 	    appDrawDrawArc( add, xp[0].x- wide/ 2,
 				    ( 8* xp[0].y+ 0* xp[2].y )/ 8,
 				    wide+ 1, ( high+ 3 )/ 4,
 				    64* 0, 64* 90 );
+# endif
 
-	    appDrawDrawLine( add,
+	    drawLine( drsf,
 		    xp[0].x+ wide/ 2, ( 7* xp[0].y+ 1* xp[2].y )/ 8,
 		    xp[0].x+ wide/ 2, ( 5* xp[0].y+ 3* xp[2].y )/ 8 );
 
+# if 0
 	    appDrawDrawArc( add, xp[2].x- wide/ 2,
 				    ( 6* xp[0].y+ 2* xp[2].y )/ 8,
 				    wide+ 1, ( high+ 3 )/ 4,
@@ -991,22 +992,25 @@ int tedDrawDrawingShape(	const DocumentRectangle *	drTwips,
 				    ( 4* xp[0].y+ 4* xp[2].y )/ 8,
 				    wide+ 1, ( high+ 3 )/ 4,
 				    64* 90, 64* 90 );
+# endif
 
-	    appDrawDrawLine( add,
+	    drawLine( drsf,
 		    xp[0].x+ wide/ 2, ( 3* xp[0].y+ 5* xp[2].y )/ 8,
 		    xp[0].x+ wide/ 2, ( 1* xp[0].y+ 7* xp[2].y )/ 8 );
 
+# if 0
 	    appDrawDrawArc( add, xp[0].x- wide/ 2,
 				    ( 2* xp[0].y+ 6* xp[2].y )/ 8,
 				    wide+ 1, ( high+ 3 )/ 4,
 				    64* 270, 64* 90 );
+# endif
 
 	    free( xp );
 	    }
 	    break;
 
 	case SHPtyFREEFORM_OR_NON_AUTOSHAPE:
-	    if  ( ds->dsVertexCount > 1 )
+	    if  ( sd->sdVertexCount > 1 )
 		{
 		const int	closed= 1;
 
@@ -1014,19 +1018,19 @@ int tedDrawDrawingShape(	const DocumentRectangle *	drTwips,
 		if  ( ! xp )
 		    { XDEB(xp); rval= -1; goto ready;	}
 
-		tedShapeDrawPoints( ds, xp, ds->dsVertexCount- 1,
-							closed, dc, sdd );
+		tedShapeDrawPoints( ds, xp, sd->sdVertexCount- 1,
+						    closed, dc, sdd );
 		}
 	    break;
 
 	case SHPtyBENT_ARROW:
 	default:
-	    LSDEB(ds->dsShapeType,docShapeTypeString(ds->dsShapeType));
+	    LSDEB(sd->sdShapeType,docShapeTypeString(sd->sdShapeType));
 	    break;
 	}
 
     /* Done by docDrawDrawingShape()....
-    if  ( ds->dsDocumentTree.eiRoot )
+    if  ( ds->dsDocumentTree.dtRoot )
 	{}
     */
 
