@@ -7,8 +7,10 @@
 #   ifndef	TED_FIND_TOOL_H
 #   define	TED_FIND_TOOL_H
 
-#   include	"tedApp.h"
+#   include	<appFrame.h>
+#   include	<docBuf.h>
 #   include	<appFindTool.h>
+#   include	<docSelectionDescription.h>
 
 /************************************************************************/
 /*									*/
@@ -23,7 +25,8 @@ extern void tedRefreshFindTool(	FindTool *			aft,
 				const DocumentSelection *	ds,
 				const SelectionDescription *	sd,
 				const BufferDocument *		bd,
-				int				documentId );
+				int				documentId,
+				const unsigned char *		cmdEnabled );
 
 extern void tedFillFindTool(	FindTool *			aft,
 				const FindToolResources *	aftr,
