@@ -7,14 +7,13 @@
 #   ifndef	TED_FORMAT_TOOL_H
 #   define	TED_FORMAT_TOOL_H
 
-#   include	"docSetRowProperties.h"
-
 #   include	"tedParaLayoutTool.h"
 #   include	"tedParaOrnamentsTool.h"
 #   include	"tedTextOrnamentsTool.h"
 #   include	"tedRowTool.h"
 #   include	"tedSectionTool.h"
 #   include	"tedPageLayoutTool.h"
+#   include	"tedThisNoteTool.h"
 #   include	"tedNotesTool.h"
 #   include	"tedHeaderFooterTool.h"
 #   include	"tedTableTool.h"
@@ -22,7 +21,6 @@
 #   include	"tedCellTool.h"
 #   include	"tedTabsTool.h"
 #   include	"tedListTool.h"
-#   include	"tedFontTool.h"
 #   include	"tedSymbolPicker.h"
 #   include	"tedLinkTool.h"
 #   include	"tedBookmarkTool.h"
@@ -32,6 +30,7 @@
 #   include	"tedTocTool.h"
 #   include	"tedFindTool.h"
 #   include	"tedSpellTool.h"
+#   include	<docSelectionDescription.h>
 
 #   include	<appRgbChooserPage.h>
 
@@ -41,17 +40,32 @@
 /*									*/
 /************************************************************************/
 
+# define USE_FONT_TOOL 1
+# define USE_TABS_TOOL 1
+# define USE_LIST_TOOL 1
+# define USE_PAGE_TOOL 1
+# define USE_FIND_TOOL 1
+# define USE_SPELL_TOOL 1
+# define USE_LINK_TOOL 1
+# define USE_BOOKMARK_TOOL 1
+
 # define USE_FRAME_TOOL 0
 
 typedef enum ToolSubjectIndex
     {
+#   if USE_FONT_TOOL
     TEDtsiFONT= 0,
+#   endif
     TEDtsiTEXT_ORN,
 
     TEDtsiPARA_LAY,
+#   if USE_TABS_TOOL
     TEDtsiTABS,
+#   endif
     TEDtsiPARA_ORN,
+#   if USE_LIST_TOOL
     TEDtsiLISTS,
+#   endif
     TEDtsiSECT,
 
     TEDtsiTABLE,
@@ -59,11 +73,19 @@ typedef enum ToolSubjectIndex
     TEDtsiCOLUMN,
     TEDtsiCELL,
 
+#   if USE_PAGE_TOOL
     TEDtsiPAGE,
+#   endif
     TEDtsiHEADFOOT,
-    TEDtsiNOTES,
+    TEDtsiTHIS_NOTE,
+    TEDtsiFOOT_NOTES,
+    TEDtsiEND_NOTES,
+#   if USE_LINK_TOOL
     TEDtsiLINK,
+#   endif
+#   if USE_BOOKMARK_TOOL
     TEDtsiBOOKMARK,
+#   endif
     TEDtsiIMAGE,
 #   if USE_FRAME_TOOL
     TEDtsiFRAME,
@@ -71,8 +93,12 @@ typedef enum ToolSubjectIndex
     TEDtsiTOC,
     TEDtsiSYMBOL,
 
+#   if USE_FIND_TOOL
     TEDtsiFIND,
+#   endif
+#   if USE_SPELL_TOOL
     TEDtsiSPELL,
+#   endif
 
     TEDtsiRGB,
 
@@ -96,23 +122,43 @@ typedef struct TedFormatTool
     ColumnTool			tftColumnTool;
     CellTool			tftCellTool;
     ParagraphLayoutTool		tftParagraphLayoutTool;
+#   if USE_TABS_TOOL
     TabsTool			tftTabsTool;
+#   endif
     ParagraphOrnamentsTool	tftParagraphOrnamentsTool;
+#   if USE_LIST_TOOL
     ListTool			tftListsTool;
+#   endif
     SectionTool			tftSectionTool;
+#   if USE_PAGE_TOOL
     PageLayoutTool		tftPageLayoutTool;
+#   endif
     HeaderFooterTool		tftHeaderFooterTool;
-    NotesTool			tftNotesTool;
+    ThisNoteTool		tftThisNoteTool;
+    NotesTool			tftFootNotesTool;
+    NotesTool			tftEndNotesTool;
+#   if USE_FONT_TOOL
     AppFontChooser		tftFontTool;
+#   endif
     TextOrnamentsTool		tftTextOrnamentsTool;
+#   if USE_LINK_TOOL
     LinkTool			tftLinkTool;
+#   endif
+#   if USE_BOOKMARK_TOOL
     BookmarkTool		tftBookmarkTool;
+#   endif
     ImageTool			tftImageTool;
+#   if USE_FRAME_TOOL
     FrameTool			tftFrameTool;
+#   endif
     TocTool			tftTocTool;
     SymbolPicker		tftSymbolPicker;
+#   if USE_FIND_TOOL
     FindTool			tftFindTool;
+#   endif
+#   if USE_SPELL_TOOL
     SpellTool			tftSpellTool;
+#   endif
 
     RgbChooserPage		tftRgbPage;
     } TedFormatTool;
@@ -123,102 +169,4 @@ typedef struct TedFormatTool
 /*									*/
 /************************************************************************/
 
-extern int tedFormatToolGetRowLeftIndent( const RowProperties *	rp,
-					const int		pageLeftMargin,
-					int *			pValue,
-					APP_WIDGET		w );
-
-extern int tedFormatToolGetGapWidth(	const RowProperties *	rp,
-					int *			pValue,
-					APP_WIDGET		w );
-
-extern void tedFormatFillSectionPage(	SectionTool *		st,
-				const SectionPageResources *	spr,
-				InspectorSubject *		is,
-				APP_WIDGET			pageWidget,
-				const InspectorSubjectResources * isr );
-
-extern void tedFormatFillSectionChoosers( SectionTool *			st,
-					const SectionPageResources *	spr );
-
-extern void tedFormatFinishSectionPage(	SectionTool *			st,
-					TedFormatTool *			tft,
-					const SectionPageResources *	spr );
-
-extern void tedFormatFinishPageLayoutPage(	PageLayoutTool *	plt,
-					TedFormatTool *			tft,
-					const PageLayoutPageResources *	plpr );
-
-extern void tedFormatFillNotesPage( NotesTool *			nt,
-				const NotesPageResources *	npr,
-				InspectorSubject *		is,
-				APP_WIDGET			pageWidget,
-				const InspectorSubjectResources * isr );
-
-extern void tedFormatFillNotesChoosers(	NotesTool *			nt,
-					const NotesPageResources *	npr );
-
-extern void tedFormatFinishNotesPage(	NotesTool *			nt,
-					TedFormatTool *			tft,
-					const NotesPageResources *	npr );
-
-extern int tedFormatValidateDimension(		int *		pNewValue,
-						int *		pChanged,
-						APP_WIDGET	w,
-						int		oldValue );
-
-extern void tedColumnToolFillChoosers( ColumnTool *			ct,
-					const ColumnPageResources *	cpr );
-
-extern void tedFormatFinishCellPage(	CellTool *			ct,
-					TedFormatTool *			tft,
-					const CellPageResources *	cpr );
-
-extern void tedFormatFillPageLayoutPage(
-			PageLayoutTool *			plt,
-			const PageLayoutPageResources *		plpr,
-			InspectorSubject *			is,
-			APP_WIDGET				pageWidget,
-			const InspectorSubjectResources *	isr );
-
-extern void tedFormatFillHeaderFooterPage(
-			HeaderFooterTool *			hft,
-			const HeaderFooterPageResources *	hfpr,
-			InspectorSubject *			is,
-			APP_WIDGET				pageWidget,
-			const InspectorSubjectResources *	isr );
-
-extern void tedFormatFillHeaderFooterChoosers( HeaderFooterTool *	hft,
-				    const HeaderFooterPageResources *	hfpr );
-
-extern void tedFormatFinishHeaderFooterPage( HeaderFooterTool *		hft,
-				    TedFormatTool *			tft,
-				    const HeaderFooterPageResources *	hfpr );
-
-extern void tedFormatToolGetColumnResourceTable(
-					EditApplication *		ea,
-					ColumnPageResources *		cpr,
-					InspectorSubjectResources *	isr );
-
-extern void tedFinishParaLayoutPage(
-				ParagraphLayoutTool *			plt,
-				TedFormatTool *				tft,
-				const ParagraphLayoutPageResources *	plpr );
-
-extern void tedFormatFinishParaOrnamentsPage(
-				ParagraphOrnamentsTool *		pot,
-				TedFormatTool *				tft,
-				const ParagraphOrnamentsPageResources *	popr );
-
-extern int tedFormatToolGetShading(	PropertyMask *		cpSetMask,
-					RowProperties *		rp,
-					int			col0,
-					int			col1,
-					BufferDocument *	bd,
-					ShadingTool *		st );
-
-extern BufferDocument * tedFormatCurDoc(
-					EditDocument **		pEd,
-					EditApplication *	ea );
-
 #   endif	/*  TED_FORMAT_TOOL_H */
