@@ -9,24 +9,26 @@
 #   include	<stdlib.h>
 #   include	<stdio.h>
 #   include	<stddef.h>
+#   include	<string.h>
 #   include	<limits.h>
 
-#   include	<geoString.h>
+#   include	"tedListTool.h"
+#   include	"tedAppFront.h"
+#   include	"tedToolUtil.h"
+#   include	<docTreeType.h>
+#   include	<appUnit.h>
+#   include	<guiWidgetsImpl.h>
+#   include	<guiToolUtil.h>
+#   include	<guiTextUtil.h>
+#   include	<docEditCommand.h>
 
-#   include	"docEvalField.h"
-#   include	"tedApp.h"
-#   include	"tedFormatTool.h"
-
-#   include	"appGuiKeys.h"
+#   include	<appGuiKeys.h>
 
 #   include	<appDebugon.h>
 
 #   ifdef USE_MOTIF
 #	include <Xm/Text.h>
-#	include <Xm/Form.h>
-#	include <Xm/Label.h>
 #	include <Xm/PushB.h>
-#	include <Xm/PushBG.h>
 #	include <Xm/RowColumn.h>
 #   endif
 
@@ -98,7 +100,7 @@ static int tedListToolFormatLevelText(
 				    int *			offsets,
 				    int				maxoffsets,
 				    ListTool *			lt,
-				    const DocumentListLevel *	dll,
+				    const ListLevel *		ll,
 				    int				level )
     {
     int		numberPath[DLmaxLEVELS];
@@ -110,7 +112,7 @@ static int tedListToolFormatLevelText(
 						offsets, maxoffsets,
 						level, numberPath,
 						lt->ltStartPath,
-						lt->ltFormatPath, dll );
+						lt->ltFormatPath, ll );
     if  ( size < 0 )
 	{ listtext[0]= '\0'; return -1;	}
 
@@ -139,9 +141,9 @@ static int tedListToolSelectNumberFormatRange(	ListTool *	lt,
     {
     const DocumentList *	dl= &(lt->ltListPropertiesChosen);
     const int			level= lt->ltCurrentLevel;
-    const DocumentListLevel *	dll= &(dl->dlLevels[level]);
+    const ListLevel *		ll= &(dl->dlLevels[level]);
 
-    const int			fieldCount= dll->dllLevelNumberCount;
+    const int			fieldCount= ll->llLevelNumberCount;
 
     int				idx0;
     int				idx1;
@@ -250,17 +252,15 @@ static void tedListToolSetLevelFormatText(
 #   endif
     }
 
-static void tedListToolRefreshLevelFormat(
-					ListTool *			lt,
-					const DocumentListLevel *	dll,
-					int				level )
+static void tedListToolRefreshLevelFormat(	ListTool *		lt,
+						const ListLevel *	ll,
+						int			level )
     {
     char		listtext[255+1];
-    int			size;
 
-    size= tedListToolFormatLevelText( listtext, sizeof(listtext)- 1,
+    tedListToolFormatLevelText( listtext, sizeof(listtext)- 1,
 				lt->ltNumberFormatOffsets, 2* DLmaxLEVELS+ 2,
-				lt, dll, level );
+				lt, ll, level );
 
     tedListToolSetLevelFormatText( lt, listtext );
 
@@ -283,19 +283,21 @@ static void tedListToolRefreshLevelFormat(
 
 # ifdef USE_MOTIF
 
-static APP_OITEM_CALLBACK_H( tedListFormatLevelChosen, w, voidlt )
+static void tedListFormatLevelChosen(	Widget			w,
+					void *			voidlt,
+					void *			pbcs )
     {
-    ListTool *			lt= (ListTool *)voidlt;
-    DocumentList *		dl= &(lt->ltListPropertiesChosen);
-    int				level= lt->ltCurrentLevel;
-    DocumentListLevel *		dll;
+    ListTool *		lt= (ListTool *)voidlt;
+    DocumentList *	dl= &(lt->ltListPropertiesChosen);
+    int			level= lt->ltCurrentLevel;
+    ListLevel *		ll;
 
-    short			number= -1;
+    short		number= -1;
 
     if  ( level < 0 || level >= dl->dlLevelCount )
 	{ LLDEB(level,dl->dlLevelCount); return;	}
 
-    dll= &(dl->dlLevels[level]);
+    ll= &(dl->dlLevels[level]);
 
 #   ifdef USE_MOTIF
     XtVaGetValues( w,	XmNpositionIndex,	&number,
@@ -413,18 +415,17 @@ static void tedListToolFormatSelectionChanged(
 
 #   endif
 
-static void tedListToolRefreshFormat(
-				ListTool *		lt,
-				const int		level,
-				DocumentListLevel *	dll,
-				int			textAlso )
+static void tedListToolRefreshFormat(	ListTool *	lt,
+					const int	level,
+					ListLevel *	ll,
+					int		textAlso )
     {
     char		listtext[255+1];
     char		listScratch[3+sizeof(listtext)];
 
     tedListToolFormatLevelText( listtext, sizeof(listtext)- 1,
 				lt->ltNumberFormatOffsets, 2* DLmaxLEVELS+ 2,
-				lt, dll, level );
+				lt, ll, level );
 
     if  ( textAlso )
 	{ tedListToolSetLevelFormatText( lt, listtext ); }
@@ -439,7 +440,7 @@ static void tedListToolRefreshFormat(
 
 /************************************************************************/
 
-static int tedListToolModifyConstPiece( DocumentListLevel *	dll,
+static int tedListToolModifyConstPiece( ListLevel *		ll,
 					int			field,
 					int			off0,
 					int			off1,
@@ -452,7 +453,7 @@ static int tedListToolModifyConstPiece( DocumentListLevel *	dll,
     int				shift= off0- off1+ length;
     int				changed= 0;
 
-    size= docListLevelGetText( scratch, sizeof(scratch)- 1, dll, field );
+    size= docListLevelGetText( scratch, sizeof(scratch)- 1, ll, field );
     if  ( size < 0 )
 	{ LLDEB(field,size); return -1; }
 
@@ -461,7 +462,7 @@ static int tedListToolModifyConstPiece( DocumentListLevel *	dll,
 	{ memcpy( scratch+ off0, text, length );	}
     scratch[size+shift]= '\0';
 
-    docListLevelSetText( &changed, dll, scratch, field );
+    docListLevelSetText( &changed, ll, scratch, field );
     return 0;
     }
 
@@ -486,14 +487,14 @@ static int tedListToolModifyFormatText(	ListTool *		lt,
 					const char *		text,
 					int			length )
     {
-    DocumentList *		dl= &(lt->ltListPropertiesChosen);
-    const int			level= lt->ltCurrentLevel;
-    DocumentListLevel *		dll= &(dl->dlLevels[level]);
+    DocumentList *	dl= &(lt->ltListPropertiesChosen);
+    const int		level= lt->ltCurrentLevel;
+    ListLevel *		ll= &(dl->dlLevels[level]);
 
-    int				idx0;
-    int				idx1;
-    int				off0;
-    int				off1;
+    int			idx0;
+    int			idx1;
+    int			off0;
+    int			off1;
 
     /*  1  */
 
@@ -521,7 +522,7 @@ static int tedListToolModifyFormatText(	ListTool *		lt,
     off0 -= lt->ltNumberFormatOffsets[idx0];
     off1 -= lt->ltNumberFormatOffsets[idx0];
 
-    if  ( tedListToolModifyConstPiece( dll, idx0/2,
+    if  ( tedListToolModifyConstPiece( ll, idx0/2,
 						off0, off1, text, length ) )
 	{ LDEB(idx0/2); return -1;	}
 
@@ -536,7 +537,7 @@ static int tedListToolModifyFormatText(	ListTool *		lt,
 	{
 	off1 -= lt->ltNumberFormatOffsets[idx1];
 
-	if  ( tedListToolModifyConstPiece( dll, idx1/2, off0, off1, "", 0 ) )
+	if  ( tedListToolModifyConstPiece( ll, idx1/2, off0, off1, "", 0 ) )
 	    { LDEB(idx1/2); return -1;	}
 
 	idx1--;
@@ -549,7 +550,7 @@ static int tedListToolModifyFormatText(	ListTool *		lt,
     if  ( IS_STRING( idx1 ) )
 	{ idx1--;	}
     while( idx1 >= idx0 )
-	{ docListLevelDeleteNumber( dll, idx1/ 2 ); idx1 -= 2; }
+	{ docListLevelDeleteNumber( ll, idx1/ 2 ); idx1 -= 2; }
 
     return 0;
     }
@@ -570,20 +571,20 @@ static int tedListToolModifyFormatText(	ListTool *		lt,
 static int tedListToolSetFormatLevel(	ListTool *	lt,
 					int		number )
     {
-    DocumentList *		dl= &(lt->ltListPropertiesChosen);
-    int				level= lt->ltCurrentLevel;
-    DocumentListLevel *		dll= &(dl->dlLevels[level]);
+    DocumentList *	dl= &(lt->ltListPropertiesChosen);
+    int			level= lt->ltCurrentLevel;
+    ListLevel *		ll= &(dl->dlLevels[level]);
 
-    int				idx0= lt->ltFormatIndex0;
-    int				idx1= lt->ltFormatIndex1;
-    char			scratch[255+1];
-    int				size;
-    int				split= -1;
+    int			idx0= lt->ltFormatIndex0;
+    int			idx1= lt->ltFormatIndex1;
+    char		scratch[255+1];
+    int			size;
+    int			split= -1;
 
     tedListToolGetSelection( lt->ltNumberFormatText, lt );
 
     /*  1  */
-    size= docListLevelGetText( scratch, sizeof(scratch)- 1, dll, idx0/ 2 );
+    size= docListLevelGetText( scratch, sizeof(scratch)- 1, ll, idx0/ 2 );
     if  ( size < 0 )
 	{ LLDEB(idx0/2,size); return -1; }
 
@@ -597,7 +598,7 @@ static int tedListToolSetFormatLevel(	ListTool *	lt,
 	    int		off1;
 
 	    size= docListLevelGetText( scratch+ split,
-			    sizeof(scratch)- split- 1, dll, idx1/ 2 );
+			    sizeof(scratch)- split- 1, ll, idx1/ 2 );
 	    if  ( size < 0 )
 		{ LLDEB(idx1/2,size); return -1; }
 
@@ -607,7 +608,7 @@ static int tedListToolSetFormatLevel(	ListTool *	lt,
 	    }
 	else{
 	    size= docListLevelGetText( scratch+ split,
-			    sizeof(scratch)- split- 1, dll, idx1/ 2+ 1 );
+			    sizeof(scratch)- split- 1, ll, idx1/ 2+ 1 );
 	    if  ( size < 0 )
 		{ LLDEB(idx1/2+ 1,size); return -1; }
 	    }
@@ -617,20 +618,20 @@ static int tedListToolSetFormatLevel(	ListTool *	lt,
     tedListToolModifyFormatText( lt, "", 0 );
 
     /*  3  */
-    docListLevelInsertNumber( dll, number, idx0/ 2 );
+    docListLevelInsertNumber( ll, number, idx0/ 2 );
 
     /*  4  */
     if  ( split >= 0 )
 	{
 	int	changed= 1;
 
-	docListLevelSetText( &changed, dll, scratch+ split, idx0/ 2+ 1 );
+	docListLevelSetText( &changed, ll, scratch+ split, idx0/ 2+ 1 );
 	scratch[split]= '\0';
-	docListLevelSetText( &changed, dll, scratch       , idx0/ 2 );
+	docListLevelSetText( &changed, ll, scratch       , idx0/ 2 );
 	}
 
     /*  5  */
-    tedListToolRefreshFormat( lt, level, dll, 1 );
+    tedListToolRefreshFormat( lt, level, ll, 1 );
 
     tedListToolSelectNumberFormatRange( lt,
 				    lt->ltNumberFormatOffsets[idx0+2],
@@ -657,13 +658,13 @@ static void tedListToolReplaceText(	ListTool *		lt,
 					const char *		text,
 					int			length )
     {
-    DocumentList *		dl= &(lt->ltListPropertiesChosen);
-    const int			level= lt->ltCurrentLevel;
-    DocumentListLevel *		dll= &(dl->dlLevels[level]);
+    DocumentList *	dl= &(lt->ltListPropertiesChosen);
+    const int		level= lt->ltCurrentLevel;
+    ListLevel *		ll= &(dl->dlLevels[level]);
 
     tedListToolModifyFormatText( lt, text, length );
 
-    tedListToolRefreshFormat( lt, level, dll, 0 );
+    tedListToolRefreshFormat( lt, level, ll, 0 );
 
     tedListToolSelectNumberFormatRange( lt, lt->ltFormatOffset0,
 						lt->ltFormatOffset0+ length );
@@ -859,7 +860,7 @@ static void tedListToolSetLevelHeader(		ListTool *	lt,
 	}
 
     scratch= to= malloc( size+ 1 );
-    if  ( ! scratch )
+    if  ( ! scratch || ! to )
 	{ LXDEB(size,scratch); return; }
 
     from= lpr->lprListLevel;
@@ -882,20 +883,20 @@ static void tedListToolSetLevelHeader(		ListTool *	lt,
     }
 
 
-static void tedListToolRefreshIndents(	ListTool *			lt,
-					const DocumentListLevel *	dll )
+static void tedListToolRefreshIndents(	ListTool *		lt,
+					const ListLevel *	ll )
     {
     appLengthToTextWidget( lt->ltFirstIndentText,
-	    dll->dllLeftIndentTwips+ dll->dllFirstIndentTwips, UNITtyPOINTS );
+	    ll->llLeftIndentTwips+ ll->llFirstIndentTwips, UNITtyPOINTS );
 
     appLengthToTextWidget( lt->ltLeftIndentText,
-	    dll->dllLeftIndentTwips, UNITtyPOINTS );
+	    ll->llLeftIndentTwips, UNITtyPOINTS );
     }
 
 static void tedListToolRefreshCurrentLevel(	ListTool *	lt )
     {
     const DocumentList *	dl= &(lt->ltListPropertiesChosen);
-    const DocumentListLevel *	dll;
+    const ListLevel *		ll;
     int				level= lt->ltCurrentLevel;
 
     int				i;
@@ -919,26 +920,26 @@ static void tedListToolRefreshCurrentLevel(	ListTool *	lt )
 
     tedListToolSetCurrentLevelPath( lt->ltCurrPath, lt->ltCurrentLevel, lt );
 
-    dll= &(dl->dlLevels[level]);
+    ll= &(dl->dlLevels[level]);
 
-    tedListToolRefreshIndents( lt, dll );
+    tedListToolRefreshIndents( lt, ll );
 
-    appIntegerToTextWidget( lt->ltStartAtText, dll->dllStartAt );
+    appIntegerToTextWidget( lt->ltStartAtText, ll->llStartAt );
 
     for ( i= 0; i < LISTTOOLcountSTYLES; i++ )
 	{
-	if  ( dll->dllNumberStyle == TED_ListToolStyles[i] )
+	if  ( ll->llNumberStyle == TED_ListToolStyles[i] )
 	    { break;	}
 	}
     if  ( i >= LISTTOOLcountSTYLES )
 	{ i= -1;	}
 
     appSetOptionmenu( &(lt->ltNumberStyleOptionmenu), i );
-    appSetOptionmenu( &(lt->ltJustifyOptionmenu), dll->dllJustification );
-    appSetOptionmenu( &(lt->ltFollowOptionmenu), dll->dllFollow );
+    appSetOptionmenu( &(lt->ltJustifyOptionmenu), ll->llJustification );
+    appSetOptionmenu( &(lt->ltFollowOptionmenu), ll->llFollow );
 
     /**/
-    tedListToolRefreshLevelFormat( lt, dll, level );
+    tedListToolRefreshLevelFormat( lt, ll, level );
 
     return;
     }
@@ -992,18 +993,18 @@ static void tedFormatToolRefreshListPage(	ListTool *	lt )
 	char			listtext[255+1];
 	char			listScratch[3+sizeof(listtext)];
 
-	const DocumentListLevel *	dll;
-	int				level;
+	const ListLevel *	ll;
+	int			level;
 
 	docListGetFormatPath( lt->ltStartPath, lt->ltFormatPath,
-					&dll, dl->dlLevelCount- 1, dl, lo );
+					&ll, dl->dlLevelCount- 1, dl, lo );
 
-	dll= dl->dlLevels;
-	for ( level= 0; level < dl->dlLevelCount; dll++, level++ )
+	ll= dl->dlLevels;
+	for ( level= 0; level < dl->dlLevelCount; ll++, level++ )
 	    {
 	    tedListToolFormatLevelText( listtext, sizeof(listtext)- 1,
 							    (int *)0, 0,
-							    lt, dll, level );
+							    lt, ll, level );
 
 	    sprintf( listScratch, "%d: %s", level+ 1, listtext );
 
@@ -1017,9 +1018,24 @@ static void tedFormatToolRefreshListPage(	ListTool *	lt )
     return;
     }
 
+/************************************************************************/
+
+static void tedListEnableListLevel(	ListTool *	lt,
+					int		enabled )
+    {
+    guiEnableWidget( lt->ltListLevelFrame, enabled );
+
+    guiEnableText( lt->ltNumberFormatText, enabled );
+    guiEnableText( lt->ltFirstIndentText, enabled );
+    guiEnableText( lt->ltLeftIndentText, enabled );
+    guiEnableText( lt->ltStartAtText, enabled );
+
+    return;
+    }
+
 /************************************************************************/
 /*									*/
-/*  Adapt the tabs tool to the current selection in the document.	*/
+/*  Adapt the lists tool to the current selection in the document.	*/
 /*									*/
 /************************************************************************/
 
@@ -1047,12 +1063,12 @@ static void tedFormatToolNoList(	ListTool *		lt,
     lt->ltFormatOffset1= -1;
     lt->ltCurrentParagraphNumber= -1;
 
-    appGuiEnableWidget( lt->ltRemoveFromListButton, 0 );
-    appGuiEnableWidget( is->isApplyButton, 0 );
-    appGuiEnableWidget( is->isRevertButton, 0 );
+    guiEnableWidget( lt->ltRemoveFromListButton, 0 );
+    guiEnableWidget( is->isApplyButton, 0 );
+    guiEnableWidget( is->isRevertButton, 0 );
 
-    appGuiEnableWidget( lt->ltListLevelFrame, 0 );
-    appGuiEnableWidget( lt->ltSetLevelButton, 0 );
+    tedListEnableListLevel( lt, 0 );
+    guiEnableWidget( lt->ltSetLevelButton, 0 );
 
     return;
     }
@@ -1066,21 +1082,14 @@ static int tedFormatToolSetList(	ListTool *			lt,
 					DocumentList *			dl,
 					ListNumberTreeNode *		root )
     {
-    const int * const	fontMap= (const int *)0;
-    const int * const	colorMap= (const int *)0;
-
-    if  ( docCopyDocumentList( &(lt->ltListPropertiesSet), dl,
-							fontMap, colorMap ) )
+    if  ( docCopyDocumentListSameDocument( &(lt->ltListPropertiesSet), dl ) )
 	{ LDEB(1); return -1;	}
-    if  ( docCopyDocumentList( &(lt->ltListPropertiesChosen), dl,
-							fontMap, colorMap ) )
+    if  ( docCopyDocumentListSameDocument( &(lt->ltListPropertiesChosen), dl ) )
 	{ LDEB(1); return -1;	}
 
-    if  ( docCopyListOverride( &(lt->ltListOverrideSet), lo,
-							fontMap, colorMap ) )
+    if  ( docCopyListOverrideSameDocument( &(lt->ltListOverrideSet), lo ) )
 	{ LDEB(1); return -1;	}
-    if  ( docCopyListOverride( &(lt->ltListOverrideChosen), lo,
-							fontMap, colorMap ) )
+    if  ( docCopyListOverrideSameDocument( &(lt->ltListOverrideChosen), lo ) )
 	{ LDEB(1); return -1;	}
 
     lt->ltHereLevel= level;
@@ -1110,12 +1119,14 @@ static int tedFormatToolSetList(	ListTool *			lt,
 	lt->ltPrevLevel= -1;
 	}
 
-    appGuiEnableWidget( lt->ltRemoveFromListButton, 1 );
-    appGuiEnableWidget( is->isApplyButton, 1 );
-    appGuiEnableWidget( is->isRevertButton, 1 );
+    guiEnableWidget( lt->ltRemoveFromListButton, lt->ltCanUpdateSelection );
 
-    appGuiEnableWidget( lt->ltListLevelFrame, 1 );
-    appGuiEnableWidget( lt->ltSetLevelButton, 1 );
+    guiEnableWidget( is->isApplyButton, lt->ltCanUpdateList );
+    guiEnableWidget( is->isRevertButton, lt->ltCanUpdateList );
+
+    tedListEnableListLevel( lt, lt->ltCanUpdateList );
+
+    guiEnableWidget( lt->ltSetLevelButton, lt->ltCanUpdateSelection );
 
     return 0;
     }
@@ -1134,7 +1145,8 @@ void tedRefreshListTool(
 				InspectorSubject *		is,
 				const DocumentSelection *	ds,
 				const SelectionDescription *	sd,
-				BufferDocument *		bd )
+				BufferDocument *		bd,
+				const unsigned char *		cmdEnabled )
     {
     ListOverride *			lo;
     DocumentList *			dl;
@@ -1142,6 +1154,8 @@ void tedRefreshListTool(
 
     int					i;
 
+    lt->ltInProgrammaticChange++;
+
     for ( i= 0; i < DLmaxLEVELS; i++ )
 	{
 	lt->ltPrevPath[i]= 0;
@@ -1156,7 +1170,10 @@ void tedRefreshListTool(
     lt->ltFormatOffset0= -1;
     lt->ltFormatOffset1= -1;
 
-    if  ( ds->dsSelectionScope.ssInExternalItem != DOCinBODY	||
+    lt->ltCanUpdateSelection= cmdEnabled[EDITcmdUPD_PARA_PROPS];
+    lt->ltCanUpdateList= cmdEnabled[EDITcmdUPD_LIST];
+
+    if  ( ds->dsSelectionScope.ssTreeType != DOCinBODY		||
 	  ! sd->sdHasLists					||
 	  sd->sdListOverride < 1				||
 	  docGetListOfParagraph( &lo, &dl,
@@ -1165,24 +1182,19 @@ void tedRefreshListTool(
     else{
 	ListNumberTreeNode *		root;
 
-	root= docGetListNumberTree( &(bd->bdBody.eiListNumberTrees),
+	root= docGetListNumberTree( &(bd->bdBody.dtListNumberTrees),
 							sd->sdListOverride );
 	if  ( ! root )
-	    { LXDEB(sd->sdListOverride,root); *pEnabled= 0; return;	}
+	    { LXDEB(sd->sdListOverride,root); *pEnabled= 0; goto ready;	}
 
 	if  ( tedFormatToolSetList( lt, is, sd->sdFirstListParaNr,
 			sd->sdListOverride, sd->sdListLevel, lo, dl, root ) )
-	    { LDEB(sd->sdFirstListParaNr); return;	}
+	    { LDEB(sd->sdFirstListParaNr); goto ready;	}
 
 	lt->ltTabIntervalTwips= dp->dpTabIntervalTwips;
 	}
 
-    if  ( sd->sdListOverride > 0 && sd->sdMultiList )
-	{ appGuiEnableWidget( lt->ltSetListButton, 1 );	}
-    else{ appGuiEnableWidget( lt->ltSetListButton, 0 );	}
-
     /**/
-
     if  ( lt->ltCurrentLevel < 0					||
 	  lt->ltCurrentLevel >= lt->ltListPropertiesChosen.dlLevelCount	)
 	{
@@ -1191,9 +1203,31 @@ void tedRefreshListTool(
 	else{ lt->ltCurrentLevel= -1;	}
 	}
 
+    if  ( lt->ltCanUpdateSelection		&&
+	  sd->sdListOverride > 0		&&
+	  sd->sdMultiList			)
+	{ guiEnableWidget( lt->ltSetListButton, 1 );	}
+    else{ guiEnableWidget( lt->ltSetListButton, 0 );	}
+
+    guiEnableWidget( lt->ltSelectionFrame, lt->ltCanUpdateSelection );
+
+    guiEnableWidget( lt->ltRemoveFromListButton,
+				    lt->ltCanUpdateSelection	&&
+				    sd->sdListOverride > 0	);
+    guiEnableWidget( lt->ltSetLevelButton,
+				    lt->ltCanUpdateSelection	&&
+				    sd->sdListOverride > 0	);
+
+    tedListEnableListLevel( lt, lt->ltCanUpdateList );
+    guiEnableWidget( lt->ltNewListButton, cmdEnabled[EDITcmdSET_NEW_LIST] );
+
     tedFormatToolRefreshListPage( lt );
 
-    *pEnabled= ! sd->sdDocumentReadonly && ds->dsSelectionScope.ssInExternalItem == DOCinBODY;
+    *pEnabled= ( sd->sdInTreeType == DOCinBODY );
+
+  ready:
+
+    lt->ltInProgrammaticChange--;
 
     return;
     }
@@ -1306,15 +1340,12 @@ static APP_BUTTON_CALLBACK_H( tedFormatListRevertPushed, w, voidlt )
     {
     ListTool *			lt= (ListTool *)voidlt;
 
-    const int * const		fontMap= (const int *)0;
-    const int * const		colorMap= (const int *)0;
-
-    if  ( docCopyDocumentList( &(lt->ltListPropertiesChosen),
-			    &(lt->ltListPropertiesSet), fontMap, colorMap ) )
+    if  ( docCopyDocumentListSameDocument( &(lt->ltListPropertiesChosen),
+						&(lt->ltListPropertiesSet) ) )
 	{ LDEB(1); return;	}
 
-    if  ( docCopyListOverride( &(lt->ltListOverrideChosen),
-			    &(lt->ltListOverrideSet), fontMap, colorMap ) )
+    if  ( docCopyListOverrideSameDocument( &(lt->ltListOverrideChosen),
+						&(lt->ltListOverrideSet) ) )
 	{ LDEB(1); return;	}
 
     tedFormatToolRefreshListPage( lt );
@@ -1328,8 +1359,8 @@ static APP_BUTTON_CALLBACK_H( tedFormatListRevertPushed, w, voidlt )
 /*									*/
 /************************************************************************/
 
-static int tedListToolGetLevelAttributes(	ListTool *		lt,
-						DocumentListLevel *	dll )
+static int tedListToolGetLevelAttributes(	ListTool *	lt,
+						ListLevel *	ll )
     {
     int				li;
     int				lipfi;
@@ -1339,33 +1370,33 @@ static int tedListToolGetLevelAttributes(	ListTool *		lt,
     const int			adaptToMax= 0;
 
     /**/
-    lipfi= dll->dllLeftIndentTwips+ dll->dllFirstIndentTwips;
+    lipfi= ll->llLeftIndentTwips+ ll->llFirstIndentTwips;
     if  ( appGetLengthFromTextWidget( lt->ltFirstIndentText,
 					&lipfi, &changed, UNITtyPOINTS,
 					INT_MIN, 0, maxValue, adaptToMax ) )
 	{ return -1;	}
 
-    li= dll->dllLeftIndentTwips;
+    li= ll->llLeftIndentTwips;
     if  ( appGetLengthFromTextWidget( lt->ltLeftIndentText,
 					&li, &changed, UNITtyPOINTS,
 					0, 0, maxValue, adaptToMax ) )
 	{ return -1;	}
 
-    if  ( dll->dllLeftIndentTwips != li )
+    if  ( ll->llLeftIndentTwips != li )
 	{
-	dll->dllLeftIndentTwips= li;
-	PROPmaskADD( &(dll->dllParaPropertyMask), PPpropLEFT_INDENT );
+	ll->llLeftIndentTwips= li;
+	PROPmaskADD( &(ll->llParaPropertyMask), PPpropLEFT_INDENT );
 	}
-    if  ( dll->dllFirstIndentTwips != lipfi- li )
+    if  ( ll->llFirstIndentTwips != lipfi- li )
 	{
-	dll->dllFirstIndentTwips= lipfi- li;
-	PROPmaskADD( &(dll->dllParaPropertyMask), PPpropFIRST_INDENT );
+	ll->llFirstIndentTwips= lipfi- li;
+	PROPmaskADD( &(ll->llParaPropertyMask), PPpropFIRST_INDENT );
 	}
 
 
     /**/
     if  ( appGetIntegerFromTextWidget( lt->ltStartAtText,
-				    &(dll->dllStartAt), 1, 0, INT_MAX, 0 ) )
+				    &(ll->llStartAt), 1, 0, INT_MAX, 0 ) )
 	{ return -1;	}
 
     return 0;
@@ -1384,6 +1415,9 @@ static APP_LIST_CALLBACK_H( tedListToolLevelChosen, w, voidlt, voidlcs )
 
     int			level;
 
+    if  ( lt->ltInProgrammaticChange )
+	{ return;	}
+
     level= appGuiGetPositionFromListCallback( w, voidlcs );
 
     if  ( level == lt->ltCurrentLevel )
@@ -1412,19 +1446,19 @@ static APP_LIST_CALLBACK_H( tedListToolLevelChosen, w, voidlt, voidlcs )
 
 static APP_BUTTON_CALLBACK_H( tedFormatChangeList, w, voidlt )
     {
-    ListTool *			lt= (ListTool *)voidlt;
-    EditApplication *		ea= lt->ltApplication;
-    DocumentList *		dl= &(lt->ltListPropertiesChosen);
+    ListTool *		lt= (ListTool *)voidlt;
+    EditApplication *	ea= lt->ltApplication;
+    DocumentList *	dl= &(lt->ltListPropertiesChosen);
 
-    int				level= lt->ltCurrentLevel;
-    DocumentListLevel *		dll;
+    int			level= lt->ltCurrentLevel;
+    ListLevel *		ll;
 
     if  ( level < 0 || level >= dl->dlLevelCount )
 	{ LLDEB(level,dl->dlLevelCount); return;	}
 
-    dll= &(dl->dlLevels[level]);
+    ll= &(dl->dlLevels[level]);
 
-    if  ( tedListToolGetLevelAttributes( lt, dll ) )
+    if  ( tedListToolGetLevelAttributes( lt, ll ) )
 	{ return;	}
 
     if  ( tedAppChangeCurrentList( ea, dl ) )
@@ -1440,97 +1474,91 @@ static APP_BUTTON_CALLBACK_H( tedFormatChangeList, w, voidlt )
 /*									*/
 /************************************************************************/
 
-static APP_OITEM_CALLBACK_H( tedListNumberStyleChosen, w, voidlt )
+static void tedListNumberStyleChosen(	int		style,
+					void *		voidlt )
     {
-    ListTool *			lt= (ListTool *)voidlt;
-    DocumentList *		dl= &(lt->ltListPropertiesChosen);
-    int				level= lt->ltCurrentLevel;
-    DocumentListLevel *		dll;
-
-    int				style;
+    ListTool *		lt= (ListTool *)voidlt;
+    DocumentList *	dl= &(lt->ltListPropertiesChosen);
+    int			level= lt->ltCurrentLevel;
+    ListLevel *		ll;
 
     if  ( level < 0 || level >= dl->dlLevelCount )
 	{ LLDEB(level,dl->dlLevelCount); return;	}
 
-    dll= &(dl->dlLevels[level]);
+    ll= &(dl->dlLevels[level]);
 
-    style= appGuiGetOptionmenuItemIndex( &(lt->ltNumberStyleOptionmenu), w );
     if  ( style < 0 || style >= LISTTOOLcountSTYLES )
 	{ LLDEB(style,LISTTOOLcountSTYLES); return;	}
 
-    dll->dllNumberStyle= TED_ListToolStyles[style];
+    ll->llNumberStyle= TED_ListToolStyles[style];
 
     tedFormatToolRefreshListPage( lt );
 
     return;
     }
 
-static APP_OITEM_CALLBACK_H( tedListJustifyChosen, w, voidlt )
+static void tedListJustifyChosen(	int		justify,
+					void *		voidlt )
     {
-    ListTool *			lt= (ListTool *)voidlt;
-    DocumentList *		dl= &(lt->ltListPropertiesChosen);
-    int				level= lt->ltCurrentLevel;
-    DocumentListLevel *		dll;
-
-    int				justify;
+    ListTool *		lt= (ListTool *)voidlt;
+    DocumentList *	dl= &(lt->ltListPropertiesChosen);
+    int			level= lt->ltCurrentLevel;
+    ListLevel *		ll;
 
     if  ( level < 0 || level >= dl->dlLevelCount )
 	{ LLDEB(level,dl->dlLevelCount); return;	}
 
-    dll= &(dl->dlLevels[level]);
+    ll= &(dl->dlLevels[level]);
 
-    justify= appGuiGetOptionmenuItemIndex( &(lt->ltJustifyOptionmenu), w );
     if  ( justify < 0 || justify >= DOClla_COUNT )
 	{ LLDEB(justify,DOClla_COUNT); return;	}
 
-    dll->dllJustification= justify;
+    ll->llJustification= justify;
 
-    if  ( dll->dllJustification == DOCllaCENTER		||
-	  dll->dllJustification == DOCllaRIGHT		)
+    if  ( ll->llJustification == DOCllaCENTER		||
+	  ll->llJustification == DOCllaRIGHT		)
 	{
 	int		refresh= 0;
 
-	if  ( dll->dllLeftIndentTwips < 20 )
+	if  ( ll->llLeftIndentTwips < 20 )
 	    {
-	    dll->dllLeftIndentTwips= lt->ltTabIntervalTwips;
-	    PROPmaskADD( &(dll->dllParaPropertyMask), PPpropLEFT_INDENT );
+	    ll->llLeftIndentTwips= lt->ltTabIntervalTwips;
+	    PROPmaskADD( &(ll->llParaPropertyMask), PPpropLEFT_INDENT );
 	    refresh= 1;
 	    }
 
-	if  ( dll->dllLeftIndentTwips+ dll->dllFirstIndentTwips < 20	&&
-	      dll->dllLeftIndentTwips- lt->ltTabIntervalTwips/ 2 >= 20	)
+	if  ( ll->llLeftIndentTwips+ ll->llFirstIndentTwips < 20	&&
+	      ll->llLeftIndentTwips- lt->ltTabIntervalTwips/ 2 >= 20	)
 	    {
-	    dll->dllFirstIndentTwips= -lt->ltTabIntervalTwips/ 2;
-	    PROPmaskADD( &(dll->dllParaPropertyMask), PPpropFIRST_INDENT );
+	    ll->llFirstIndentTwips= -lt->ltTabIntervalTwips/ 2;
+	    PROPmaskADD( &(ll->llParaPropertyMask), PPpropFIRST_INDENT );
 	    refresh= 1;
 	    }
 
 	if  ( refresh )
-	    { tedListToolRefreshIndents( lt, dll );	}
+	    { tedListToolRefreshIndents( lt, ll );	}
 	}
 
     return;
     }
 
-static APP_OITEM_CALLBACK_H( tedListFollowChosen, w, voidlt )
+static void tedListFollowChosen(	int		follow,
+					void *		voidlt )
     {
-    ListTool *			lt= (ListTool *)voidlt;
-    DocumentList *		dl= &(lt->ltListPropertiesChosen);
-    int				level= lt->ltCurrentLevel;
-    DocumentListLevel *		dll;
-
-    int				follow;
+    ListTool *		lt= (ListTool *)voidlt;
+    DocumentList *	dl= &(lt->ltListPropertiesChosen);
+    int			level= lt->ltCurrentLevel;
+    ListLevel *		ll;
 
     if  ( level < 0 || level >= dl->dlLevelCount )
 	{ LLDEB(level,dl->dlLevelCount); return;	}
 
-    dll= &(dl->dlLevels[level]);
+    ll= &(dl->dlLevels[level]);
 
-    follow= appGuiGetOptionmenuItemIndex( &(lt->ltFollowOptionmenu), w );
     if  ( follow < 0 || follow >= DOCllf_COUNT )
 	{ LLDEB(follow,DOCllf_COUNT); return;	}
 
-    dll->dllFollow= follow;
+    ll->llFollow= follow;
 
     return;
     }
@@ -1543,18 +1571,18 @@ static APP_OITEM_CALLBACK_H( tedListFollowChosen, w, voidlt )
 
 static APP_TXACTIVATE_CALLBACK_H( tedLevelStartAtChanged, w, voidlt )
     {
-    ListTool *			lt= (ListTool *)voidlt;
-    DocumentList *		dl= &(lt->ltListPropertiesChosen);
-    int				level= lt->ltCurrentLevel;
-    DocumentListLevel *		dll;
+    ListTool *		lt= (ListTool *)voidlt;
+    DocumentList *	dl= &(lt->ltListPropertiesChosen);
+    int			level= lt->ltCurrentLevel;
+    ListLevel *		ll;
 
     if  ( level < 0 || level >= dl->dlLevelCount )
 	{ LLDEB(level,dl->dlLevelCount); return;	}
 
-    dll= &(dl->dlLevels[level]);
+    ll= &(dl->dlLevels[level]);
 
     if  ( appGetIntegerFromTextWidget( lt->ltStartAtText,
-				    &(dll->dllStartAt), 1, 0, INT_MAX, 0 ) )
+				    &(ll->llStartAt), 1, 0, INT_MAX, 0 ) )
 	{ return;	}
 
     tedFormatToolRefreshListPage( lt );
@@ -1564,10 +1592,10 @@ static APP_TXACTIVATE_CALLBACK_H( tedLevelStartAtChanged, w, voidlt )
 
 static APP_TXACTIVATE_CALLBACK_H( tedLevelFirstIndentChanged, w, voidlt )
     {
-    ListTool *			lt= (ListTool *)voidlt;
-    DocumentList *		dl= &(lt->ltListPropertiesChosen);
-    int				level= lt->ltCurrentLevel;
-    DocumentListLevel *		dll;
+    ListTool *		lt= (ListTool *)voidlt;
+    DocumentList *	dl= &(lt->ltListPropertiesChosen);
+    int			level= lt->ltCurrentLevel;
+    ListLevel *		ll;
 
     int				li;
     int				lipfi;
@@ -1576,24 +1604,24 @@ static APP_TXACTIVATE_CALLBACK_H( tedLevelFirstIndentChanged, w, voidlt )
     if  ( level < 0 || level >= dl->dlLevelCount )
 	{ LLDEB(level,dl->dlLevelCount); return;	}
 
-    dll= &(dl->dlLevels[level]);
+    ll= &(dl->dlLevels[level]);
 
-    li= dll->dllLeftIndentTwips;
-    lipfi=  dll->dllLeftIndentTwips+ dll->dllFirstIndentTwips;
+    li= ll->llLeftIndentTwips;
+    lipfi=  ll->llLeftIndentTwips+ ll->llFirstIndentTwips;
 
     if  ( tedFormatValidateDimension( &lipfi, &changed,
 					    lt->ltFirstIndentText, lipfi ) )
 	{ return;	}
 
-    if  ( dll->dllLeftIndentTwips != li )
+    if  ( ll->llLeftIndentTwips != li )
 	{
-	dll->dllLeftIndentTwips= li;
-	PROPmaskADD( &(dll->dllParaPropertyMask), PPpropLEFT_INDENT );
+	ll->llLeftIndentTwips= li;
+	PROPmaskADD( &(ll->llParaPropertyMask), PPpropLEFT_INDENT );
 	}
-    if  ( dll->dllFirstIndentTwips != lipfi- li )
+    if  ( ll->llFirstIndentTwips != lipfi- li )
 	{
-	dll->dllFirstIndentTwips= lipfi- li;
-	PROPmaskADD( &(dll->dllParaPropertyMask), PPpropFIRST_INDENT );
+	ll->llFirstIndentTwips= lipfi- li;
+	PROPmaskADD( &(ll->llParaPropertyMask), PPpropFIRST_INDENT );
 	}
 
     return;
@@ -1601,36 +1629,36 @@ static APP_TXACTIVATE_CALLBACK_H( tedLevelFirstIndentChanged, w, voidlt )
 
 static APP_TXACTIVATE_CALLBACK_H( tedLevelLeftIndentChanged, w, voidlt )
     {
-    ListTool *			lt= (ListTool *)voidlt;
-    DocumentList *		dl= &(lt->ltListPropertiesChosen);
-    int				level= lt->ltCurrentLevel;
-    DocumentListLevel *		dll;
+    ListTool *		lt= (ListTool *)voidlt;
+    DocumentList *	dl= &(lt->ltListPropertiesChosen);
+    int			level= lt->ltCurrentLevel;
+    ListLevel *		ll;
 
-    int				li;
-    int				lipfi;
-    int				changed;
+    int			li;
+    int			lipfi;
+    int			changed;
 
     if  ( level < 0 || level >= dl->dlLevelCount )
 	{ LLDEB(level,dl->dlLevelCount); return;	}
 
-    dll= &(dl->dlLevels[level]);
+    ll= &(dl->dlLevels[level]);
 
-    li= dll->dllLeftIndentTwips;
-    lipfi=  dll->dllLeftIndentTwips+ dll->dllFirstIndentTwips;
+    li= ll->llLeftIndentTwips;
+    lipfi= ll->llLeftIndentTwips+ ll->llFirstIndentTwips;
 
     if  ( tedFormatValidateDimension( &li, &changed,
 						lt->ltLeftIndentText, li ) )
 	{ return;	}
 
-    if  ( dll->dllLeftIndentTwips != li )
+    if  ( ll->llLeftIndentTwips != li )
 	{
-	dll->dllLeftIndentTwips= li;
-	PROPmaskADD( &(dll->dllParaPropertyMask), PPpropLEFT_INDENT );
+	ll->llLeftIndentTwips= li;
+	PROPmaskADD( &(ll->llParaPropertyMask), PPpropLEFT_INDENT );
 	}
-    if  ( dll->dllFirstIndentTwips != lipfi- li )
+    if  ( ll->llFirstIndentTwips != lipfi- li )
 	{
-	dll->dllFirstIndentTwips= lipfi- li;
-	PROPmaskADD( &(dll->dllParaPropertyMask), PPpropFIRST_INDENT );
+	ll->llFirstIndentTwips= lipfi- li;
+	PROPmaskADD( &(ll->llParaPropertyMask), PPpropFIRST_INDENT );
 	}
 
     return;
@@ -1642,13 +1670,12 @@ static APP_TXACTIVATE_CALLBACK_H( tedLevelLeftIndentChanged, w, voidlt )
 
 static APP_EVENT_HANDLER_H( tedListToolNumberKeyPress, w, voidlt, event )
     {
-    ListTool *			lt= (ListTool *)voidlt;
-    DocumentList *		dl= &(lt->ltListPropertiesChosen);
-    int				level= lt->ltCurrentLevel;
-    DocumentListLevel *		dll;
+    ListTool *		lt= (ListTool *)voidlt;
+    DocumentList *	dl= &(lt->ltListPropertiesChosen);
+    int			level= lt->ltCurrentLevel;
 
-    APP_KEY_VALUE		keySym;
-    unsigned int		state;
+    APP_KEY_VALUE	keySym;
+    unsigned int	state;
 
 #   ifdef USE_MOTIF
     int		refused= *pRefused;
@@ -1660,8 +1687,6 @@ static APP_EVENT_HANDLER_H( tedListToolNumberKeyPress, w, voidlt, event )
     if  ( level < 0 || level >= dl->dlLevelCount )
 	{ LLDEB(level,dl->dlLevelCount); return;	}
 
-    dll= &(dl->dlLevels[level]);
-
 #   ifdef USE_MOTIF
     {
     XKeyPressedEvent *	keyEvent= &(event->xkey);
@@ -1734,8 +1759,7 @@ LDEB(1);
 	case KEY_KP_1:
 	    if  ( ( state & KEY_CONTROL_MASK ) )
 		{
-		if  ( level >= 0 )
-		    { tedListToolSetFormatLevel( lt, 0 );	}
+		tedListToolSetFormatLevel( lt, 0 );
 
 		refused= 0;
 		}
@@ -1904,12 +1928,14 @@ void tedFormatFillListsPage(	ListTool *			lt,
 
     APP_WIDGET		row;
 
-    const int		visibleItems= 9;
+    const int		visibleItems= 4;
     const int		textColumns= 10;
 
     /**/
     lt->ltPageResources= lpr;
 
+    lt->ltInProgrammaticChange= 0;
+
     /**/
     docInitDocumentList( &(lt->ltListPropertiesSet) );
     docInitDocumentList( &(lt->ltListPropertiesChosen) );
@@ -1931,13 +1957,13 @@ void tedFormatFillListsPage(	ListTool *			lt,
 				    &(lt->ltSelectionPaned),
 				    pageWidget, lpr->lprSelection );
 
-    appInspectorMakeButtonRow( &row, lt->ltSelectionPaned,
+    guiToolMake2BottonRow( &row, lt->ltSelectionPaned,
 		    &(lt->ltSetListButton), &(lt->ltRemoveFromListButton),
 		    lpr->lprSetList, lpr->lprRemoveFromList,
 		    tedFormatListSetListPushed,
 		    tedFormatListRemoveFromListPushed, lt );
 
-    appInspectorMakeButtonRow( &row, lt->ltSelectionPaned,
+    guiToolMake2BottonRow( &row, lt->ltSelectionPaned,
 		    &(lt->ltSetLevelButton), &(lt->ltNewListButton),
 		    lpr->lprSetLevel, lpr->lprNewList,
 		    tedFormatListSetLevelPushed,
@@ -1949,12 +1975,13 @@ void tedFormatFillListsPage(	ListTool *			lt,
 				    pageWidget, lpr->lprListLevel );
 
     /**/
-    appInspectorMakeMenuRow( &row, &(lt->ltNumberStyleOptionmenu),
+    guiToolMakeLabelAndMenuRow( &row, &(lt->ltNumberStyleOptionmenu),
 				    &styleLabel, lt->ltListLevelPaned,
-				    lpr->lprNumberStyle );
+				    lpr->lprNumberStyle,
+				    tedListNumberStyleChosen, (void *)lt );
 
     /**/
-    appMakeLabelAndTextRow( &row, &(lt->ltFormatLabel),
+    guiToolMakeLabelAndTextRow( &row, &(lt->ltFormatLabel),
 				    &(lt->ltNumberFormatText),
 				    lt->ltListLevelPaned,
 				    lpr->lprNumberFormat, textColumns, 1 );
@@ -2019,14 +2046,14 @@ void tedFormatFillListsPage(	ListTool *			lt,
 # endif
 
     /**/
-    appMakeLabelAndTextRow( &row, &firstLabel, &(lt->ltFirstIndentText),
+    guiToolMakeLabelAndTextRow( &row, &firstLabel, &(lt->ltFirstIndentText),
 				    lt->ltListLevelPaned,
 				    lpr->lprLevelFirstIndent, textColumns, 1 );
 
     appGuiSetGotValueCallbackForText( lt->ltFirstIndentText,
 				    tedLevelFirstIndentChanged, (void *)lt );
     /**/
-    appMakeLabelAndTextRow( &row, &leftLabel, &(lt->ltLeftIndentText),
+    guiToolMakeLabelAndTextRow( &row, &leftLabel, &(lt->ltLeftIndentText),
 				    lt->ltListLevelPaned,
 				    lpr->lprLevelLeftIndent, textColumns, 1 );
 
@@ -2034,22 +2061,24 @@ void tedFormatFillListsPage(	ListTool *			lt,
 				    tedLevelLeftIndentChanged, (void *)lt );
 
     /**/
-    appMakeLabelAndTextRow( &row, &startLabel, &(lt->ltStartAtText),
+    guiToolMakeLabelAndTextRow( &row, &startLabel, &(lt->ltStartAtText),
 				    lt->ltListLevelPaned,
 				    lpr->lprStartAt, textColumns, 1 );
 
     appGuiSetGotValueCallbackForText( lt->ltStartAtText,
 					tedLevelStartAtChanged, (void *)lt );
     /**/
-    appInspectorMakeMenuRow( &row, &(lt->ltJustifyOptionmenu),
+    guiToolMakeLabelAndMenuRow( &row, &(lt->ltJustifyOptionmenu),
 				    &justifyLabel, lt->ltListLevelPaned,
-				    lpr->lprJustify );
+				    lpr->lprJustify,
+				    tedListJustifyChosen, (void *)lt );
 
-    appInspectorMakeMenuRow( &row, &(lt->ltFollowOptionmenu),
+    guiToolMakeLabelAndMenuRow( &row, &(lt->ltFollowOptionmenu),
 				    &followLabel, lt->ltListLevelPaned,
-				    lpr->lprFollowedBy );
+				    lpr->lprFollowedBy,
+				    tedListFollowChosen, (void *)lt );
 
-    appInspectorMakeButtonRow( &row, pageWidget,
+    guiToolMake2BottonRow( &(is->isApplyRow), pageWidget,
 		&(is->isRevertButton), &(is->isApplyButton),
 		isr->isrRevert, isr->isrApplyToSubject,
 		tedFormatListRevertPushed, tedFormatChangeList, lt );
@@ -2069,18 +2098,15 @@ void tedFormatFillListChoosers(		ListTool *			lt )
 
     appFillInspectorMenu( LISTTOOLcountSTYLES, 0,
 			lt->ltNumberStyleItems, lpr->lprStyleOptionTexts,
-			&(lt->ltNumberStyleOptionmenu),
-			tedListNumberStyleChosen, (void *)lt );
+			&(lt->ltNumberStyleOptionmenu) );
 
     appFillInspectorMenu( DOClla_COUNT, DOCllaLEFT,
 			lt->ltJustifyItems, lpr->lprJustifyOptionTexts,
-			&(lt->ltJustifyOptionmenu),
-			tedListJustifyChosen, (void *)lt );
+			&(lt->ltJustifyOptionmenu) );
 
     appFillInspectorMenu( DOCllf_COUNT, DOCllfTAB,
 			lt->ltFollowItems, lpr->lprFollowOptionTexts,
-			&(lt->ltFollowOptionmenu),
-			tedListFollowChosen, (void *)lt );
+			&(lt->ltFollowOptionmenu) );
 
     return;
     }
