@@ -7,8 +7,12 @@
 #   ifndef	TED_PARA_LAYOUT_TOOL_H
 #   define	TED_PARA_LAYOUT_TOOL_H
 
-#   include	"tedBorderTool.h"
-#   include	"tedShadingTool.h"
+#   include	<docPropVal.h>
+#   include	<docBuf.h>
+#   include	<docSelectionGeometry.h>
+#   include	<docSelectionDescription.h>
+#   include	<appFrame.h>
+#   include	<appInspector.h>
 #   include	"tedHeightTool.h"
 
 /************************************************************************/
@@ -38,7 +42,7 @@ typedef struct ParagraphLayoutPageResources
     const char *	pprParaLineDistExactly;
 
     const char *	pprParaAlignment;
-    const char *	pprParaAlignMenuTexts[DOCia_COUNT];
+    const char *	pprParaAlignMenuTexts[DOCtha_COUNT];
     } ParagraphLayoutPageResources;
 
 /************************************************************************/
@@ -53,30 +57,48 @@ typedef struct ParagraphLayoutTool
     AppInspector *				ptInspector;
     const ParagraphLayoutPageResources *	ptPageResources;
 
+    unsigned char				pltCanChange;
+
     ParagraphProperties				ptPropertiesSet;
     ParagraphProperties				ptPropertiesChosen;
 
-    APP_WIDGET					ptListLevelText;
+    APP_WIDGET					pltListLevelRow;
+    APP_WIDGET					pltListLevelText;
+
+    APP_WIDGET					ptFirstIndentRow;
+    APP_WIDGET					ptFirstIndentLabel;
     APP_WIDGET					ptFirstIndentText;
+
+    APP_WIDGET					ptLeftIndentRow;
+    APP_WIDGET					ptLeftIndentLabel;
     APP_WIDGET					ptLeftIndentText;
+
+    APP_WIDGET					ptRightIndentRow;
+    APP_WIDGET					ptRightIndentLabel;
     APP_WIDGET					ptRightIndentText;
 
+    APP_WIDGET					pltPageRow;
     APP_WIDGET					ptOnNewPageToggle;
     APP_WIDGET					ptKeepOnPageToggle;
 
+    APP_WIDGET					pltKeepRow;
     APP_WIDGET					ptWidowControlToggle;
     APP_WIDGET					ptKeepWithNextToggle;
 
-    APP_WIDGET					ptSpaceAboveToggle;
-    APP_WIDGET					ptSpaceAboveText;
+    APP_WIDGET					pltSpaceAboveRow;
+    APP_WIDGET					pltSpaceAboveToggle;
+    APP_WIDGET					pltSpaceAboveText;
 
-    APP_WIDGET					ptSpaceBelowToggle;
-    APP_WIDGET					ptSpaceBelowText;
+    APP_WIDGET					pltSpaceBelowRow;
+    APP_WIDGET					pltSpaceBelowToggle;
+    APP_WIDGET					pltSpaceBelowText;
 
     HeightChooser				ptLineDistChooser;
 
-    AppOptionmenu				ptAlignOptionmenu;
-    APP_WIDGET					ptAlignItems[DOCia_COUNT];
+    APP_WIDGET					pltAlignmentRow;
+    APP_WIDGET					pltAlignmentLabel;
+    AppOptionmenu				pltAlignOptionmenu;
+    APP_WIDGET					pltAlignItems[DOCtha_COUNT];
     } ParagraphLayoutTool;
 
 /************************************************************************/
@@ -108,9 +130,14 @@ extern void tedRefreshParaLayoutTool(
 				InspectorSubject *		is,
 				const DocumentSelection *	ds,
 				const SelectionGeometry *	sg,
-				const SelectionDescription *	sd );
+				const SelectionDescription *	sd,
+				const unsigned char *		cmdEnabled );
 
 extern void tedFormatCleanParaLayoutTool(
 				ParagraphLayoutTool *		plt );
 
+extern void tedFinishParaLayoutPage(
+				ParagraphLayoutTool *			plt,
+				const ParagraphLayoutPageResources *	plpr );
+
 #   endif	/*  TED_PARA_LAYOUT_TOOL_H */
