@@ -7,6 +7,13 @@
 #   ifndef	TED_ROW_TOOL_H
 #   define	TED_ROW_TOOL_H
 
+#   include	"tedBorderTool.h"
+#   include	"tedShadingTool.h"
+#   include	"tedHeightTool.h"
+#   include	"tedRowMarginsTool.h"
+#   include	<docSelectionDescription.h>
+#   include	<docSelectionGeometry.h>
+
 /************************************************************************/
 /*									*/
 /*  Resources for the 'Row' page.					*/
@@ -19,11 +26,11 @@ typedef struct RowPageResources
     char *			rprHeightAtLeast;
     char *			rprHeightExactly;
 
+    char *			rprBorders;
     char *			rprTopBorder;
     char *			rprBottomBorder;
 
-    char *			rprCellMargin;
-    char *			rprLeftIndent;
+    RowMarginsToolResources	rprMarginsResources;
 
     char *			rprKeepOnPage;
     char *			rprIsTableHeader;
@@ -47,27 +54,34 @@ typedef struct RowTool
     AppInspector *		rtInspector;
     const RowPageResources *	rtPageResources;
 
-    RowProperties		rtPropertiesSet;
-    RowProperties		rtPropertiesChosen;
+    RowProperties		rtRowPropertiesSet;
+    RowProperties		rtRowPropertiesChosen;
+    CellProperties		rtCellPropertiesSet;
+    CellProperties		rtCellPropertiesChosen;
 
     TableRectangle		rtTableRectangle;
 
-    int				rtPageRight;
-    int				rtPageLeftMargin;
+    unsigned char		rtCanChange;
+
+    APP_WIDGET			rtRowRow;
+    APP_WIDGET			rtRowLabel;
+    APP_WIDGET			rtRowText;
 
-    APP_WIDGET			rtNumberText;
     HeightChooser		rtHeightChooser;
-    APP_WIDGET			rtCellMarginText;
-    APP_WIDGET			rtLeftIndentText;
+    RowMarginsTool		rtMarginsTool;
 
+    APP_WIDGET			rtBordersFrame;
+    APP_WIDGET			rtBordersPaned;
     BorderTool			rtTopBorderTool;
     BorderTool			rtBottomBorderTool;
 
     ShadingTool			rtShadingTool;
 
+    APP_WIDGET			rtKeepHeaderRow;
     APP_WIDGET			rtKeepOnPageToggle;
     APP_WIDGET			rtIsTableHeaderToggle;
 
+    APP_WIDGET			rtKeepfollowRow;
     APP_WIDGET			rtKeepfollowToggle;
     APP_WIDGET			rtKeepfollowLabel;
     } RowTool;
@@ -103,7 +117,9 @@ extern void tedRefreshRowTool(	RowTool *			rt,
 				InspectorSubject *		is,
 				const DocumentSelection *	ds,
 				const SelectionGeometry *	sg,
-				const SelectionDescription *	sd );
+				const SelectionDescription *	sd,
+				BufferDocument *		bd,
+				const unsigned char *		cmdEnabled );
 
 extern void tedInitRowTool(	RowTool *	rt );
 extern void tedCleanRowTool(	RowTool *	rt );
