@@ -6,14 +6,13 @@
 
 #   include	"tedConfig.h"
 
-#   include	<stdlib.h>
 #   include	<stdio.h>
 #   include	<stddef.h>
 
-#   include	"tedApp.h"
-#   include	"tedFormatTool.h"
-
+#   include	"tedShadingTool.h"
 #   include	<appDebugon.h>
+#   include	<guiToolUtil.h>
+#   include	<guiTextUtil.h>
 
 #   define	SHOW_PATTERN	0
 
@@ -29,7 +28,7 @@ static void tedShadingToolShowLevel(	ShadingTool *		st,
     if  ( ! st->stLevelText )
 	{ return;	}
 
-    appEnableText( st->stLevelText, is->isPattern == DOCspSOLID );
+    guiEnableText( st->stLevelText, is->isPattern == DOCspSOLID );
 
     if  ( is->isPattern == DOCspSOLID )
 	{
@@ -40,13 +39,28 @@ static void tedShadingToolShowLevel(	ShadingTool *		st,
     return;
     }
 
+/************************************************************************/
+
+void tedEnableShadingTool(		ShadingTool *		st,
+					int			enabled )
+    {
+    ExpandedItemShading *	eis= &(st->stShadingChosen);
+
+    if  ( st->stFrame )
+	{ guiEnableWidget( st->stFrame, enabled );		}
+    else{ guiEnableWidget( st->stRow, enabled );		}
+
+    appEnableColorChooser( &(st->stBackColorChooser), enabled );
+    appShowColorChooser( &(st->stBackColorChooser), eis->eisBackColorExplicit );
+    }
+
 /************************************************************************/
 /*									*/
 /*  Set the current shading in a shading tool.				*/
 /*									*/
 /************************************************************************/
 
-void tedSetShadingTool(			ShadingTool *			st,
+static void tedSetShadingTool(		ShadingTool *			st,
 					const DocumentProperties *	dp,
 					const ItemShading *		is )
     {
@@ -56,20 +70,23 @@ void tedSetShadingTool(			ShadingTool *			st,
     tedShadingToolShowLevel( st, is );
 
     /**/
-    docExpandItemShading( eis, is, dp->dpColors, dp->dpColorCount );
+    docExpandItemShading( eis, is, dp->dpColorPalette );
 
     /**/
     appColorChooserSuggestPalette( &(st->stBackColorChooser),
-				avoidZero, dp->dpColors, dp->dpColorCount );
+					    avoidZero, dp->dpColorPalette );
     appColorChooserSetColor( &(st->stBackColorChooser),
 				    eis->eisBackColorExplicit,
 				    &(eis->eisBackColor) );
+    appGuiSetToggleState( st->stOnOffToggle, eis->eisBackColorExplicit );
+    appShowColorChooser( &(st->stBackColorChooser),
+				    eis->eisBackColorExplicit );
 
     /**/
     if  ( st->stForeColorChooser.ccFilled )
 	{
 	appColorChooserSuggestPalette( &(st->stForeColorChooser),
-				avoidZero, dp->dpColors, dp->dpColorCount );
+					    avoidZero, dp->dpColorPalette );
 
 	appColorChooserSetColor( &(st->stForeColorChooser),
 				eis->eisForeColorExplicit,
@@ -87,17 +104,15 @@ void tedSetShadingTool(			ShadingTool *			st,
     return;
     }
 
-
 void tedSetShadingToolByNumber(		ShadingTool *			st,
 					const BufferDocument *		bd,
 					int				num )
     {
     const DocumentProperties *		dp= &(bd->bdProperties);
-    const NumberedPropertiesList *	isl= &(bd->bdItemShadingList);
 
     ItemShading			is;
 
-    docGetItemShadingByNumber( &is, isl, num );
+    docGetItemShadingByNumber( &is, bd, num );
 
     tedSetShadingTool( st, dp, &is );
 
@@ -119,14 +134,13 @@ static void tedDrawShadedBox(	AppDrawingData *		add,
     {
     if  ( pattern != DOCspSOLID )
 	{
-	tedDrawShadedRectangle( add, st->stPatternPixmaps, pattern,
-			    drI->drX0, drI->drY0, drI->drX1, drI->drY1 );
+	tedDrawShadedRectangle( add, st->stPatternPixmaps, pattern, drI );
 	}
 
-    appDrawDrawLine( add, drI->drX0, drI->drY0, drI->drX1, drI->drY0 );
-    appDrawDrawLine( add, drI->drX1, drI->drY0, drI->drX1, drI->drY1 );
-    appDrawDrawLine( add, drI->drX1, drI->drY1, drI->drX0, drI->drY1 );
-    appDrawDrawLine( add, drI->drX0, drI->drY1, drI->drX0, drI->drY0 );
+    drawLine( add, drI->drX0, drI->drY0, drI->drX1, drI->drY0 );
+    drawLine( add, drI->drX1, drI->drY0, drI->drX1, drI->drY1 );
+    drawLine( add, drI->drX1, drI->drY1, drI->drX0, drI->drY1 );
+    drawLine( add, drI->drX0, drI->drY1, drI->drX0, drI->drY0 );
 
     return;
     }
@@ -141,16 +155,16 @@ static APP_EVENT_HANDLER_H( tedShadingRedrawInplace, w, voidst, exposeEvent )
 
     DocumentRectangle	drI;
 
-    appDrawnPulldownDrawArrow( &wide, &high, w, add );
+    appDrawnPulldownDrawArrow( &wide, &high, w, &(xx) );
 
     drI.drX0= 3; drI.drX1= wide- 3;
     drI.drY0= 3; drI.drY1= high- 3;
 
-    appDrawSetForegroundWhite( add );
-    appDrawFillRectangle( add, drI.drX0, drI.drY0,
+    drawSetForegroundColorWhite( add );
+    drawFillRectangle( add, drI.drX0, drI.drY0,
 			    drI.drX1- drI.drX0+ 1, drI.drY1- drI.drY0+ 1 );
 
-    appDrawSetForegroundBlack( add );
+    drawSetForegroundColorBlack( add );
 
     tedDrawShadedBox( add, st, st->stShadingChosen.eisPattern, &drI );
 
@@ -181,22 +195,22 @@ static APP_EVENT_HANDLER_H( tedShadingRedrawPulldown, w, voidst, exposeEvent )
 	st->stPulldownDrawingDataSet= 1;
 	}
 
-    appDrawGetSizeOfWidget( &pulldownWide, &pulldownHigh, w );
-    appDrawGetSizeOfWidget( &inplaceWide, &inplaceHigh,
+    guiDrawGetSizeOfWidget( &pulldownWide, &pulldownHigh, w );
+    guiDrawGetSizeOfWidget( &inplaceWide, &inplaceHigh,
 				    st->stPatternPulldown.adpInplaceDrawing );
 
-    appCollectExposures( &drClip, add, ox, oy, exposeEvent );
+    guiCollectExposures( &drClip, add, ox, oy, exposeEvent );
 
     appDrawSetForegroundWhite( add );
 
-    appDrawFillRectangle( add, drClip.drX0, drClip.drY0,
+    drawFillRectangle( add, drClip.drX0, drClip.drY0,
 					    drClip.drX1- drClip.drX0+ 1,
 					    drClip.drY1- drClip.drY0+ 1 );
 
-    appDrawSetForegroundBlack( add );
-    appDrawDrawRectangle( add, 0, 0, pulldownWide- 1, pulldownHigh- 1 );
+    drawSetForegroundBlack( add );
+    drawRectangle( add, 0, 0, pulldownWide- 1, pulldownHigh- 1 );
 
-    for ( i= DOCspSOLID+ 1; i < DOCsp_COUNT; i++ )
+    for ( i= DOCspSOLID+ 1; i < PSshd_COUNT; i++ )
 	{
 	DocumentRectangle	drI;
 	DocumentRectangle	drX;
@@ -249,8 +263,8 @@ static APP_EVENT_HANDLER_H( tedShadingClickedPulldown, w, voidst, mouseEvent )
 				&(st->stPatternPulldown), w, mouseEvent ) )
 	{ return;	}
 
-    if  ( pattern < 0 || pattern >= DOCsp_COUNT )
-	{ LLDEB(pattern,DOCsp_COUNT); return;	}
+    if  ( pattern < 0 || pattern >= PSshd_COUNT )
+	{ LLDEB(pattern,PSshd_COUNT); return;	}
 
     if  ( eis->eisPattern != pattern )
 	{
@@ -262,7 +276,7 @@ static APP_EVENT_HANDLER_H( tedShadingClickedPulldown, w, voidst, mouseEvent )
 
 	eis->eisPattern= pattern;
 
-	appExposeDrawingData( &(st->stPatternInplaceDrawingData) );
+	guiExposeDrawingWidget( &(st->stPatternInplaceDrawingData) );
 
 	if  ( st->stCallback )
 	    {
@@ -274,6 +288,30 @@ static APP_EVENT_HANDLER_H( tedShadingClickedPulldown, w, voidst, mouseEvent )
     }
 # endif
 
+/************************************************************************/
+
+static APP_TOGGLE_CALLBACK_H( tedShadeToggled, w, voidst, voidtbcs )
+    {
+    ShadingTool *		st= (ShadingTool *)voidst;
+    ExpandedItemShading *	eis= &(st->stShadingChosen);
+
+    int				set;
+
+    set= appGuiGetToggleStateFromCallback( w, voidtbcs );
+
+    eis->eisBackColorExplicit= set != 0;
+    appShowColorChooser( &(st->stBackColorChooser), set );
+
+    PROPmaskADD( &(st->stShadingChanged), ISpropBACK_COLOR );
+
+    if  ( set )
+	{
+	appColorChooserSetColor( &(st->stBackColorChooser),
+					    eis->eisBackColorExplicit,
+					    &(eis->eisBackColor) );
+	}
+    }
+
 /************************************************************************/
 /*									*/
 /*  A background/foreground has been selected in one of the color	*/
@@ -398,17 +436,20 @@ void tedInitShadingTool(		ShadingTool *		st )
 
     st->stFrame= (APP_WIDGET)0;
     st->stPaned= (APP_WIDGET)0;
+    st->stRow= (APP_WIDGET)0;
 
     st->stPatternLabel= (APP_WIDGET)0;
     st->stLevelLabel= (APP_WIDGET)0;
     st->stBackLabel= (APP_WIDGET)0;
     st->stForeLabel= (APP_WIDGET)0;
 
+    st->stOnOffToggle= (APP_WIDGET)0;
+
     st->stShowPattern= 0;
     appInitDrawnPulldown( &(st->stPatternPulldown) );
 
-    for ( i= 0; i < DOCsp_COUNT; i++ )
-	{ st->stPatternPixmaps[i]= (APP_BITMAP_IMAGE)0;	}
+    for ( i= 0; i < PSshd_COUNT; i++ )
+	{ st->stPatternPixmaps[i]= (DrawingSurface)0;	}
 
     st->stLevelText= (APP_WIDGET)0;
 
@@ -428,14 +469,12 @@ void tedInitShadingTool(		ShadingTool *		st )
 
 void tedCleanShadingTool(		ShadingTool *		st )
     {
-    AppDrawingData *	add= &(st->stPatternPulldown.adpInplaceDrawingData);
-
     int			i;
 
-    for ( i= 0; i < DOCsp_COUNT; i++ )
+    for ( i= 0; i < PSshd_COUNT; i++ )
 	{
 	if  ( st->stPatternPixmaps[i] )
-	    { appDrawFreePixmap( add, st->stPatternPixmaps[i] );	}
+	    { drawFreeDrawingSurface( st->stPatternPixmaps[i] );	}
 	}
 
     appCleanDrawnPulldown( &(st->stPatternPulldown) );
@@ -457,7 +496,8 @@ void tedFormatMakeShadingTool(	ShadingTool *			st,
 				TedShadingToolCallback		callback,
 				void *				target )
     {
-    APP_WIDGET	row;
+    const int	shadingHasAutomaticColor= 0;
+    APP_WIDGET	parent= pageWidget;
 
     /*
     const int	heightResizable= 0;
@@ -482,14 +522,19 @@ void tedFormatMakeShadingTool(	ShadingTool *			st,
     st->stBackWhich= backWhich;
     st->stForeWhich= foreWhich;
 
+    docInitExpandedItemShading( &(st->stShadingChosen) );
+
     /****/
-    title= (const char *)0;
-    appMakeColumnFrameInColumn( &(st->stFrame),
+    if  ( title )
+	{
+	appMakeColumnFrameInColumn( &(st->stFrame),
 					&(st->stPaned), pageWidget, title );
+	parent= st->stPaned;
+	}
 
     /****/
 #   if SHOW_PATTERN
-    row= appMakeRowInColumn( st->stPaned, 2, heightResizable );
+    row= appMakeRowInColumn( parent, 2, heightResizable );
 
     appMakeLabelInRow( &(st->stPatternLabel), row,
 				labelColumn, labelColspan, str->strPattern );
@@ -506,8 +551,8 @@ void tedFormatMakeShadingTool(	ShadingTool *			st,
 
     /****/
 #   if 0
-    appMakeLabelAndTextRow( &row, &(st->stLevelLabel), &(st->stLevelText),
-				st->stPaned, str->strLevel, textColumns, 1 );
+    guiToolMakeLabelAndTextRow( &row, &(st->stLevelLabel), &(st->stLevelText),
+				parent, str->strLevel, textColumns, 1 );
 #   else
     st->stLevelLabel= (APP_WIDGET)0;
     st->stLevelText= (APP_WIDGET)0;
@@ -520,17 +565,26 @@ void tedFormatMakeShadingTool(	ShadingTool *			st,
 	}
 
     /****/
-    appMakeLabelAndColorChooserRow( &row, &(st->stBackLabel),
+#   if 0
+    appMakeLabelAndColorChooserRow( &(st->stRow), &(st->stBackLabel),
 			    &(st->stBackColorChooser),
-			    st->stPaned, str->strBackColor,
+			    parent, str->strBackColor,
 			    &(str->strBackColorChooserResources),
 			    tedShadeColorChosen, backWhich, (void *)st );
+#   else
+    appMakeToggleAndColorChooserRow( &(st->stRow), &(st->stOnOffToggle),
+			    &(st->stBackColorChooser), shadingHasAutomaticColor,
+			    parent, str->strBackColor,
+			    &(str->strBackColorChooserResources),
+			    tedShadeToggled, tedShadeColorChosen,
+			    backWhich, (void *)st );
+#   endif
 
     /****/
 #   if 0
-    appMakeLabelAndColorChooserRow( &row, &(st->stForeLabel),
+    appMakeLabelAndColorChooserRow( &(st->stRow2), &(st->stForeLabel),
 			    &(st->stForeColorChooser),
-			    st->stPaned, str->strForeColor,
+			    parent, str->strForeColor,
 			    &(str->strForeColorChooserResources),
 			    tedShadeColorChosen, foreWhich, (void *)st );
 #   endif
@@ -538,22 +592,32 @@ void tedFormatMakeShadingTool(	ShadingTool *			st,
     return;
     }
 
-void tedFinishShadingTool(	ShadingTool *		st )
+void tedFinishShadingTool(	ShadingTool *			st,
+				const PostScriptFontList *	psfl )
     {
     if  ( st->stShowPattern )
 	{
 	if  ( appFinishDrawnPulldownInplace( &(st->stPatternPulldown) ) )
 	    { LDEB(1); return;	}
 
-	appGuiSetDrawnPulldownStrips( &(st->stPatternPulldown), DOCsp_COUNT );
+	appGuiSetDrawnPulldownStrips( &(st->stPatternPulldown), PSshd_COUNT );
 	}
 
     /**/
-    appFinishColorChooser( &(st->stBackColorChooser), st->stBackLabel );
+    if  ( st->stBackLabel )
+	{
+	appFinishColorChooser( &(st->stBackColorChooser),
+						    psfl, st->stBackLabel );
+	}
+    else{
+	appFinishColorChooser( &(st->stBackColorChooser),
+						    psfl, st->stOnOffToggle );
+	}
 
     if  ( st->stForeColorChooser.ccFilled )
 	{
-	appFinishColorChooser( &(st->stForeColorChooser), st->stForeLabel );
+	appFinishColorChooser( &(st->stForeColorChooser),
+						    psfl, st->stForeLabel );
 	}
 
     return;
@@ -571,7 +635,8 @@ void tedFinishShadingTool(	ShadingTool *		st )
 /*									*/
 /************************************************************************/
 
-int tedShadingToolGetShading(	ExpandedItemShading *	eisSet,
+static int tedShadingToolGetShading(
+				ExpandedItemShading *	eisSet,
 				PropertyMask *		pSetMask,
 				const ShadingTool *	st )
     {
@@ -630,7 +695,7 @@ int tedShadingToolGetShadingNumber(	int *			pNum,
     if  ( tedShadingToolGetShading( &eis, isSetMask, st ) )
 	{ LDEB(1); return -1;	}
 
-    docGetItemShadingByNumber( &is, &(bd->bdItemShadingList), *pNum );
+    docGetItemShadingByNumber( &is, bd, *pNum );
 
     if  ( ! utilPropMaskIsEmpty( isSetMask ) )
 	{
@@ -639,11 +704,11 @@ int tedShadingToolGetShadingNumber(	int *			pNum,
 	utilPropMaskClear( &isDoneMask );
 
 	if  ( docIndirectItemShading( &isDoneMask, &is, isSetMask, &eis,
-				    &(dp->dpColors), &(dp->dpColorCount) ) )
+							dp->dpColorPalette ) )
 	    { LDEB(1); return -1;	}
 	}
 
-    num= docItemShadingNumber( &(bd->bdItemShadingList), &is );
+    num= docItemShadingNumber( bd, &is );
     if  ( num < 0 )
 	{ LDEB(num); return -1;	}
 
@@ -651,3 +716,25 @@ int tedShadingToolGetShadingNumber(	int *			pNum,
     return 0;
     }
 
+/************************************************************************/
+/*									*/
+/*  Retrieve the shading for a table rectangle from a shading tool.	*/
+/*									*/
+/************************************************************************/
+
+int tedFormatToolGetCellShading(	CellProperties *	cp,
+					BufferDocument *	bd,
+					ShadingTool *		st )
+    {
+    PropertyMask		isSetMask;
+
+    utilPropMaskClear( &isSetMask );
+
+    /*  1  */
+    if  ( tedShadingToolGetShadingNumber( &(cp->cpShadingNumber), &isSetMask,
+								    st, bd  ) )
+	{ LDEB(1); return -1;	}
+
+    return 0;
+    }
+
