@@ -7,8 +7,10 @@
 #   ifndef	TED_SPELL_TOOL_H
 #   define	TED_SPELL_TOOL_H
 
-#   include	"tedApp.h"
 #   include	<appSpellTool.h>
+#   include	<appFrame.h>
+#   include	<docBuf.h>
+#   include	<docSelectionDescription.h>
 
 /************************************************************************/
 /*									*/
@@ -23,7 +25,8 @@ extern void tedRefreshSpellTool(SpellTool *			ast,
 				const DocumentSelection *	ds,
 				const SelectionDescription *	sd,
 				const BufferDocument *		bd,
-				int				documentId );
+				int				documentId,
+				const unsigned char *		cmdEnabled );
 
 extern void tedFillSpellTool(	SpellTool *			ast,
 				const SpellToolResources *	astr,
