@@ -7,8 +7,10 @@
 #   ifndef	TED_SYMBOL_PICKER_H
 #   define	TED_SYMBOL_PICKER_H
 
-#   include	"tedApp.h"
 #   include	<appSymbolPicker.h>
+#   include	<docSelect.h>
+#   include	<docSelectionDescription.h>
+#   include	<docBuf.h>
 
 /************************************************************************/
 /*									*/
@@ -24,7 +26,8 @@ extern void tedRefreshSymbolPicker(
 				const DocumentSelection *	ds,
 				const SelectionDescription *	sd,
 				const BufferDocument *		bd,
-				int				documentId );
+				int				documentId,
+				const unsigned char *		cmdEnabled );
 
 extern void tedSymbolPickerInsert(	void *			voidea,
 					const char *		bytes,
