@@ -10,7 +10,7 @@
 #   include	<stdio.h>
 #   include	<stdlib.h>
 
-#   include	<appFrame.h>
+#   include	"appFrame.h"
 
 #   include	<appDebugon.h>
 
@@ -439,7 +439,8 @@ APP_EVENT_HANDLER_H( appDocCopyPasteHandler, w, voided, event )
 	    EditDocument *	ed= (EditDocument *)voided;
 
 	    appDebug( "SELECTION \"%s\": %s\n",
-			    ed->edTitle, APP_X11EventNames[event->type] );
+			    utilMemoryBufferGetString( &(ed->edTitle) ),
+			    APP_X11EventNames[event->type] );
 	    *pRefused= True;
 	    }
 	    break;
