@@ -13,11 +13,11 @@
 #   include	<stdlib.h>
 #   include	<string.h>
 #   include	<stdio.h>
-#   include	<locale.h>
 
 #   include	<appSystem.h>
 
-#   include	<appFrame.h>
+#   include	"appFrame.h"
+#   include	"appQuestion.h"
 #   include	"appFileChooser.h"
 
 #   include	<appDebugon.h>
@@ -49,8 +49,7 @@ static void appChooserDestroyed(APP_WIDGET	fileChooser,
     {
     AppChooserInformation *	aci= (AppChooserInformation *)voidaci;
 
-    if  ( aci->aciFilename )
-	{ free( aci->aciFilename );	}
+    utilCleanMemoryBuffer( &(aci->aciFilename) );
 
     free( aci );
     }
@@ -61,7 +60,7 @@ static void appInitAci(		AppChooserInformation *	aci )
 
     aci->aciApplication= (EditApplication *)0;
     aci->aciDocument= (EditDocument *)0;
-    aci->aciFilename= (char *)0;
+    utilInitMemoryBuffer( &(aci->aciFilename) );
     aci->aciThrough= (void *)0;
     aci->aciOpenDocument= (APP_OPEN_DOCUMENT)0;
     aci->aciExtensions= (AppFileExtension *)0;
@@ -74,18 +73,24 @@ static void appInitAci(		AppChooserInformation *	aci )
     }
 
 #   if HAS_DIRECTORY
-static void appChooserSetDirectory(	char *			filename,
+static void appChooserSetDirectory(	const MemoryBuffer *	filename,
 					GtkFileChooser *	gfs )
     {
-    char *	slash= strrchr( filename, '/' );
+    MemoryBuffer	dir;
 
-    if  ( slash )
+    utilInitMemoryBuffer( &dir );
+
+    if  ( appDirectoryOfFileName( &dir, filename ) )
+	{ LDEB(1); return;	}
+
+    if  ( ! utilMemoryBufferIsEmpty( &dir ) )
 	{
-	*slash= '\0';
-	gtk_file_chooser_set_current_folder( gfs, filename );
-	*slash= '/';
+	gtk_file_chooser_set_current_folder( gfs,
+					utilMemoryBufferGetString( &dir ) );
 	}
 
+    utilCleanMemoryBuffer( &dir );
+
     return;
     }
 #   endif /* HAS_DIRECTORY */
@@ -109,33 +114,42 @@ static void appFileChooserSetFilter( AppChooserInformation *	aci,
 /*									*/
 /************************************************************************/
 
-static void appChooserSetFileExtension(	char *			filename,
+static void appChooserSetFileExtension(	const MemoryBuffer *	filename,
 					const char *		newExtension,
 					GtkFileChooser *	gfs,
 					int			selectFile )
     {
-    const char *	oldExtension;
+    MemoryBuffer	oldExtension;
+    MemoryBuffer	newFileName;
 
-    oldExtension= appFileExtensionOfName( filename );
+    utilInitMemoryBuffer( &oldExtension );
+    utilInitMemoryBuffer( &newFileName );
 
-    if  ( oldExtension && strcmp( newExtension, oldExtension ) )
+    if  ( appFileGetFileExtension( &oldExtension, filename ) )
+	{ goto ready;	}
+
+    if  ( ! utilMemoryBufferEqualsString( &oldExtension, newExtension ) )
 	{
-	int	l;
-	char *	s;
+	const char *	s;
 
-	l= strlen( filename )+ strlen( newExtension )+ 2;
-	s= (char *)malloc( l );
-	strcpy( s, filename );
-	strcpy( s+ ( oldExtension- filename ), newExtension );
+	if  ( utilCopyMemoryBuffer( &newFileName, filename ) )
+	    { LDEB(1); goto ready;	}
+	if  ( appFileSetExtension( &newFileName, newExtension ) )
+	    { LDEB(1); goto ready;	}
+
+	s= utilMemoryBufferGetString( &newFileName );
 
 	if  ( selectFile )
 	    { gtk_file_chooser_set_filename( gfs, s );	}
 
 	gtk_file_chooser_set_current_name( gfs, s );
-
-	free( s );
 	}
 
+  ready:
+
+    utilCleanMemoryBuffer( &oldExtension );
+    utilCleanMemoryBuffer( &newFileName );
+
     return;
     }
 
@@ -284,7 +298,7 @@ static int appRunFileChooser(	EditApplication *		ea,
 	    break;
 	}
 #   else
-    aci->aciFilename= (char *)0;
+    utilEmptyMemoryBuffer( &(aci->aciFilename) );
 
     appGuiShowDialog( ea, &(aci->aciDialog), relative );
 
@@ -303,27 +317,26 @@ static int appRunFileChooser(	EditApplication *		ea,
 /************************************************************************/
 
 static void appFileChooserOpenFile(	AppChooserInformation *	aci,
-					const char *		filename,
+					const MemoryBuffer *	filename,
 					APP_OPEN_DOCUMENT	openDocument,
 					void *			through )
     {
     int			ret;
     const char *	extension= (const char *)0;
 
-    ret= appChooserSaveFilename( &(aci->aciFilename),
-					    aci, filename, extension );
+    ret= appChooserSaveFilename( aci, filename, extension );
 
     if  ( ! ret )
 	{
-	ret= appFileChooserTestNameForOpen( aci, aci->aciFilename );
+	ret= appFileChooserTestNameForOpen( aci );
 	if  ( ret )
-	    { SDEB(aci->aciFilename);	}
+	    { LDEB(1);	}
 	}
 
     if  ( ! ret && (*openDocument)( aci->aciApplication,
 					through, aci->aciRelativeTo,
-					aci->aciOption, aci->aciFilename ) )
-	{ SDEB(aci->aciFilename);	}
+					aci->aciOption, &(aci->aciFilename) ) )
+	{ LDEB(1);	}
 
     return;
     }
@@ -338,14 +351,21 @@ static void appFileChooserOpenFiles(	AppChooserInformation *	aci,
     GSList *	filenames;
     GSList *	fn;
 
+    MemoryBuffer	filename;
+
+    utilInitMemoryBuffer( &filename );
+
     fn= filenames= gtk_file_chooser_get_filenames( gfs );
     if  ( filenames )
 	{
 	while( fn )
 	    {
-	    gchar *		filename= (gchar *)(fn->data);
+	    gchar *		fnm= (gchar *)(fn->data);
 
-	    appFileChooserOpenFile( aci, filename, openDocument, through );
+	    if  ( utilMemoryBufferSetString( &filename, fnm ) )
+		{ LDEB(1); goto ready;	}
+
+	    appFileChooserOpenFile( aci, &filename, openDocument, through );
 
 	    g_free( fn->data );
 	    fn= fn->next;
@@ -354,6 +374,10 @@ static void appFileChooserOpenFiles(	AppChooserInformation *	aci,
 	g_slist_free( filenames );
 	}
 
+  ready:
+
+    utilCleanMemoryBuffer( &filename );
+
     return;
     }
 
@@ -405,6 +429,7 @@ void appRunOpenChooser( APP_WIDGET			option,
 			int				extensionCount,
 			AppFileExtension *		extensions,
 			const char *			defaultFilter,
+			const MemoryBuffer *		dir,
 			APP_OPEN_DOCUMENT		openDocument,
 			EditApplication *		ea,
 			void *				through )
@@ -472,6 +497,12 @@ void appRunOpenChooser( APP_WIDGET			option,
 
 #   endif /*  MAKE_SELECTION  */
 
+    if  ( dir && ! utilMemoryBufferIsEmpty( dir ) )
+	{
+	gtk_file_chooser_set_current_folder( gfs,
+					utilMemoryBufferGetString( dir ) );
+	}
+
     aci->aciApplication= ea;
     aci->aciOption= option;
     aci->aciRelativeTo= relative;
@@ -498,27 +529,13 @@ void appRunOpenChooser( APP_WIDGET			option,
     return;
     }
 
-static int appChooserOpenDocument(	EditApplication *	ea,
-					void *			through,
-					APP_WIDGET		relative,
-					APP_WIDGET		option,
-					const char *		filename )
-    {
-    const int	read_only= 0;
-
-    if  ( ! appOpenDocument( ea, relative, option, read_only, filename ) )
-	{ return -1;	}
-
-    return 0;
-    }
-
 APP_MENU_CALLBACK_H( appAppFileOpen, option, voidea, e )
     {
     EditApplication *	ea= (EditApplication *)voidea;
 
     appRunOpenChooser( GTK_WIDGET( option ), ea->eaToplevel.atTopWidget,
 			ea->eaFileExtensionCount, ea->eaFileExtensions,
-			ea->eaDefaultFileFilter,
+			ea->eaDefaultFileFilter, (MemoryBuffer *)0,
 			appChooserOpenDocument, ea, (void *)ea );
     }
 
@@ -529,82 +546,109 @@ APP_MENU_CALLBACK_H( appDocFileOpen, option, voided, e )
 
     appRunOpenChooser( GTK_WIDGET( option ), ed->edToplevel.atTopWidget,
 			ea->eaFileExtensionCount, ea->eaFileExtensions,
-			ea->eaDefaultFileFilter,
+			ea->eaDefaultFileFilter, (MemoryBuffer *)0,
 			appChooserOpenDocument, ea, (void *)ea );
     }
 
+static int appChooserGetFileName(	MemoryBuffer *		fileName,
+					GtkFileChooser *	gfs )
+    {
+    const gchar *	filename;
+
+#   if MAKE_CHOOSER
+    filename= gtk_file_chooser_get_filename( gfs );
+#   endif
+
+#   if MAKE_SELECTION
+    filename= gtk_file_selection_get_filename( gfs );
+#   endif
+
+    if  ( utilMemoryBufferSetString( fileName, filename ) )
+	{ LDEB(1); return -1;	}
+
+    return 0;
+    }
+
 static int appSaveChooserSave(	AppChooserInformation *	aci,
 				APP_WIDGET		relative,
 				unsigned int		useFlags,
 				GtkFileChooser *	gfs,
 				EditDocument *		ed )
     {
+    int			rval= 0;
     EditApplication *	ea= ed->edApplication;
 
-    const gchar *	filename;
     int			format= -1;
     const char *	extension= (const char *)0;
     int			ret;
     int			resp;
+    int			suggestStdout= 0;
 
-#   if MAKE_CHOOSER
+    MemoryBuffer	filename;
 
-    filename= gtk_file_chooser_get_filename( gfs );
+    utilInitMemoryBuffer( &filename );
 
-#   endif
+    if  ( appChooserGetFileName( &filename, gfs ) )
+	{ LDEB(1); rval= -1; goto ready;	}
 
-#   if MAKE_SELECTION
+    format= appDocumentGetSaveFormat( &suggestStdout, ea, &filename,
+				ed->edPrivateData, useFlags, ed->edFormat );
 
-    filename= gtk_file_selection_get_filename( gfs );
+    if  ( format >= 0 && format < ea->eaFileExtensionCount )
+	{ extension= ea->eaFileExtensions[format].afeExtension; }
 
-#   endif
-
-    if  ( format < 0 )
-	{
-	format= appDocumentGetSaveFormat( ea, filename,
-			ed->edPrivateData, useFlags, ed->edFormat );
-
-	if  ( format >= 0 && format < ea->eaFileExtensionCount )
-	    { extension= ea->eaFileExtensions[format].afeExtension; }
-	}
-
-    ret= appChooserSaveFilename( &(aci->aciFilename), aci,
-							filename, extension );
+    ret= appChooserSaveFilename( aci, &filename, extension );
     if  ( ret )
-	{ SSDEB(filename,extension); return -1;	}
+	{ SDEB(extension); rval= -1; goto ready;	}
 
-    resp= appFileChooserTestNameForWrite( aci, aci->aciFilename );
+    resp= appFileChooserTestNameForWrite( aci );
 
     if  ( resp == ACIrespSAVE )
 	{
 	if  ( (*aci->aciSaveDocument)( ed, aci->aciThrough,
-					    aci->aciRelativeTo, aci->aciOption,
-					    format, aci->aciFilename ) )
-	    { SLDEB(aci->aciFilename,format); return -1;	}
+				    aci->aciRelativeTo, aci->aciOption,
+				    format, &(aci->aciFilename) ) )
+	    { LDEB(format); rval= -1; goto ready;	}
 	}
 
-    return 0;
+  ready:
+
+    utilCleanMemoryBuffer( &filename );
+
+    return rval;
     }
 
-static APP_OITEM_CALLBACK_H( appFileFilterChosen, w, voidaci )
+static void appFileFilterChosen(	int		ext,
+					void *		voidaci )
     {
     AppChooserInformation *	aci= (AppChooserInformation *)voidaci;
     GtkFileChooser *		gfs= GTK_FILE_CHOOSER( aci->aciWidget );
     const AppFileExtension *	afe= aci->aciExtensions;
-    int				ext;
-    char *			filename;
+    char *			fnm;
 
-    filename= gtk_file_chooser_get_filename( gfs );
+    MemoryBuffer		filename;
 
-    ext= appGuiGetOptionmenuItemIndex( &(aci->aciFilterOptionmenu), w );
-    if  ( filename )
+    utilInitMemoryBuffer( &filename );
+
+    fnm= gtk_file_chooser_get_filename( gfs );
+
+    if  ( fnm )
 	{
 	const int	selectFile= 0;
 	const char *	newExtension= afe[ext].afeExtension;
 
+	if  ( utilMemoryBufferSetString( &filename, fnm ) )
+	    { LDEB(1); goto ready;	}
+
 	appFileChooserSetFilter( aci, ext );
-	appChooserSetFileExtension( filename, newExtension, gfs, selectFile );
+	appChooserSetFileExtension( &filename, newExtension, gfs, selectFile );
 	}
+
+  ready:
+
+    utilCleanMemoryBuffer( &filename );
+
+    return;
     }
 
 static void appFillSaveFilter(	AppChooserInformation *	aci,
@@ -631,13 +675,14 @@ static void appFillSaveFilter(	AppChooserInformation *	aci,
 	{
 	APP_WIDGET	filterWidget;
 
-	filterWidget= appAddItemToOptionmenu( aom, afe->afeDescription,
-					appFileFilterChosen, (void *)aci );
+	filterWidget= appAddItemToOptionmenu( aom, afe->afeDescription );
 
 	if  ( appDocumentTestCanSave( ea, afe, ed->edPrivateData,
 							    useFlags, i ) )
 	    {
-	    appHideMenuOption( filterWidget );
+	    const int	visible= 0;
+
+	    guiShowMenuOption( filterWidget, visible );
 	    continue;
 	    }
 
@@ -690,6 +735,8 @@ int appRunSaveChooser(	APP_WIDGET		option,
 
 	aom->aomPulldown= gtk_menu_new();
 	aom->aomInplace= gtk_option_menu_new();
+	aom->aomCallback= appFileFilterChosen;
+	aom->aomTarget= (void *)aci;
 
 	gtk_option_menu_set_menu( GTK_OPTION_MENU( aom->aomInplace ),
 							    aom->aomPulldown );
@@ -699,11 +746,13 @@ int appRunSaveChooser(	APP_WIDGET		option,
 	appFillSaveFilter( aci, useFlags, ed );
 	}
 
-    if  ( ed->edFilename )
+    if  ( ! utilMemoryBufferIsEmpty( &(ed->edFilename) ) )
 	{
-	gtk_file_chooser_set_filename( gfs, ed->edFilename );
-	gtk_file_chooser_set_current_name( gfs, ed->edFilename );
-	appChooserSetDirectory( ed->edFilename, gfs );
+	const char *	fnm= utilMemoryBufferGetString( &(ed->edFilename) );
+
+	gtk_file_chooser_set_filename( gfs, fnm );
+	gtk_file_chooser_set_current_name( gfs, fnm );
+	appChooserSetDirectory( &(ed->edFilename), gfs );
 	}
 
     gtk_file_chooser_set_do_overwrite_confirmation( gfs, TRUE );
@@ -755,30 +804,40 @@ int appRunSaveChooser(	APP_WIDGET		option,
 static int appSaveChooserPrint(	AppChooserInformation *	aci,
 				const char *		extension )
     {
+    int			rval= 0;
     GtkFileChooser *	gfs= GTK_FILE_CHOOSER( aci->aciWidget );
     const int		format= -1;
 
-    const gchar *	filename;
+    const gchar *	fnm;
     int			ret;
     int			resp;
 
-    filename= gtk_file_chooser_get_filename( gfs );
-    ret= appChooserSaveFilename( &(aci->aciFilename), aci,
-						    filename, extension );
-    if  ( ret )
-	{ SSDEB(filename,extension); return -1;	}
+    MemoryBuffer	filename;
 
-    resp= appFileChooserTestNameForWrite( aci, aci->aciFilename );
+    utilInitMemoryBuffer( &filename );
+
+    fnm= gtk_file_chooser_get_filename( gfs );
+    if  ( utilMemoryBufferSetString( &filename, fnm ) )
+	{ LDEB(1); rval= -1; goto ready;	}
+    ret= appChooserSaveFilename( aci, &filename, extension );
+    if  ( ret )
+	{ SSDEB(fnm,extension); rval= -1; goto ready;	}
+
+    resp= appFileChooserTestNameForWrite( aci );
 
     if  ( resp == ACIrespSAVE )
 	{
 	if  ( (*aci->aciSaveDocument)( aci->aciDocument, aci->aciThrough,
-					    aci->aciRelativeTo, aci->aciOption,
-					    format, aci->aciFilename ) )
-	    { SLDEB(aci->aciFilename,format); return -1;	}
+				    aci->aciRelativeTo, aci->aciOption,
+				    format, &(aci->aciFilename) ) )
+	    { SLDEB(fnm,format); rval= -1; goto ready;	}
 	}
 
-    return 0;
+  ready:
+
+    utilCleanMemoryBuffer( &filename );
+
+    return rval;
     }
 
 
@@ -810,11 +869,11 @@ int appRunPrintToFileChooser(	APP_WIDGET		option,
     gtk_file_chooser_set_filter( gfs, fileFilter );
     }
 
-    if  ( ed->edFilename )
+    if  ( ! utilMemoryBufferIsEmpty( &(ed->edFilename) ) )
 	{
 	const int	selectFile= 1;
-	appChooserSetFileExtension( ed->edFilename, psExt, gfs, selectFile );
-	appChooserSetDirectory( ed->edFilename, gfs );
+	appChooserSetFileExtension( &(ed->edFilename), psExt, gfs, selectFile );
+	appChooserSetDirectory( &(ed->edFilename), gfs );
 	}
 
     gtk_file_chooser_set_do_overwrite_confirmation( gfs, TRUE );
@@ -828,10 +887,10 @@ int appRunPrintToFileChooser(	APP_WIDGET		option,
 
     gfs= GTK_FILE_SELECTION( aci->aciWidget );
 
-    if  ( ed->edFilename )
+    if  ( ! utilMemoryBufferIsEmpty( &(ed->edFilename) ) )
 	{
 	const int	selectFile= 1;
-	appChooserSetFileExtension( ed->edFilename, psExt, gfs, selectFile );
+	appChooserSetFileExtension( &(ed->edFilename), psExt, gfs, selectFile );
 	}
 
 #   endif
@@ -888,6 +947,7 @@ int appFileChooserConfirmOverWrite(	const AppChooserInformation *	aci,
 	    LDEB(rcc);
 	    /*FALLTHROUGH*/
 	case AQDrespCANCEL:
+	case AQDrespCLOSED:
 	    return ACIrespCANCEL;
 	}
     }
