@@ -9,12 +9,14 @@
 #   include	<stddef.h>
 #   include	<stdlib.h>
 #   include	<stdio.h>
-#   include	<locale.h>
 
 #   include	<appSystem.h>
 
-#   include	<appFrame.h>
+#   include	"appFrame.h"
 #   include	"appFileChooser.h"
+#   include	"appQuestion.h"
+#   include	"guiWidgetsImpl.h"
+#   include	"guiTextUtil.h"
 
 #   include	<appDebugon.h>
 
@@ -39,8 +41,7 @@ static void appFreeAci(		Widget		fileChooser,
     {
     AppChooserInformation *	aci= (AppChooserInformation *)voidaci;
 
-    if  ( aci->aciFilename )
-	{ free( aci->aciFilename );	}
+    utilCleanMemoryBuffer( &(aci->aciFilename) );
 
     free( aci );
     }
@@ -49,7 +50,7 @@ static void appInitAci(		AppChooserInformation *	aci )
     {
     appInitOptionmenu( &(aci->aciFilterOptionmenu) );
 
-    aci->aciFilename= (char *)0;
+    utilInitMemoryBuffer( &(aci->aciFilename) );
     aci->aciDocument= (EditDocument *)0;
     aci->aciThrough= (void *)0;
     aci->aciOpenDocument= (APP_OPEN_DOCUMENT)0;
@@ -95,11 +96,16 @@ static int appChooserGetFilename(	void *			voidcbs,
     int					ret;
     XmFileSelectionBoxCallbackStruct *	cbs;
 
-    char *				filename= (char *)0;
+    char *				fnm= (char *)0;
+
+    MemoryBuffer			filename;
+
+    utilInitMemoryBuffer( &filename );
 
     cbs= (XmFileSelectionBoxCallbackStruct *)voidcbs;
 
-    if  ( ! XmStringGetLtoR( cbs->value, XmFONTLIST_DEFAULT_TAG, &filename ) )
+    if  ( ! XmStringGetLtoR( cbs->value, XmFONTLIST_DEFAULT_TAG, &fnm )	||
+	  utilMemoryBufferSetString( &filename, fnm )			)
 	{
 	LDEB(1);
 	appGuiBreakDialog( &(aci->aciDialog), ACIrespFAILURE );
@@ -107,8 +113,7 @@ static int appChooserGetFilename(	void *			voidcbs,
 	}
 
     aci->aciRelativeTo= aci->aciDialog.adTopWidget;
-    ret= appChooserSaveFilename( &(aci->aciFilename), aci,
-						    filename, extension );
+    ret= appChooserSaveFilename( aci, &filename, extension );
 
     if  ( ret < 0 )
 	{
@@ -119,8 +124,11 @@ static int appChooserGetFilename(	void *			voidcbs,
 	{ rval= -1; goto ready;		}
 
   ready:
-    if  ( filename )
-	{ XtFree( filename );	}
+
+    if  ( fnm )
+	{ XtFree( fnm );	}
+
+    utilCleanMemoryBuffer( &filename );
 
     return rval;
     }
@@ -132,21 +140,23 @@ static int appChooserGetFilename(	void *			voidcbs,
 /*									*/
 /************************************************************************/
 
-static void appChooserSetText(		Widget  w,
-					char *	s )
+static void appChooserSetText(		Widget  		w,
+					const MemoryBuffer *	mbText )
     {
+    const char *	s= utilMemoryBufferGetString( mbText );
+
     if  ( XmIsText( w ) )
 	{
-	XmTextSetString( w, s );
-	XmTextSetInsertionPosition( w, strlen( s ) );
+	XmTextSetString( w, (char *)s );
+	XmTextSetInsertionPosition( w, mbText->mbSize );
 
 	return;
 	}
 
     if  ( XmIsTextField( w ) )
 	{
-	XmTextFieldSetString( w, s );
-	XmTextFieldSetInsertionPosition( w, strlen( s ) );
+	XmTextFieldSetString( w, (char *)s );
+	XmTextFieldSetInsertionPosition( w, mbText->mbSize );
 
 	return;
 	}
@@ -154,26 +164,39 @@ static void appChooserSetText(		Widget  w,
     SDEB( s );
     }
 
-static void appChooserSetDirectory(	char *			filename,
+static void appChooserSetDirectory(	const MemoryBuffer *	dir,
 					AppChooserInformation *	aci )
     {
-    char *	slash= strrchr( filename, '/' );
+    XmString		directoryString= (XmString)0;
 
-    if  ( slash )
-	{
-	XmString	directoryString;
+    directoryString= XmStringCreateLocalized(
+			    (char *)utilMemoryBufferGetString( dir ) );
 
-	*slash= '\0';
-	directoryString= XmStringCreateLocalized( filename );
-	*slash= '/';
-
-	XtVaSetValues( aci->aciDialog.adDialog,
+    XtVaSetValues( aci->aciDialog.adDialog,
 				XmNdirectory,		directoryString,
 				NULL );
 
-	XmStringFree( directoryString );
+    if  ( directoryString )
+	{ XmStringFree( directoryString );	}
+
+    return;
+    }
+
+static void appChooserSetFileDirectory(	const MemoryBuffer *	filename,
+					AppChooserInformation *	aci )
+    {
+    MemoryBuffer	directory;
+
+    utilInitMemoryBuffer( &directory );
+
+    if  ( ! appDirectoryOfFileName( &directory, filename )	&&
+	  ! utilMemoryBufferIsEmpty( &directory )		)
+	{
+	appChooserSetDirectory( &directory, aci );
 	}
 
+    utilCleanMemoryBuffer( &directory );
+
     return;
     }
 
@@ -183,28 +206,23 @@ static void appChooserSetDirectory(	char *			filename,
 /*									*/
 /************************************************************************/
 
-static void appChooserSetFileExtension(	char *		filename,
-					const char *	extension,
-					Widget	text )
+static void appChooserSetFileExtension(
+				const MemoryBuffer *		filename,
+				const char *			extension,
+				Widget				text )
     {
-    const char *	ext;
+    MemoryBuffer	changed;
 
-    ext= appFileExtensionOfName( filename );
+    utilInitMemoryBuffer( &changed );
 
-    if  ( ext )
-	{
-	int	l;
-	char *	s;
+    if  ( appFileSetExtension( &changed, extension ) )
+	{ LDEB(1); goto ready;	}
 
-	l= strlen( filename )+ strlen( extension )+ 2;
-	s= (char *)malloc( l );
-	strcpy( s, filename );
-	strcpy( s+ ( ext- filename ), extension );
+    appChooserSetText( text, &changed );
 
-	appChooserSetText( text, s );
+  ready:
 
-	free( s );
-	}
+    utilCleanMemoryBuffer( &changed );
 
     return;
     }
@@ -237,18 +255,15 @@ static void appOpenOkPushed(	Widget		fileChooser,
 	{ return;	}
 
     aci->aciRelativeTo= aci->aciDialog.adTopWidget;
-    if  ( appFileChooserTestNameForOpen( aci, aci->aciFilename ) )
-	{
-	free( aci->aciFilename ); aci->aciFilename= (char *)0;
-	return;
-	}
+    if  ( appFileChooserTestNameForOpen( aci ) )
+	{ utilEmptyMemoryBuffer( &(aci->aciFilename) ); return; }
 
     if  ( (*aci->aciOpenDocument)( aci->aciApplication, aci->aciThrough,
 					    aci->aciDialog.adTopWidget, option,
-					    aci->aciFilename ) )
-	{ free( aci->aciFilename ); aci->aciFilename= (char *)0; return; }
+					    &(aci->aciFilename) ) )
+	{ utilEmptyMemoryBuffer( &(aci->aciFilename) ); return; }
 
-    free( aci->aciFilename ); aci->aciFilename= (char *)0;
+    utilEmptyMemoryBuffer( &(aci->aciFilename) );
 
     appGuiBreakDialog( &(aci->aciDialog), ACIrespOPEN );
 
@@ -272,14 +287,22 @@ static void appFileFilterActivated(	Widget		w,
 							XmDIALOG_FILTER_TEXT );
 
     char *		filter= XmTextGetString( text );
-    const char *	extS;
 
+    MemoryBuffer	mbFilter;
+    MemoryBuffer	mbExt;
+
+    utilInitMemoryBuffer( &mbFilter );
+    utilInitMemoryBuffer( &mbExt );
 
     if  ( ! filter )
-	{ return;	}
+	{ goto ready;	}
 
-    extS= appFileExtensionOfName( filter );
-    if  ( extS )
+    if  ( utilMemoryBufferSetString( &mbFilter, filter ) )
+	{ LDEB(1); goto ready;	}
+    if  ( appFileGetFileExtension( &mbExt, &mbFilter ) < 0 )
+	{ LDEB(1); goto ready;	}
+
+    if  ( ! utilMemoryBufferIsEmpty( &mbExt ) )
 	{
 	int				i;
 	const AppFileExtension *	afe= aci->aciExtensions;
@@ -302,7 +325,7 @@ static void appFileFilterActivated(	Widget		w,
 
 	if  ( i >= childCount				||
 	      i >= aci->aciExtensionCount		||
-	      strcmp( extS, afe[i].afeExtension )	)
+	      ! utilMemoryBufferEqualsString( &mbExt, afe[i].afeExtension ) )
 	    {
 	    for ( i= 0; i < aci->aciExtensionCount; afe++, i++ )
 		{
@@ -313,7 +336,8 @@ static void appFileFilterActivated(	Widget		w,
 		if  ( ! XtIsSensitive( children[i] ) )
 		    { continue;	}
 
-		if  ( ! strcmp( extS, afe->afeExtension )	)
+		if  ( utilMemoryBufferEqualsString( &mbExt,
+						    afe->afeExtension )	)
 		    { break;	}
 		}
 
@@ -322,7 +346,13 @@ static void appFileFilterActivated(	Widget		w,
 	    }
 	}
 
-    XtFree( filter );
+  ready:
+
+    utilCleanMemoryBuffer( &mbFilter );
+    utilCleanMemoryBuffer( &mbExt );
+
+    if  ( filter )
+	{ XtFree( filter );	}
 
     return;
     }
@@ -333,62 +363,58 @@ static void appFileFilterActivated(	Widget		w,
 /*									*/
 /************************************************************************/
 
-static void appFileFilterChosen(	Widget		w,
-					XtPointer	voidaci,
-					XtPointer	e )
+static void appFileFilterChosen(	int		formatChosen,
+					void *		voidaci )
     {
     AppChooserInformation *	aci= (AppChooserInformation *)voidaci;
     const AppFileExtension *	afe= aci->aciExtensions;
     Widget			chooser= aci->aciDialog.adDialog;
     Widget			text;
 
-    int				previousExtension= aci->aciFormat;
-    short			extensionChosen= -1;
+    int				previousFormat= aci->aciFormat;
 
     const char *		filter;
     XmString			filterString;
 
-    char *			fileSelected;
+    MemoryBuffer		fileSelected;
+    MemoryBuffer		extension;
+
+    utilInitMemoryBuffer( &fileSelected );
+    utilInitMemoryBuffer( &extension );
 
     text= XmFileSelectionBoxGetChild( chooser, XmDIALOG_TEXT );
-    fileSelected= appGetStringFromTextWidget( text );
+    appBufferFromTextWidget( &fileSelected, text );
 
-    extensionChosen= appGuiGetOptionmenuItemIndex(
-					&(aci->aciFilterOptionmenu), w );
-    if  ( extensionChosen < 0 )
-	{ LDEB(extensionChosen); return;	}
-
-    filter= afe[extensionChosen].afeFilter;
+    filter= afe[formatChosen].afeFilter;
     filterString= XmStringCreateLocalized( (char *)filter );
 
     XtVaSetValues( chooser,
 			XmNpattern,		filterString,
 			NULL );
 
-    if  ( fileSelected )
+    if  ( ! utilMemoryBufferIsEmpty( &fileSelected ) )
 	{
-	const char *	extS;
-
-	extS= appFileExtensionOfName( fileSelected );
-
-	if  ( extS							&&
-	      previousExtension >= 0					&&
-	      afe[previousExtension].afeExtension			&&
-	      afe[extensionChosen].afeExtension				&&
-	      ! strcmp( extS, afe[previousExtension].afeExtension )	)
+	if  ( ! appFileGetFileExtension( &extension, &fileSelected )	&&
+	      ! utilMemoryBufferIsEmpty( &extension )			&&
+	      previousFormat >= 0					&&
+	      afe[previousFormat].afeExtension				&&
+	      afe[formatChosen].afeExtension				&&
+	      utilMemoryBufferEqualsString( &extension,
+				  afe[previousFormat].afeExtension )	)
 	    {
-	    const char *	ext= afe[extensionChosen].afeExtension;
+	    const char *	ext= afe[formatChosen].afeExtension;
 
-	    appChooserSetFileExtension( fileSelected, ext, text );
+	    appChooserSetFileExtension( &fileSelected, ext, text );
 	    }
-	else{ appChooserSetText( text, fileSelected ); }
-
-	appFreeStringFromTextWidget( fileSelected );
+	else{ appChooserSetText( text, &fileSelected ); }
 	}
 
     XmStringFree( filterString );
 
-    aci->aciFormat= extensionChosen;
+    aci->aciFormat= formatChosen;
+
+    utilCleanMemoryBuffer( &fileSelected );
+    utilCleanMemoryBuffer( &extension );
 
     return;
     }
@@ -399,12 +425,14 @@ static void appFileFilterChosen(	Widget		w,
 /*									*/
 /************************************************************************/
 
-static void appChooserMakeOptionmenu(	AppOptionmenu *	aom,
-					Widget		parent )
+static void appChooserMakeOptionmenu(	AppChooserInformation *	aci,
+					Widget			parent )
     {
     Arg				al[20];
     int				ac= 0;
 
+    AppOptionmenu *		aom= &(aci->aciFilterOptionmenu);
+
     appInitOptionmenu( aom );
 
     ac= 0;
@@ -444,6 +472,9 @@ static void appChooserMakeOptionmenu(	AppOptionmenu *	aom,
 
     XtManageChild( aom->aomInplace );
 
+    aom->aomCallback= appFileFilterChosen;
+    aom->aomTarget= (void *)aci;
+
     return;
     }
 
@@ -458,7 +489,7 @@ static void appFileMakeFilter(	AppChooserInformation *	aci )
     XtSetArg( al[ac], XmNresizePolicy,	XmRESIZE_NONE );
     child= XmCreateForm( aci->aciDialog.adDialog, WIDGET_NAME, al, ac );
 
-    appChooserMakeOptionmenu( &(aci->aciFilterOptionmenu), child );
+    appChooserMakeOptionmenu( aci, child );
 
     XtManageChild( child );
 
@@ -485,10 +516,8 @@ static void appFileFillFilter(	EditApplication *	ea,
     afe= extensions;
     for ( i= 0; i < extensionCount; afe++, i++ )
 	{
-	Widget	fresh;
-
-	fresh= appAddItemToOptionmenu( &(aci->aciFilterOptionmenu),
-		    afe->afeDescription, appFileFilterChosen, (void *)aci );
+	appAddItemToOptionmenu( &(aci->aciFilterOptionmenu),
+						    afe->afeDescription );
 
 	if  ( selected < 0 )
 	    {
@@ -666,7 +695,7 @@ static void appRunFileChooser(	EditApplication *		ea,
 				AppChooserInformation *		aci,
 				Widget				relative )
     {
-    aci->aciFilename= (char *)0;
+    utilInitMemoryBuffer( &(aci->aciFilename) );
 
     appGuiShowDialog( ea, &(aci->aciDialog), relative );
 
@@ -696,6 +725,7 @@ void appRunOpenChooser( Widget				option,
 			int				extensionCount,
 			AppFileExtension *		extensions,
 			const char *			defaultFilter,
+			const MemoryBuffer *		dir,
 			APP_OPEN_DOCUMENT		openDocument,
 			EditApplication *		ea,
 			void *				through )
@@ -724,7 +754,7 @@ void appRunOpenChooser( Widget				option,
     aci->aciRelativeTo= relative;
     aci->aciThrough= through;
     aci->aciOpenDocument= openDocument;
-    aci->aciFilename= (char *)0;
+    utilInitMemoryBuffer( &(aci->aciFilename) );
 
     if  ( withFilter )
 	{
@@ -749,6 +779,9 @@ void appRunOpenChooser( Widget				option,
 	    }
 	}
 
+    if  ( dir && ! utilMemoryBufferIsEmpty( dir ) )
+	{ appChooserSetDirectory( dir, aci );	}
+
     appRunFileChooser( ea, aci, relative );
 
     XtDestroyWidget( aci->aciDialog.adTopWidget );
@@ -756,27 +789,13 @@ void appRunOpenChooser( Widget				option,
     return;
     }
 
-static int appChooserOpenDocument(	EditApplication *	ea,
-					void *			through,
-					Widget			relative,
-					Widget			option,
-					const char *		filename )
-    {
-    const int	read_only= 0;
-
-    if  ( ! appOpenDocument( ea, relative, option, read_only, filename ) )
-	{ return -1;	}
-
-    return 0;
-    }
-
 APP_MENU_CALLBACK_H( appAppFileOpen, option, voidea, e )
     {
     EditApplication *	ea= (EditApplication *)voidea;
 
     appRunOpenChooser( option, ea->eaToplevel.atTopWidget,
 			ea->eaFileExtensionCount, ea->eaFileExtensions,
-			ea->eaDefaultFileFilter,
+			ea->eaDefaultFileFilter, (MemoryBuffer *)0,
 			appChooserOpenDocument, ea, (void *)ea );
     }
 
@@ -789,7 +808,7 @@ void appDocFileOpen(	APP_WIDGET	option,
 
     appRunOpenChooser( option, ed->edToplevel.atTopWidget,
 			ea->eaFileExtensionCount, ea->eaFileExtensions,
-			ea->eaDefaultFileFilter,
+			ea->eaDefaultFileFilter, (MemoryBuffer *)0,
 			appChooserOpenDocument, ea, (void *)ea );
     }
 
@@ -803,17 +822,16 @@ static void appFileOkPushed(		AppChooserInformation *	aci,
 	{ return;	}
 
     aci->aciRelativeTo= aci->aciDialog.adTopWidget;
-    response= appFileChooserTestNameForWrite( aci, aci->aciFilename );
+    response= appFileChooserTestNameForWrite( aci );
 
     switch( response )
 	{
 	case ACIrespSAVE:
 	    if  ( (*aci->aciSaveDocument)( aci->aciDocument, aci->aciThrough, 
 			    aci->aciDialog.adTopWidget, aci->aciOption,
-			    aci->aciFormat, aci->aciFilename ) )
+			    aci->aciFormat, &(aci->aciFilename) ) )
 		{
-		SDEB(aci->aciFilename);
-		free( aci->aciFilename ); aci->aciFilename= (char *)0;
+		utilEmptyMemoryBuffer( &(aci->aciFilename) );
 		}
 	    else{
 		appGuiBreakDialog( &(aci->aciDialog), ACIrespSAVE );
@@ -825,12 +843,12 @@ static void appFileOkPushed(		AppChooserInformation *	aci,
 	    return;
 
 	case ACIrespNONE:
-	    free( aci->aciFilename ); aci->aciFilename= (char *)0;
+	    utilEmptyMemoryBuffer( &(aci->aciFilename) );
 	    return;
 
 	default:
 	    LDEB(response);
-	    free( aci->aciFilename ); aci->aciFilename= (char *)0;
+	    utilEmptyMemoryBuffer( &(aci->aciFilename) );
 	    appGuiBreakDialog( &(aci->aciDialog), ACIrespFAILURE );
 	    return;
 	}
@@ -842,8 +860,8 @@ static void appSaveOkPushed(		Widget		fileChooser,
 					XtPointer	voidaci,
 					XtPointer	voidcbs	 )
     {
-    AppChooserInformation *		aci= (AppChooserInformation *)voidaci;
-    const char *			extension= (const char *)0;
+    AppChooserInformation *	aci= (AppChooserInformation *)voidaci;
+    const char *		extension= (const char *)0;
 
     if  ( aci->aciExtensionCount > 0 )
 	{
@@ -862,8 +880,8 @@ static void appPrintOkPushed(		Widget		fileChooser,
 					XtPointer	voidaci,
 					XtPointer	voidcbs	 )
     {
-    AppChooserInformation *		aci= (AppChooserInformation *)voidaci;
-    const char *			extension= "ps";
+    AppChooserInformation *	aci= (AppChooserInformation *)voidaci;
+    const char *		extension= "ps";
 
     appFileOkPushed( aci, voidcbs, extension );
     }
@@ -919,7 +937,7 @@ static int appSaveChooserFilterExtensions( EditApplication *	ea,
 
 	XmStringFree( filterString );
 
-	if  ( ed->edFilename )
+	if  ( ! utilMemoryBufferIsEmpty( &(ed->edFilename) ) )
 	    {
 	    Widget	text;
 
@@ -927,13 +945,13 @@ static int appSaveChooserFilterExtensions( EditApplication *	ea,
 							    XmDIALOG_TEXT );
 
 	    if  ( choice == ed->edFormat )
-		{ appChooserSetText( text, ed->edFilename ); }
+		{ appChooserSetText( text, &(ed->edFilename) ); }
 	    else{
 		const char *	ext= ea->eaFileExtensions[choice].afeExtension;
 
 		if  ( ext )
 		    {
-		    appChooserSetFileExtension( ed->edFilename,
+		    appChooserSetFileExtension( &(ed->edFilename),
 							    ext, text );
 		    }
 		}
@@ -982,8 +1000,8 @@ int appRunSaveChooser(	APP_WIDGET		option,
     aci->aciThrough= through;
     aci->aciSaveDocument= saveDocument;
 
-    if  ( ed->edFilename )
-	{ appChooserSetDirectory( ed->edFilename, aci ); }
+    if  ( ! utilMemoryBufferIsEmpty( &(ed->edFilename) ) )
+	{ appChooserSetFileDirectory( &(ed->edFilename), aci ); }
 
     if  ( ea->eaFileExtensionCount > 0					&&
 	  appSaveChooserFilterExtensions( ea, ed, useFlags, aci )	)
@@ -991,7 +1009,7 @@ int appRunSaveChooser(	APP_WIDGET		option,
 
     appRunFileChooser( ea, aci, relative );
 
-    response= aci->aciDialog.adResponse;;
+    response= aci->aciDialog.adResponse;
 
     XtDestroyWidget( aci->aciDialog.adTopWidget );
 
@@ -1028,15 +1046,15 @@ int appRunPrintToFileChooser(
     aci->aciThrough= through;
     aci->aciSaveDocument= printDocument;
 
-    if  ( ed->edFilename )
+    if  ( ! utilMemoryBufferIsEmpty( &(ed->edFilename) ) )
 	{
 	Widget	text;
 
 	text= XmFileSelectionBoxGetChild(
 				    aci->aciDialog.adDialog, XmDIALOG_TEXT );
 
-	appChooserSetDirectory( ed->edFilename, aci );
-	appChooserSetFileExtension( ed->edFilename, "ps", text );
+	appChooserSetFileDirectory( &(ed->edFilename), aci );
+	appChooserSetFileExtension( &(ed->edFilename), "ps", text );
 	}
 
     appRunFileChooser( ea, aci, relative );
@@ -1067,6 +1085,7 @@ int appFileChooserConfirmOverWrite(	const AppChooserInformation *	aci,
 	    LDEB(rcc);
 	    /*FALLTHROUGH*/
 	case AQDrespCANCEL:
+	case AQDrespCLOSED:
 	    return ACIrespCANCEL;
 	}
     }
