@@ -10,14 +10,13 @@
 #   include	<stdio.h>
 #   include	<stdlib.h>
 
-#   include	<utilEndian.h>
-#   include	<appImage.h>
+#   include	"appImage.h"
 
 #   include	<appDebugon.h>
 
 #   ifdef USE_MOTIF
 
-#   include	<X11/Xlib.h>
+#   include	"drawUtilMotif.h"
 
 static int appGetIndexedColors(	XColor **	pColors,
 				Display *	display,
@@ -142,10 +141,10 @@ static int appGetRGB8Description(	BitmapDescription *	bd,
 
     bd->bdHasAlpha= 0;
 
-    bd->bdColorCount= 0;
-    bd->bdRGB8Palette= (RGB8Color *)malloc( count* sizeof(RGB8Color) );
-    if  ( ! bd->bdRGB8Palette )
-	{ LXDEB(count,bd->bdRGB8Palette); return -1; }
+    bd->bdPalette.cpColorCount= 0;
+    bd->bdPalette.cpColors= (RGB8Color *)malloc( count* sizeof(RGB8Color) );
+    if  ( ! bd->bdPalette.cpColors )
+	{ LXDEB(count,bd->bdPalette.cpColors); return -1; }
 
     bd->bdBytesPerRow= ( bitsPerPixel/ 8 )* bd->bdPixelsWide;
     bd->bdBufferLength= bd->bdPixelsHigh* bd->bdBytesPerRow;
@@ -172,8 +171,6 @@ static int appGetRGBDescription(	BitmapDescription *	bd,
 
     bd->bdHasAlpha= 0;
 
-    bd->bdColorCount= 0;
-
     bd->bdBytesPerRow= ( bd->bdBitsPerPixel/ 8 )* bd->bdPixelsWide;
     bd->bdBufferLength= bd->bdPixelsHigh* bd->bdBytesPerRow;
 
@@ -210,7 +207,7 @@ static int appGetRGB8Palette(	XColor *	xc,
 /*									*/
 /************************************************************************/
 
-int appGetImageMotif(	AppBitmapImage *	abi,
+int appGetImageMotif(	RasterImage *	abi,
 			const APP_IMAGE *	xim,
 			Display *		display )
     {
@@ -238,6 +235,8 @@ int appGetImageMotif(	AppBitmapImage *	abi,
     double		horPixPerMM;
     double		xfac;
 
+    bmInitDescription( &bd );
+
     bitsPerPixel= xim->bits_per_pixel;
     bytesPerLine= xim->bytes_per_line;
     data= xim->data;
@@ -254,8 +253,6 @@ int appGetImageMotif(	AppBitmapImage *	abi,
 
     xfac=  ( 25.4/ ( 20.0* 72.0 ) )* horPixPerMM;
 
-    bmInitDescription( &bd );
-
     if  ( xim->xoffset )
 	{ LDEB( xim->xoffset); return -1;	}
 
@@ -342,7 +339,7 @@ int appGetImageMotif(	AppBitmapImage *	abi,
 		    { xc[*b].pad= 1; }
 		}
 
-	    bd.bdColorCount= appGetRGB8Palette( xc, count, bd.bdRGB8Palette );
+	    bd.bdPalette.cpColorCount= appGetRGB8Palette( xc, count, bd.bdPalette.cpColors );
 
 	    for ( row= 0; row < bd.bdPixelsHigh; row++ )
 		{
@@ -367,9 +364,9 @@ int appGetImageMotif(	AppBitmapImage *	abi,
 		    { xc[*psh].pad= 1; }
 		}
 
-	    bd.bdColorCount= appGetRGB8Palette( xc, count, bd.bdRGB8Palette );
+	    bd.bdPalette.cpColorCount= appGetRGB8Palette( xc, count, bd.bdPalette.cpColors );
 
-	    if  ( bd.bdColorCount < 256 )
+	    if  ( bd.bdPalette.cpColorCount < 256 )
 		{
 		unsigned char *	pch= buffer;
 
@@ -447,12 +444,13 @@ int appGetImageMotif(	AppBitmapImage *	abi,
     if  ( xc )
 	{ free( xc );	}
 
-    abi->abiBuffer= buffer;
-    abi->abiBitmap= bd;
+    abi->riBytes= buffer;
+    abi->riDescription= bd;
+
     return 0;
     }
 
-int appImgPastePixmap(		AppBitmapImage *	abi,
+int appImgPastePixmap(		RasterImage *	abi,
 				APP_WIDGET		w,
 				APP_SELECTION_EVENT *	event )
     {
