@@ -5,50 +5,14 @@
 #   include	<string.h>
 
 #   include	"appFrame.h"
-#   include	<geoString.h>
+#   include	"guiWidgetsGtk.h"
+#   include	"guiWidgetsImpl.h"
+#   include	"guiDrawingWidget.h"
 
 #   include	<appDebugon.h>
 
 #   ifdef USE_GTK
 
-/************************************************************************/
-/*									*/
-/*  Retrieve configurable resource values from the GUI environment.	*/
-/*									*/
-/*  1)  This should be done wih something like the GNU message catalog	*/
-/*	system. For the moment, just install the default values.	*/
-/*									*/
-/************************************************************************/
-
-void appGuiGetResourceValues(	int *				pGotResources,
-				EditApplication *		ea,
-				void *				pValues,
-				AppConfigurableResource *	acrList,
-				int				acrCount )
-    {
-    AppConfigurableResource *	acr;
-    char *			values= (char *)pValues;
-    int				i;
-
-    if  ( *pGotResources )
-	{ LDEB(*pGotResources); return;	}
-
-    if  ( ! *pGotResources )
-	{ appSetResourceDefaults( ea, acrList, acrCount );	}
-
-    acr= acrList;
-    for ( i= 0; i < acrCount; acr++, i++ )
-	{
-	*((const char **)(values+acr->acrStructOffset))= acr->acrDefaultValue;
-	}
-
-    if  ( ea->eaToplevel.atTopWidget )
-	{ appGuiGetResourceValuesGtkX( ea, pValues, acrList, acrCount ); }
-
-    *pGotResources= 1;
-    return;
-    }
-
 /************************************************************************/
 /*									*/
 /*  Destroy all children of a widget.					*/
@@ -79,25 +43,28 @@ int appGuiInitApplication(	EditApplication *	ea,
 
     gtk_set_locale();
 
+    if  ( ea->eaStyleToolInt >= 0 )
+	{ gtk_rc_add_default_file( CONFDIR "/ted.gtkrc-2.0" );	}
+
     gtk_init( &argc, &argv );
 
     gWindow= gtk_window_new( GTK_WINDOW_TOPLEVEL );
     ea->eaToplevel.atTopWidget= gWindow;
 
     /* user can't minimize or maximize */
-    gtk_window_set_policy (GTK_WINDOW (gWindow), FALSE, FALSE, FALSE);
-    gtk_window_set_position (GTK_WINDOW (gWindow), GTK_WIN_POS_CENTER);
+    gtk_window_set_policy( GTK_WINDOW( gWindow), FALSE, FALSE, FALSE);
+    gtk_window_set_position( GTK_WINDOW( gWindow), GTK_WIN_POS_CENTER);
 
     appSetCloseCallback( gWindow, ea, appAppWmClose, (void*)ea );
 
     /* 
      * Facilities for making menu option accelerators.
      */
-    gAccelGroup = gtk_accel_group_new();
+    gAccelGroup= gtk_accel_group_new();
     ea->eaToplevel.atAccelGroup= gAccelGroup;
 
 #   if GTK_MAJOR_VERSION < 2
-    gtk_accel_group_attach (gAccelGroup, GTK_OBJECT (gWindow));
+    gtk_accel_group_attach( gAccelGroup, GTK_OBJECT( gWindow));
 #   else
     gtk_window_add_accel_group( GTK_WINDOW( gWindow ), gAccelGroup );
 #   endif
@@ -162,12 +129,9 @@ void appGuiInsertMenubarInColumn(	APP_WIDGET *	pMenubar,
 /*									*/
 /************************************************************************/
 
-void appGetFactors(	EditApplication *	ea,
-			double *		pHorPixPerMM,
-			double *		pVerPixPerMM,
-			double *		pXfac,
-			double *		pYfac )
+void appGetPixelsPerTwip( EditApplication *	ea )
     {
+#   if 0
     double		horPixPerMM;
     double		verPixPerMM;
     double		xfac;
@@ -179,11 +143,10 @@ void appGetFactors(	EditApplication *	ea,
     xfac=  ( 25.4/ ( 20.0* 72.0 ) )* horPixPerMM;
     yfac=  ( 25.4/ ( 20.0* 72.0 ) )* verPixPerMM;
 
-    *pHorPixPerMM= horPixPerMM;
-    *pVerPixPerMM= verPixPerMM;
-
-    *pXfac= ea->eaMagnification* xfac;
-    *pYfac= ea->eaMagnification* yfac;
+    ea->eaPixelsPerTwip= xfac;
+#   else
+    ea->eaPixelsPerTwip= 96.0/ ( 20* 72 );
+#   endif
 
     return;
     }
@@ -196,8 +159,8 @@ void appGetFactors(	EditApplication *	ea,
 /*									*/
 /************************************************************************/
 
-void appGuiEnableWidget(	APP_WIDGET		w,
-				int			on_off )
+void guiEnableWidget(	APP_WIDGET		w,
+			int			on_off )
     {
     gtk_widget_set_sensitive( w, on_off != 0 );
     }
@@ -243,81 +206,22 @@ void appSetShellTitle(	APP_WIDGET		shell,
     }
 
 void appGuiSetShellTitle(	APP_WIDGET		shell,
-				const char *		fullTitle )
+				const MemoryBuffer *	fullTitle )
     {
-    gtk_window_set_title( GTK_WINDOW( shell ), fullTitle );
+    gtk_window_set_title( GTK_WINDOW( shell ),
+				    utilMemoryBufferGetString( fullTitle ) );
 
     return;
     }
 
 void appGuiSetIconTitle(	APP_WIDGET		shell,
-				const char *		fullIconName )
+				const MemoryBuffer *	iconName )
     {
-    gdk_window_set_icon_name( shell->window, fullIconName );
+    gdk_window_set_icon_name( shell->window,
+				    utilMemoryBufferGetString( iconName ) );
     return;
     }
 
-void appGuiLowerShellWidget(	APP_WIDGET	shell )
-    {
-    gdk_window_lower( shell->window );
-
-    return;
-    }
-
-/************************************************************************/
-/*									*/
-/*  Change the label/state of a toggle button.				*/
-/*									*/
-/************************************************************************/
-
-void appGuiSetToggleLabel(	APP_WIDGET		toggle,
-				const char *		text )
-    {
-    if  ( ! appGuiGtkSetChildLabel( toggle, text ) )
-	{ SDEB(text);	}
-    }
-
-void appGuiSetToggleState(	APP_WIDGET		toggle,
-				int			set )
-    {
-    gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( toggle ), set != 0 );
-    }
-
-int appGuiGetToggleState(	APP_WIDGET		toggle )
-    {
-    return gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON( toggle ) ) != 0;
-    }
-
-int appGuiGetToggleStateFromCallbackGtk( GtkWidget *	toggle )
-    {
-    return gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON( toggle ) ) != 0;
-    }
-
-APP_WIDGET appMakeToggleInRow(	APP_WIDGET		row,
-				const char *		text,
-				APP_TOGGLE_CALLBACK_T	callback,
-				void *			through,
-				int			col,
-				int			colspan )
-    {
-    GtkWidget *	toggle= gtk_check_button_new_with_label( (char *)text );
-
-    gtk_table_attach( GTK_TABLE( row ),
-			toggle,
-			col, col+ colspan,
-			0, 1,
-			GTK_FILL | GTK_EXPAND | GTK_SHRINK,
-			GTK_FILL | GTK_EXPAND | GTK_SHRINK,
-			ROW_XPADDING_GTK, ROW_YPADDING_GTK );
-
-    gtk_widget_show( toggle );
-
-    gtk_signal_connect( GTK_OBJECT( toggle ), "toggled",
-					    (GtkSignalFunc)callback, through );
-
-    return toggle;
-    }
-
 void appGuiSetScrollbarValues(		APP_WIDGET	scrollbar,
 					int		value,
 					int		sliderSize )
@@ -415,7 +319,7 @@ void appGuiMakeDrawingAreaInColumn( APP_WIDGET *		pDrawing,
     *pDrawing= drawing;
 
     if  ( redraw )
-	{ appDrawSetRedrawHandler( drawing, redraw, through );	}
+	{ guiDrawSetRedrawHandler( drawing, redraw, through );	}
 
     return;
     }
@@ -431,7 +335,6 @@ void appMakeVerticalTool(	APP_WIDGET *		pShell,
 				EditApplication *	ea,
 				APP_BITMAP_IMAGE	iconPixmap,
 				APP_BITMAP_MASK		iconMask,
-				const char *		widgetName,
 				int			userResizable,
 				APP_WIDGET		option,
 				APP_CLOSE_CALLBACK_T	closeCallback,
@@ -453,7 +356,9 @@ void appMakeVerticalTool(	APP_WIDGET *		pShell,
 
     gtk_widget_show( column );
 
-    *pShell= shell; *pColumn= column; return;
+    *pShell= shell;
+    *pColumn= column;
+    return;
     }
 
 /************************************************************************/
@@ -834,4 +739,42 @@ void appGuiFocusToWidget(	APP_WIDGET		w )
     gtk_widget_grab_focus( w );
     }
 
+void appGuiGtkListTree(		int			indent,
+				APP_WIDGET		w )
+    {
+    GType		type= GTK_WIDGET_TYPE( w );
+    const char *	typeName;
+    const char *	instanceName= gtk_widget_get_name( w );
+
+    typeName= g_type_name( type );
+    appDebug( "%*s%s%s%s (%d..%d x %d..%d)\n", 2* indent, "",
+				typeName,
+				( instanceName?" ":"" ),
+				( instanceName?instanceName:"" ),
+				w->allocation.x,
+				w->allocation.x+ w->allocation.width,
+				w->allocation.y,
+				w->allocation.y+ w->allocation.height );
+
+    if  ( GTK_IS_CONTAINER( w ) )
+	{
+	GList *	glf;
+	GList *	gl;
+
+	gl= glf= gtk_container_children( GTK_CONTAINER( w ) );
+
+	while( gl )
+	    {
+	    appGuiGtkListTree( indent+ 1, (GtkWidget *)gl->data );
+
+	    gl= gl->next;
+	    }
+
+	if  ( glf )
+	    { g_list_free( glf );	}
+	}
+
+    return;
+    }
+
 #   endif
