@@ -1,16 +1,14 @@
 #   include	"appFrameConfig.h"
 
-#   include	<stdlib.h>
 #   include	<stdio.h>
 
-#   include	"appFrame.h"
+#   include	"guiWidgets.h"
 
 #   include	<appDebugon.h>
 
 #   ifdef USE_MOTIF
 
 #   include	<X11/Xatom.h>
-#   include	<Xm/PanedW.h>
 #   include	<Xm/List.h>
 
 /************************************************************************/
@@ -22,7 +20,7 @@
 void appGuiMakeListInColumn(	Widget *		pList,
 				Widget			column,
 				int			visibleItems,
-				APP_LIST_CALLBACK_T	callback,
+				APP_LIST_CALLBACK_T	listCallback,
 				APP_BUTTON_CALLBACK_T	actionCallback,
 				void *			through )
     {
@@ -34,20 +32,30 @@ void appGuiMakeListInColumn(	Widget *		pList,
     ac= 0;
     XtSetArg( al[ac], XmNskipAdjust,		False ); ac++;
     XtSetArg( al[ac], XmNallowResize,		False ); ac++;
-    XtSetArg( al[ac], XmNvisibleItemCount,	visibleItems ); ac++;
-    /* NO!
-    */
-    XtSetArg( al[ac], XmNlistSizePolicy,	XmCONSTANT ); ac++;
+    if  ( visibleItems > 0 )
+	{
+	XtSetArg( al[ac], XmNvisibleItemCount,	visibleItems ); ac++;
+	}
+
     XtSetArg( al[ac], XmNwidth,			25 ); ac++;
 
-    list= XmCreateScrolledList( column, WIDGET_NAME, al, ac );
+    if  ( visibleItems >= 0 )
+	{
+	XtSetArg( al[ac], XmNscrollBarDisplayPolicy,	XmAS_NEEDED ); ac++;
+	XtSetArg( al[ac], XmNlistSizePolicy,		XmCONSTANT ); ac++;
+
+	list= XmCreateScrolledList( column, WIDGET_NAME, al, ac );
+	}
+    else{
+	list= XmCreateList( column, WIDGET_NAME, al, ac );
+	}
 
     XtManageChild( list );
 
-    if  ( callback )
+    if  ( listCallback )
 	{
 	XtAddCallback( list, XmNbrowseSelectionCallback,
-						callback, through );
+						listCallback, through );
 	}
 
     if  ( actionCallback )
@@ -69,8 +77,8 @@ void appGuiEmptyListWidget(	Widget			list )
     return;
     }
 
-void appGuiDeleteValueFromListWidget(	APP_WIDGET	list,
-					int		pos )
+void appGuiDeletePositionFromListWidget(	APP_WIDGET	list,
+						int		pos )
     {
     XmListDeletePos( list, pos+ 1 );
     }
@@ -127,16 +135,12 @@ void appGuiAddValueToListWidget(	Widget		list,
     return;
     }
 
-void appGuiSelectPositionInListWidget(		APP_WIDGET	list,
-						int		position )
+static void appGuiScrollListToPosMotif(		APP_WIDGET	list,
+						int		pp1 )
     {
     int		firstVisible;
     int		nVisible;
 
-    int		pp1= position+ 1;	/*  Silly Motif counts from 1	*/
-
-    XmListSelectPos( list, pp1, False );
-
     /* If the selected item is not visible, scroll the list */
     XtVaGetValues( list,
 		XmNtopItemPosition,	&firstVisible,
@@ -151,6 +155,40 @@ void appGuiSelectPositionInListWidget(		APP_WIDGET	list,
     return;
     }
 
+void appGuiSelectPositionInListWidget(		APP_WIDGET	list,
+						int		position )
+    {
+    int		pp1= position+ 1;	/*  Silly Motif counts from 1	*/
+
+    XmListSelectPos( list, pp1, False );
+
+    /* If the selected item is not visible, scroll the list */
+    appGuiScrollListToPosMotif( list, pp1 );
+
+    return;
+    }
+
+void appGuiSelectValueInListWidget(		APP_WIDGET	list,
+						const char *	value )
+    {
+    XmString	labelString;
+    int *	selected= (int *)0;
+    int		selectedCount= 0;
+
+    labelString= XmStringCreateLocalized( (char *)value );
+
+    XmListSelectItem( list, labelString, False );
+
+    XmStringFree( labelString );
+
+    if  ( XmListGetSelectedPos( list, &selected, &selectedCount ) )
+	{
+	appGuiScrollListToPosMotif( list, selected[0] );
+	}
+
+    return;
+    }
+
 void appGuiRemoveSelectionFromListWidget(	APP_WIDGET	list )
     {
     XmListDeselectAllItems( list );
