@@ -8,7 +8,6 @@
 
 #   include	<stddef.h>
 #   include	<stdio.h>
-#   include	<stdlib.h>
 
 #   include	"appFrame.h"
 #   include	<appDebugon.h>
@@ -240,30 +239,12 @@ void appFreeTextFromMenuOption(	char *		s )
 /*									*/
 /************************************************************************/
 
-void appHideMenuOption(		APP_WIDGET		w )
+void guiShowMenuOption(		APP_WIDGET		w,
+				int			visible )
     {
-    XtUnmanageChild( w );
-    }
-
-/************************************************************************/
-/*									*/
-/*  The implementation and usage are inefficient. We do not care	*/
-/*  as the routine is rarely called.					*/
-/*									*/
-/************************************************************************/
-
-void appHideMenuChild(		APP_WIDGET		menu,
-				int			n )
-    {
-    WidgetList		children;
-    Cardinal		childCount= 0;
-
-    XtVaGetValues( menu,
-			    XmNchildren,		&children,
-			    XmNnumChildren,		&childCount,
-			    NULL );
-
-    XtUnmanageChild( children[n] );
+    if  ( visible )
+	{ XtManageChild( w );	}
+    else{ XtUnmanageChild( w );	}
     }
 
 #   endif
