@@ -6,7 +6,6 @@
 
 #   include	"appFrameConfig.h"
 
-#   include	<stdlib.h>
 #   include	<stdio.h>
 #   include	<stddef.h>
 #   include	<limits.h>
@@ -15,10 +14,15 @@
 
 #   include	"appFrame.h"
 #   include	"appPageLayoutTool.h"
+#   include	"guiWidgetDrawingSurface.h"
+#   include	"guiDrawingWidget.h"
+#   include	"guiDrawPage.h"
+#   include	"guiToolUtil.h"
+#   include	"guiTextUtil.h"
 
 #   include	<appDebugon.h>
 
-#   define	DRH_MM		40
+#   define	DRH_MM		32
 
 /************************************************************************/
 /*									*/
@@ -29,14 +33,13 @@
 static void appPageLayoutRefreshPageLayoutPage(	PageLayoutTool *	plt )
     {
     EditApplication *		ea= plt->pltApplication;
-    AppDrawingData *		add= &(plt->pltDrawingData);
     DocumentGeometry *		dg= &(plt->pltGeometryChosen);
 
     appPaperChooserAdaptToGeometry( &(plt->pltPaperChooser), dg );
 
     appMarginToolShowMargins( &(plt->pltMarginTool), plt->pltUnitType, dg );
 
-    appExposeDrawingData( add );
+    guiExposeDrawingWidget( plt->pltPageDrawing );
 
     if  ( plt->pltHeaderPositionText )
 	{
@@ -50,53 +53,64 @@ static void appPageLayoutRefreshPageLayoutPage(	PageLayoutTool *	plt )
 				dg->dgFooterPositionTwips, ea->eaUnitInt );
 	}
 
+    if  ( plt->pltHeaderFooterFrame )
+	{
+	guiEnableWidget( plt->pltHeaderFooterFrame,
+		    plt->pltCanChangeSelection || plt->pltCanChangeDocument );
+
+	guiEnableText( plt->pltHeaderPositionText,
+		    plt->pltCanChangeSelection || plt->pltCanChangeDocument );
+	guiEnableText( plt->pltFooterPositionText,
+		    plt->pltCanChangeSelection || plt->pltCanChangeDocument );
+	}
+
+    appEnablePaperChooser( &(plt->pltPaperChooser),
+		    plt->pltCanChangeSelection || plt->pltCanChangeDocument );
+    appEnableMarginTool( &(plt->pltMarginTool),
+		    plt->pltCanChangeSelection || plt->pltCanChangeDocument );
+
+    if  ( plt->pltChangeSelectionWidget )
+	{
+	guiEnableWidget( plt->pltChangeSelectionWidget,
+						plt->pltCanChangeSelection );
+	}
+    if  ( plt->pltRevertSelectionWidget )
+	{
+	guiEnableWidget( plt->pltRevertSelectionWidget,
+						plt->pltCanChangeSelection );
+	}
+    if  ( plt->pltChangeDocumentWidget )
+	{
+	guiEnableWidget( plt->pltChangeDocumentWidget,
+						plt->pltCanChangeDocument );
+	}
+    if  ( plt->pltRevertDocumentWidget )
+	{
+	guiEnableWidget( plt->pltRevertDocumentWidget,
+						plt->pltCanChangeDocument );
+	}
+
     return;
     }
 
 void appPageLayoutPageRefresh(	PageLayoutTool *		plt,
-				int *				pEnabled,
 				InspectorSubject *		is,
 				const DocumentGeometry *	dgSect,
 				const DocumentGeometry *	dgDoc )
     {
-    int				changed= 0;
-    const DocumentGeometry *	dgSelection;
+    if  ( plt->pltManageSelection && dgSect )
+	{
+	plt->pltGeometryChosen= *dgSect;
+	plt->pltGeometrySetSelection= *dgSect;
+	plt->pltGeometrySetDocument= *dgDoc;
+	}
+    else{
+	plt->pltGeometryChosen= *dgDoc;
+	plt->pltGeometrySetSelection= *dgDoc;
+	plt->pltGeometrySetDocument= *dgDoc;
+	}
 
-    PropertyMask		setMask;
-    PropertyMask		doneMask;
-
-    utilPropMaskClear( &setMask );
-    utilPropMaskFill( &setMask, DGprop_COUNT );
-
-    if  ( plt->pltManageSelection )
-	{ dgSelection= dgSect;	}
-    else{ dgSelection= dgDoc;	}
-
-    /**/
-    utilPropMaskClear( &doneMask );
-    utilUpdDocumentGeometry( &(plt->pltGeometryChosen), dgSelection,
-						    &doneMask, &setMask );
-    if  ( ! utilPropMaskIsEmpty( &doneMask ) )
-	{ changed= 1;	}
-
-    /**/
-    utilPropMaskClear( &doneMask );
-    utilUpdDocumentGeometry( &(plt->pltGeometrySetSelection), dgSelection,
-						    &doneMask, &setMask );
-    if  ( ! utilPropMaskIsEmpty( &doneMask ) )
-	{ changed= 1;	}
-
-    /**/
-    utilPropMaskClear( &doneMask );
-    utilUpdDocumentGeometry( &(plt->pltGeometrySetDocument), dgDoc,
-						    &doneMask, &setMask );
-    if  ( ! utilPropMaskIsEmpty( &doneMask ) )
-	{ changed= 1;	}
-
-    if  ( changed )
-	{ appPageLayoutRefreshPageLayoutPage( plt );	}
-
-    *pEnabled= 1;
+    appPageLayoutRefreshPageLayoutPage( plt );
 
     return;
     }
@@ -173,7 +187,7 @@ static void appPageLayoutChangeLayout(	PageLayoutTool *	plt,
 	PROPmaskUNSET( &setMask, DGpropFOOTER_POSITION );
 	}
 
-    (*ea->eaSetPageLayout)( ed, &dgNew, &setMask, wholeDocument );
+    (*ea->eaSetPageLayout)( ed, &setMask, &dgNew, wholeDocument );
 
     return;
     }
@@ -247,7 +261,6 @@ static APP_TXTYPING_CALLBACK_H( appSectFooterPositionChanged, w, voidplt )
 static APP_TXACTIVATE_CALLBACK_H( appPaperMarginChanged, w, voidplt )
     {
     PageLayoutTool *		plt= (PageLayoutTool *)voidplt;
-    AppDrawingData *		add= &(plt->pltDrawingData);
     DocumentGeometry *		dgSect= &(plt->pltGeometryChosen);
 
     PropertyMask		dgUpdMask;
@@ -277,7 +290,7 @@ static APP_TXACTIVATE_CALLBACK_H( appPaperMarginChanged, w, voidplt )
     dgSect->dgRightMarginTwips= dg.dgRightMarginTwips;
     dgSect->dgBottomMarginTwips= dg.dgBottomMarginTwips;
 
-    appExposeDrawingData( add );
+    guiExposeDrawingWidget( plt->pltPageDrawing );
 
     return;
     }
@@ -319,10 +332,11 @@ static APP_BUTTON_CALLBACK_H( appPageLayoutRevertDocumentPushed, w, voidplt )
 static APP_EVENT_HANDLER_H( appPageLayoutToolDrawPage, w, voidplt, exposeEvent )
     {
     PageLayoutTool *		plt= (PageLayoutTool *)voidplt;
-    AppDrawingData *		add= &(plt->pltDrawingData);
+    DrawingSurface		ds= plt->pltDrawingSurface;
     DocumentGeometry *		dg= &(plt->pltGeometryChosen);
 
-    appDrawPageDiagram( w, add, DRH_MM, dg );
+    appDrawPageDiagram( w, ds, &(plt->pltBackgroundColor),
+						    plt->pltPixelsPerTwip, dg );
     }
 
 /************************************************************************/
@@ -337,12 +351,11 @@ static void appPageLayoutToolPaperRectChanged(
 				const DocumentGeometry *	dg )
     {
     PageLayoutTool *		plt= (PageLayoutTool *)voidplt;
-    AppDrawingData *		add= &(plt->pltDrawingData);
 
     plt->pltGeometryChosen.dgPageWideTwips= dg->dgPageWideTwips;
     plt->pltGeometryChosen.dgPageHighTwips= dg->dgPageHighTwips;
 
-    appExposeDrawingData( add );
+    guiExposeDrawingWidget( plt->pltPageDrawing );
 
     return;
     }
@@ -376,11 +389,11 @@ static void appPageLayoutMakeHeaderFooterWidgets(
     /**********************/
 #   define	TW	7
 
-    appMakeLabelAndTextRow( &row, &label, &(plt->pltHeaderPositionText),
+    guiToolMakeLabelAndTextRow( &row, &label, &(plt->pltHeaderPositionText),
 				    plt->pltHeaderFooterLeftColumn,
 				    plpr->plprHeaderPositionText, TW, 1 );
 
-    appMakeLabelAndTextRow( &row, &label, &(plt->pltFooterPositionText),
+    guiToolMakeLabelAndTextRow( &row, &label, &(plt->pltFooterPositionText),
 				    plt->pltHeaderFooterRightColumn,
 				    plpr->plprFooterPositionText, TW, 1 );
 
@@ -426,9 +439,18 @@ void appPageLayoutPageFillPage(	PageLayoutTool *		plt,
     plt->pltManageHeadersFooters= doHdFt;
     plt->pltManageSelection= doSelection;
 
+    plt->pltCanChangeSelection= 1;
+    plt->pltCanChangeDocument= 1;
+
+    plt->pltHeaderFooterFrame= (APP_WIDGET)0;
+    plt->pltHeaderFooterLeftColumn= (APP_WIDGET)0;
+    plt->pltHeaderFooterRightColumn= (APP_WIDGET)0;
+    plt->pltHeaderPositionText= (APP_WIDGET)0;
+    plt->pltFooterPositionText= (APP_WIDGET)0;
+
     /**/
 
-    appInitDrawingData( &(plt->pltDrawingData) );
+    plt->pltDrawingSurface= (DrawingSurface)0;
 
     utilInitDocumentGeometry( &(plt->pltGeometrySetDocument) );
     utilInitDocumentGeometry( &(plt->pltGeometrySetSelection) );
@@ -441,9 +463,13 @@ void appPageLayoutPageFillPage(	PageLayoutTool *		plt,
     appInitPaperChooser( &(plt->pltPaperChooser) );
 
     /**************/
+    plt->pltPageHighMm= DRH_MM;
+    plt->pltPixelsPerTwip= ( plt->pltPageHighMm* ea->eaPixelsPerTwip )/
+								A3_MM_HIGH;
 
-    plt->pltPageDrawing= appMakePageDrawing( pageWidget, ea, DRH_MM,
-				    appPageLayoutToolDrawPage, (void *)plt );
+    plt->pltPageDrawing= appMakePageDrawing( pageWidget,
+				ea->eaPixelsPerTwip, plt->pltPageHighMm,
+				appPageLayoutToolDrawPage, (void *)plt );
 
     appMakePaperChooserWidgets( pageWidget, plpr->plprPage,
 					    plt->pltUnitType,
@@ -472,7 +498,7 @@ void appPageLayoutPageFillPage(	PageLayoutTool *		plt,
 
     if  ( plt->pltManageSelection )
 	{
-	appInspectorMakeButtonRow( &row, pageWidget,
+	guiToolMake2BottonRow( &row, pageWidget,
 				    &(plt->pltRevertSelectionWidget),
 				    &(plt->pltChangeSelectionWidget),
 				    plpr->plprRevertSelectionText,
@@ -482,7 +508,7 @@ void appPageLayoutPageFillPage(	PageLayoutTool *		plt,
 				    (void *)plt );
 	}
 
-    appInspectorMakeButtonRow( &row, pageWidget,
+    guiToolMake2BottonRow( &(is->isApplyRow), pageWidget,
 				&(is->isRevertButton), &(is->isApplyButton),
 				isr->isrRevert, isr->isrApplyToSubject,
 				appPageLayoutRevertDocumentPushed,
@@ -490,6 +516,7 @@ void appPageLayoutPageFillPage(	PageLayoutTool *		plt,
 				(void *)plt );
 
     plt->pltChangeDocumentWidget= is->isApplyButton;
+    plt->pltRevertDocumentWidget= is->isRevertButton;
 
     return;
     }
@@ -512,15 +539,13 @@ void appPageLayoutPageFillChoosers(	PageLayoutTool *		plt,
 void appPageLayoutPageFinishPage(	PageLayoutTool *		plt,
 					const PageLayoutPageResources *	plpr )
     {
-    AppDrawingData *	add= &(plt->pltDrawingData);
-    const double	magnification= 1.0;
+    appPaperChooserRefreshMenuWidth( &(plt->pltPaperChooser) );
 
-    appPaperChooserRetreshMenuWidth( &(plt->pltPaperChooser) );
+    plt->pltDrawingSurface= guiDrawingSurfaceForNativeWidget(
+		plt->pltPageDrawing,
+		plt->pltApplication->eaPostScriptFontList.psflAvoidFontconfig );
 
-    if  ( appSetDrawingDataForWidget( plt->pltPageDrawing, (AppColors *)0,
-						    magnification, add ) )
-	{ LDEB(1);				}
-    else{ plt->pltDrawingDataAllocated= 1;	}
+    guiGetBackgroundColor( &(plt->pltBackgroundColor), plt->pltPageDrawing );
 
     return;
     }
@@ -534,7 +559,9 @@ void appPageLayoutPageFinishPage(	PageLayoutTool *		plt,
 void appCleanPageLayoutTool(	PageLayoutTool *	plt )
     {
     appCleanPaperChooser( &(plt->pltPaperChooser) );
-    appCleanDrawingData( &(plt->pltDrawingData) );
+
+    if  ( plt->pltDrawingSurface )
+	{ drawFreeDrawingSurface( plt->pltDrawingSurface );	}
 
     return;
     }
