@@ -7,20 +7,15 @@
 #   ifndef	APP_PRINT_JOB_H
 #   define	APP_PRINT_JOB_H
 
-#   include	<stdio.h>
-
-#   include	<appGuiBase.h>
-#   include	<appGuiResource.h>
-
-#   include	"utilPrinter.h"
-#   include	<appDraw.h>
-#   include	<psPrint.h>
+#   include	<drawDrawingSurface.h>
 
 # ifdef __cplusplus
 extern "C"
     {
 # endif
 
+struct PrintGeometry;
+
 /************************************************************************/
 /*									*/
 /*  Printing..								*/
@@ -29,12 +24,12 @@ extern "C"
 
 typedef struct PrintJob
     {
-    void *			pjPrivateData;
-    int				pjFormat;
-    const char *		pjTitle;
-    AppDrawingData *		pjDrawingData;
-    struct EditApplication *	pjApplication;
-    const PrintGeometry *	pjPrintGeometry;
+    void *				pjPrivateData;
+    int					pjFormat;
+    const char *			pjTitle;
+    DrawingSurface			pjDrawingSurface;
+    struct EditApplication *		pjApplication;
+    const struct PrintGeometry *	pjPrintGeometry;
     } PrintJob;
 
 /************************************************************************/
