@@ -6,9 +6,10 @@
 
 #   include	<stddef.h>
 #   include	<stdio.h>
-#   include	<stdlib.h>
 
-#   include	<appFrame.h>
+#   include	"appFrame.h"
+#   include	"appQuestion.h"
+#   include	"appFileChooser.h"
 
 #   include	<appDebugon.h>
 
@@ -27,9 +28,9 @@ void appRunReallyCloseDialog(	APP_WIDGET			option,
     AppFileMessageResources *	afmr= &(ea->eaFileMessageResources);
 
     rcc= appQuestionRunSubjectYesNoCancelDialog( ea,
-				    ed->edToplevel.atTopWidget,
-				    option, ed->edTitle,
-				    afmr->afmrReallyCloseQuestion );
+				ed->edToplevel.atTopWidget, option,
+				utilMemoryBufferGetString( &(ed->edTitle) ),
+				afmr->afmrReallyCloseQuestion );
 
     switch( rcc )
 	{
@@ -37,38 +38,29 @@ void appRunReallyCloseDialog(	APP_WIDGET			option,
 	    if  ( ! ea->eaSaveDocument )
 		{ XDEB(ea->eaSaveDocument); return;	}
 
-	    if  ( ! ed->edFilename )
+	    if  ( utilMemoryBufferIsEmpty( &(ed->edFilename) ) )
 		{
-		int	done= 0;
-
-#		ifdef USE_MOTIF
-		appDocFileSaveAs( option, (void *)ed, (void *)0 );
-		done= 1;
-#		endif
-#		ifdef USE_GTK
-		appDocFileSaveAs( option, (void *)ed );
-		done= 1;
-#		endif
-		if  ( ! done )
-		    { LXDEB(done,ed->edFilename);	}
-		return;
+		appRunSaveChooser( option, ed->edToplevel.atTopWidget,
+					APPFILE_CAN_SAVE, appDocSaveDocument,
+					ed, ed->edPrivateData );
 		}
 	    else{
-		const int	interactive= 1;
-
-		if  ( ! appDocSaveDocumentByName( ed, option, interactive,
-					    ed->edFormat, ed->edFilename ) )
+		if  ( ! appDocSaveDocument( ed, (void *)0,
+					    ed->edToplevel.atTopWidget, option,
+					    ed->edFormat, &(ed->edFilename) ) )
 		    { appDocumentChanged( ed, 0 ); }
 		}
 
 	    if  ( ! ed->edHasBeenChanged )
-		{ appCloseDocument( ea, ed );	}
+		{ appCloseDocument( ed );	}
 	    break;
 
 	case AQDrespNO:
-	    appCloseDocument( ea, ed );
+	    appCloseDocument( ed );
 	    break;
+
 	case AQDrespCANCEL:
+	case AQDrespCLOSED:
 	    break;
 	default:
 	    LDEB(rcc); break;
