@@ -7,13 +7,12 @@
 #   include	"appUtilConfig.h"
 
 #   include	<stdio.h>
-#   include	<stdlib.h>
 #   include	<string.h>
+#   include	<stdlib.h>
 
-#   include	<unistd.h>
-
-#   include	<appCgiIn.h>
-#   include	<utilTree.h>
+#   include	"appCgiIn.h"
+#   include	"utilTree.h"
+#   include	"appTagval.h"
 
 #   include	<appDebugon.h>
 
@@ -28,7 +27,6 @@ extern char **		environ;
 static void * appCgiInGetHeaderList( void )
     {
     char **		e;
-    int			count;
 
     const int		ownKeys= 1;
     void *		rval= (void *)0;
@@ -37,7 +35,7 @@ static void * appCgiInGetHeaderList( void )
     if  ( ! tree )
 	{ XDEB(tree); goto ready;	}
 
-    e= environ; count= 0;
+    e= environ;
     while( *e )
 	{
 	char *		eq;
@@ -227,11 +225,11 @@ static void * appCgiInAnalyseQueryString(	const char *	queryString )
 	if  ( ! val )
 	    { SXDEB(queryString,val); queryString= from; continue;	}
 
-	key= malloc( val- queryString );
+	key= (char *)malloc( val- queryString );
 	if  ( ! key )
 	    { XDEB(key); goto ready;	}
 
-	value= malloc( from- val+ 1 );
+	value= (char *)malloc( from- val+ 1 );
 	if  ( ! value )
 	    { XDEB(value); goto ready;	}
 
@@ -343,11 +341,11 @@ static void * appCgiInAnalyseCookieString( const char *	cookieString )
 	if  ( ! val )
 	    { SXDEB(cookieString,val); cookieString= from; continue;	}
 
-	key= malloc( val- cookieString );
+	key= (char *)malloc( val- cookieString );
 	if  ( ! key )
 	    { XDEB(key); goto ready;	}
 
-	value= malloc( from- val+ 1 );
+	value= (char *)malloc( from- val+ 1 );
 	if  ( ! value )
 	    { XDEB(value); goto ready;	}
 
