@@ -4,13 +4,14 @@
 /*									*/
 /************************************************************************/
 
-#   include	"config.h"
+#   include	"appUtilConfig.h"
 
 #   include	<stdio.h>
 #   include	<stdarg.h>
 #   include	<appDebug.h>
 
 static FILE *	APP_DebugFile;
+const int appDebugZero = 0;
 
 int appDebug(	const char *	format,
 		... )
