@@ -1,14 +1,14 @@
 #   ifndef	APP_UNIT_H
 #   define	APP_UNIT_H
 
-#   include	<time.h>
-
 /************************************************************************/
 /*									*/
 /*  Unit types and conversions between units.				*/
 /*									*/
 /************************************************************************/
 
+struct tm;
+
 #   define	UNITtyCM	1
 #   define	UNITtyINCH	2
 #   define	UNITtyPOINTS	3
@@ -36,6 +36,6 @@ extern int appWordFormatDate(	char *			target,
 				const struct tm *	tm,
 				const char *		wordPicture );
 
-extern void appInvalidateTime(	struct tm *		tm );
+extern void utilInvalidateTime(	struct tm *		tm );
 
 #   endif	/*  APP_UNIT_H  */
