@@ -2,6 +2,6 @@
 # define GEO_GRID_H
 
 #   define	COORDtoGRID(xmag,t) ((int)((xmag)*(t)))
-#   define	GRIFtoCOORD(p,xmag) ((int)((p)/(xmag)))
+#   define	GRIDtoCOORD(p,xmag) ((int)((p)/(xmag)))
 
 # endif /* GEO_GRID_H */
