@@ -5,8 +5,8 @@
 /*									*/
 /************************************************************************/
 
-#   include	<sioGeneral.h>
-#   include	<appCgiIn.h>
+#   include	"sioGeneral.h"
+#   include	"appCgiIn.h"
 
 extern SimpleInputStream * sioInCgiOpen(	CGIRequest *	cgir );
 
