@@ -1,8 +1,7 @@
 #   ifndef	SIO_ENDIAN_H
 #   define	SIO_ENDIAN_H
 
-#   include	<utilEndian.h>
-#   include	<sioGeneral.h>
+#   include	"sioGeneral.h"
 
 extern int	sioEndianGetLeInt16(SimpleInputStream *);
 extern long	sioEndianGetLeInt32(SimpleInputStream *);
