@@ -5,9 +5,7 @@
 /*									*/
 /************************************************************************/
 
-#   include	<sioGeneral.h>
-
-extern int sioInFlateSkipHeader(	SimpleInputStream *	sisFlate );
+#   include	"sioGeneral.h"
 
 extern SimpleInputStream * sioInFlateOpen(SimpleInputStream *	sisFlate );
 
