@@ -8,7 +8,8 @@
 #   define	SIO_GENERAL_H
 
 
-#   include	<stdio.h>		/*  for EOF.			*/
+		/*  for EOF:			*/
+#   include	<stdio.h>
 
 #   define	SIOsizBUF		1024
 
@@ -22,7 +23,7 @@ typedef struct SimpleInputStream
     int			sisN;
     void *		sisPrivate;
 
-    long		sisReadUpto;
+    long		sisBytesRead;
 
     SIOinREADBYTES	sisReadBytes;
     SIOinCLOSE		sisClose;
@@ -43,6 +44,8 @@ typedef struct SimpleOutputStream
     int			sosN;
     void *		sosPrivate;
 
+    long		sosBytesWritten;
+
     SIOoutWRITEBYTES	sosWriteBytes;
     SIOoutCLOSE		sosClose;
     } SimpleOutputStream;
@@ -67,6 +70,8 @@ extern SimpleInputStream * sioInOpen(	void *			specific,
 					SIOinREADBYTES		readBytes,
 					SIOinCLOSE		closeIt );
 
+extern long sioInGetBytesRead(		SimpleInputStream *	sis );
+
 extern int sioInClose(	SimpleInputStream *		sis );
 
 extern char * sioInGetString(	char *			s,
@@ -87,6 +92,8 @@ extern SimpleOutputStream * sioOutOpen(	void *			specific,
 
 extern int sioOutClose(	SimpleOutputStream *		sos );
 
+extern long sioOutGetBytesWritten(	SimpleOutputStream *	sos );
+
 extern int sioOutPutString(	const char *		s,
 				SimpleOutputStream *	sos );
 
