@@ -1,22 +1,20 @@
 #   include	"appUtilConfig.h"
 
-#   include	<sioSmtp.h>
-#   include	<sioMemory.h>
-#   include	<sioBase64.h>
-#   include	<utilMemoryBuffer.h>
+#   include	"sioSmtp.h"
+#   include	"sioMemory.h"
+#   include	"sioBase64.h"
+#   include	"utilMemoryBuffer.h"
 
 #   include	<stdlib.h>
 #   include	<stdarg.h>
 #   include	<stdio.h>
-#   include	<string.h>
 #   include	<time.h>
-#   include	<sys/time.h>
 #   include	<sys/types.h>
 #   include	<sys/socket.h>
 #   include	<pwd.h>
 #   include	<unistd.h>
-#   include	<fcntl.h>
 #   include	<errno.h>
+#   include	<string.h>
 #   include	<sys/utsname.h>
 #   include	<netdb.h>
 
@@ -184,9 +182,11 @@ SimpleOutputStream * sioOutSmtpOpen(	const char *	mailHost,
     const char *		nodename= (const char *)0;
 
     int				haveEsmtp= 1;
-    int				haveAuth= 0;
     int				haveAuthLogin= 0;
+    /*
+    int				haveAuth= 0;
     int				haveAuthPlain= 0;
+    */
 
     SimpleOutputStream *	sos;
 
@@ -303,7 +303,7 @@ SimpleOutputStream * sioOutSmtpOpen(	const char *	mailHost,
 
 	if  ( tail- head == 4 && ! strncmp( head, "AUTH", 4 ) )
 	    {
-	    haveAuth= 1;
+	    /* haveAuth= 1; */
 
 	    while( *tail && isspace( *tail ) )
 		{ tail++;	}
@@ -319,8 +319,10 @@ SimpleOutputStream * sioOutSmtpOpen(	const char *	mailHost,
 
 		if  ( tail- head == 5 && ! strncmp( head, "LOGIN", 5 ) )
 		    { haveAuthLogin= 1;	}
+		/*
 		if  ( tail- head == 5 && ! strncmp( head, "PLAIN", 5 ) )
 		    { haveAuthPlain= 1;	}
+		*/
 
 		while( *tail && isspace( *tail ) )
 		    { tail++;	}
@@ -820,7 +822,7 @@ char *	sioSmtpGuessMailAddress( void )
     if  ( ! nodename )
 	{ XDEB(nodename); return (char *)0;	}
 
-#   ifdef  UTSNAME_DOMAIN
+#   if defined(UTSNAME_DOMAIN) && ! defined(__cplusplus)
     if  ( un.UTSNAME_DOMAIN[0] && strcmp( un.UTSNAME_DOMAIN, "(none)" ) )
 	{ domainname= un.UTSNAME_DOMAIN;	}
 #   endif
