@@ -7,7 +7,7 @@
 #   ifndef	UTIL_MAIL_CONTENT_H
 #   define	UTIL_MAIL_CONTENT_H
 
-#   include	<sioGeneral.h>
+#   include	"sioGeneral.h"
 
 typedef int (*WriteMail)(	SimpleOutputStream *	sos,
 				const char *		mimeBoundary,
