@@ -7,8 +7,6 @@
 #   ifndef	UTIL_PROP_MASK_H
 #   define	UTIL_PROP_MASK_H
 
-#   include	<string.h>
-
 #   define	PROPmaskSIZE		8
 #   define	PROPmaskMAXPROPS	(8*(PROPmaskSIZE))
 
@@ -17,9 +15,6 @@ typedef struct PropertyMask
     unsigned char	pmBits[PROPmaskSIZE];
     } PropertyMask;
 
-#   define	utilPropMaskClear( pm ) \
-			memset( (pm)->pmBits, 0, PROPmaskSIZE )
-
 #   define	PROPmaskADD( pm, v ) \
 			(pm)->pmBits[(v)/8] |= (1<<((v)%8))
 
@@ -29,6 +24,8 @@ typedef struct PropertyMask
 #   define	PROPmaskISSET( pm, v ) \
 			( (pm)->pmBits[(v)/8] & (1<<((v)%8)) ) != 0
 
+extern void utilPropMaskClear(		PropertyMask *		pm );
+
 extern void utilPropMaskFill(		PropertyMask *		pm,
 					int			c );
 
