@@ -1,4 +1,4 @@
-#   include	<bmWmf.h>
+#   include	"bmWmf.h"
 #   include	<sioGeneral.h>
 
 extern int bmMetaReadWmfHeader(		WmfHeader *		wh,
