@@ -1,12 +1,7 @@
 #   include	"bitmapConfig.h"
 
-#   include	<stdio.h>
-#   include	<stdlib.h>
 #   include	<string.h>
 #   include	"bmintern.h"
-#   include	<sioHex.h>
-#   include	<sioEndian.h>
-#   include	<sioStdio.h>
 
 #   include	<appDebugon.h>
 
@@ -317,22 +312,24 @@ int bmMakeMonochrome(		BitmapDescription *	bd,
     int		bitsPerPixel;
     int		bytesPerRow;
 
-    if  ( bd->bdColorCount == 2 )
+    ColorPalette *	cp= &(bd->bdPalette);
+
+    if  ( cp->cpColorCount == 2 )
 	{
 	bitsPerPixel= 1+ hasAlpha;
 	bytesPerRow= ( bd->bdPixelsWide* bitsPerPixel+ 7 )/ 8;
 
-	if  ( bd->bdRGB8Palette[0].rgb8Red	== 0	&&
-	      bd->bdRGB8Palette[0].rgb8Green	== 0	&&
-	      bd->bdRGB8Palette[0].rgb8Blue	== 0	&&
-	      bd->bdRGB8Palette[1].rgb8Red	== 255	&&
-	      bd->bdRGB8Palette[1].rgb8Green	== 255	&&
-	      bd->bdRGB8Palette[1].rgb8Blue	== 255	)
+	if  ( cp->cpColors[0].rgb8Red	== 0	&&
+	      cp->cpColors[0].rgb8Green	== 0	&&
+	      cp->cpColors[0].rgb8Blue	== 0	&&
+	      cp->cpColors[1].rgb8Red	== 255	&&
+	      cp->cpColors[1].rgb8Green	== 255	&&
+	      cp->cpColors[1].rgb8Blue	== 255	)
 	    {
 	    if  ( bmSqueezeBuffer( bd, bitsPerPixel, bytesPerRow, buffer ) )
 		{ LDEB(1); return -1;	}
 
-	    free( bd->bdRGB8Palette ); bd->bdRGB8Palette= (RGB8Color *)0;
+	    utilPaletteSetCount( cp, 0 );
 	    bd->bdBitsPerSample= 1;
 	    bd->bdColorEncoding= BMcoWHITEBLACK;
 	    bd->bdSamplesPerPixel= 1+ hasAlpha;
@@ -342,17 +339,17 @@ int bmMakeMonochrome(		BitmapDescription *	bd,
 	    return 0;
 	    }
 
-	if  ( bd->bdRGB8Palette[0].rgb8Red	== 255	&&
-	      bd->bdRGB8Palette[0].rgb8Green	== 255	&&
-	      bd->bdRGB8Palette[0].rgb8Blue	== 255	&&
-	      bd->bdRGB8Palette[1].rgb8Red	== 0	&&
-	      bd->bdRGB8Palette[1].rgb8Green	== 0	&&
-	      bd->bdRGB8Palette[1].rgb8Blue	== 0	)
+	if  ( cp->cpColors[0].rgb8Red	== 255	&&
+	      cp->cpColors[0].rgb8Green	== 255	&&
+	      cp->cpColors[0].rgb8Blue	== 255	&&
+	      cp->cpColors[1].rgb8Red	== 0	&&
+	      cp->cpColors[1].rgb8Green	== 0	&&
+	      cp->cpColors[1].rgb8Blue	== 0	)
 	    {
 	    if  ( bmSqueezeBuffer( bd, bitsPerPixel, bytesPerRow, buffer ) )
 		{ LDEB(1); return -1;	}
 
-	    free( bd->bdRGB8Palette ); bd->bdRGB8Palette= (RGB8Color *)0;
+	    utilPaletteSetCount( cp, 0 );
 	    bd->bdBitsPerSample= 1;
 	    bd->bdColorEncoding= BMcoBLACKWHITE;
 	    bd->bdSamplesPerPixel= 1+ hasAlpha;
