@@ -7,29 +7,29 @@
 #   ifndef DOC_DOCUMENT_SHAPE_LIST_H
 #   define DOC_DOCUMENT_SHAPE_LIST_H
 
-#   include	"docShape.h"
-#   include	"utilPagedList.h"
+#   include	<utilPagedList.h>
 
 typedef struct DrawingShapeList
     {
     PagedList		dslPagedList;
     } DrawingShapeList;
 
-extern DrawingShape * docGetShapeByNumber(
+extern struct DrawingShape * docGetShapeByNumber(
 					const DrawingShapeList *	dsl,
 					int				n );
 
 extern void docDeleteShapeFromList(	DrawingShapeList *		dsl,
-					DrawingShape *			ds );
+					struct DrawingShape *		ds );
 
 extern void docCleanShapeList(		DrawingShapeList *	dsl );
 extern void docInitShapeList(		DrawingShapeList *	dsl );
 
-extern DrawingShape * docClaimDrawingShape(
+extern struct DrawingShape * docClaimDrawingShape(
 					DrawingShapeList *	dsl );
 
-DrawingShape * docClaimShapeInParent(	DrawingShapeList *	dsl,
-					DrawingShape *		parent,
+extern struct DrawingShape * docClaimShapeInParent(
+					DrawingShapeList *	dsl,
+					struct DrawingShape *	parent,
 					int			n,
 					int			kind );
 
