@@ -1,5 +1,7 @@
 #   include	"indConfig.h"
 
+#   include	<stdlib.h>
+
 #   include	<uniUtf8.h>
 #   include	"indlocal.h"
 #   include	<appDebugon.h>
@@ -19,15 +21,15 @@ int indTNmake( IND *	ind )
 	{
 	int		newm= ( ind->indAllocatedNodes+ TNsBLOCK )/ TNsBLOCK;
 	unsigned	sz= newm* sizeof(TrieNode *);
-	TrieNode **	new;
+	TrieNode **	fresh;
 	TrieNode *	nwpg;
 
 	if  ( ind->indNodePages )
-	    { new= (TrieNode **) realloc( (char *)ind->indNodePages, sz );}
-	else{ new= (TrieNode **) malloc( sz );				}
-	if  ( ! new )
+	    { fresh= (TrieNode **) realloc( (char *)ind->indNodePages, sz );}
+	else{ fresh= (TrieNode **) malloc( sz );				}
+	if  ( ! fresh )
 	    { return -1;	}
-	ind->indNodePages= new;
+	ind->indNodePages= fresh;
 	nwpg= (TrieNode *)malloc( TNsBLOCK* sizeof( TrieNode ) );
 	if  ( ! nwpg )
 	    { return -1;	}
@@ -117,10 +119,10 @@ int indINDstep(	int *				pTrans,
 /*									*/
 /************************************************************************/
 
-int indINDgetUtf8(	int *			paccept,
-			IND *			ind,
-			int			tn,
-			const unsigned char *	key )
+int indINDgetUtf8(	int *		paccept,
+			IND *		ind,
+			int		tn,
+			const char *	key )
     {
     int		m;
 
@@ -198,7 +200,7 @@ int indINDgetUtf16(	int *			paccept,
 /************************************************************************/
 
 int indINDforget(	IND *		ind,
-			unsigned char *	key )
+			const char *	key )
     {
     int		accepted;
     int		tn= indINDgetUtf8( &accepted, ind, ind->ind_start, key );
@@ -287,9 +289,9 @@ static int indAddNodeToNode(		IND *		ind,
 /*									*/
 /************************************************************************/
 
-int indINDputUtf8(	IND *			ind,
-			int			tn,
-			const unsigned char *	key )
+int indINDputUtf8(	IND *		ind,
+			int		tn,
+			const char *	key )
     {
     for (;;)
 	{
