@@ -1,7 +1,10 @@
 #   include	"indConfig.h"
 
-#   include	<ind.h>
+#   include	<stdlib.h>
+
+#   include	"ind.h"
 #   include	<uniUtf8.h>
+#   include	<ucdGeneralCategory.h>
 #   include	<ucd.h>
 #   include	"indlocal.h"
 #   include	<appDebugon.h>
@@ -85,10 +88,10 @@ static int indGetCapModes(	int *			pTshift,
 /*									*/
 /************************************************************************/
 
-int indWRDget(	IND *			ind,
-		int *			pWhatWasShifted,
-		const unsigned char *	word,
-		int			asPrefix )
+int indWRDget(	IND *		ind,
+		int *		pWhatWasShifted,
+		const char *	word,
+		int		asPrefix )
     {
     int				rval= -1;
 
@@ -122,7 +125,7 @@ int indWRDget(	IND *			ind,
 	{
 	int		i;
 
-	shifted= malloc( 4* ulen+ 1 );
+	shifted= (char *)malloc( 4* ulen+ 1 );
 	if  ( ! shifted )
 	    { LXDEB(ulen,shifted); rval= -1; goto ready;	}
 
@@ -135,7 +138,7 @@ int indWRDget(	IND *			ind,
 	    indShiftWord( shifted, ucods, ulen, INDhASIS );
 
 	    if  ( indINDgetUtf8( &accepted, ind, ind->ind_start,
-				(unsigned char *)shifted ) >= 0	&&
+					    shifted ) >= 0	&&
 		  ( accepted || asPrefix )			)
 		{ *pWhatWasShifted= tshift; rval= 0; goto ready;	}
 	    }
@@ -152,7 +155,7 @@ int indWRDget(	IND *			ind,
 	    indShiftWord( shifted, ucods, ulen, INDhASIS );
 
 	    if  ( indINDgetUtf8( &accepted, ind, ind->ind_start,
-			    (unsigned char *)shifted ) >= 0	&&
+					    shifted ) >= 0	&&
 		  ( accepted || asPrefix )			)
 		{ *pWhatWasShifted= hshift; rval= 0; goto ready;	}
 	    }
@@ -166,7 +169,7 @@ int indWRDget(	IND *			ind,
 	    /* already shifted */
 
 	    if  ( indINDgetUtf8( &accepted, ind, ind->ind_start,
-			    (unsigned char *)shifted ) >= 0	&&
+					    shifted ) >= 0	&&
 		  ( accepted || asPrefix )			)
 		{ *pWhatWasShifted= fshift; rval= 0; goto ready;	}
 	    }
@@ -242,7 +245,7 @@ int indShiftWord(	char *				target,
     {
     int			from= 0;
     int			i;
-    unsigned char *	to= (unsigned char *)target;
+    char *		to= target;
 
     switch( how )
 	{
