@@ -7,7 +7,7 @@
 #   ifndef	PS_CONFIG_H
 #   define	PS_CONFIG_H
 
-#   include	<psPostScriptFontList.h>
+#   include	"psPostScriptFontList.h"
 #   include	<sioGeneral.h>
 
 /************************************************************************/
@@ -16,22 +16,28 @@
 /*									*/
 /************************************************************************/
 
-extern int psFontmapForFiles(		SimpleOutputStream *	sosOut,
-					int			fileCount,
-					char **			fileNames );
+extern int psFontmapForFiles(	SimpleOutputStream *	sosOut,
+				int			fileCount,
+				const char * const *	fileNames );
 
 extern int psAfmToGSFontmap(	SimpleOutputStream *	sosFontDir,
-				const char *		afmFileName,
-				SimpleInputStream *	sisAfm );
+				const char *		afmFileName );
 
 extern int psGSLibAfmDirectory(	PostScriptFontList *	psfl,
-				const char *		afmDirectory,
-				const char *		psDirectory );
+				int			ignoreKerning,
+				const MemoryBuffer *	afmDirectory,
+				const MemoryBuffer *	psDirectory );
 
 extern int psAfmForFontFiles(	PostScriptFontList *	psfl,
+				int			ignoreKerning,
 				int			fileCount,
 				char **			fileNames,
-				const char *		afmDirectory,
-				const char *		psDirectory );
+				const MemoryBuffer *	afmDirectory,
+				const MemoryBuffer *	psDirectory );
+
+extern int psFontFileToAfm(	SimpleOutputStream *	sosAfm,
+				int			omitKernPairs,
+				const char *		fontFileName,
+				const MemoryBuffer *	psDirectory );
 
 #   endif
