@@ -8,7 +8,8 @@
 #   define	PS_TTF_H
 
 #   include	<sioGeneral.h>
-#   include	<psFontInfo.h>
+#   include	<utilMemoryBuffer.h>
+#   include	"psFontInfo.h"
 
 /************************************************************************/
 /*									*/
@@ -17,20 +18,16 @@
 /************************************************************************/
 
 extern int psTtfToPt42(		SimpleOutputStream *	sosPf42,
-				const char *		fontFileName,
+				const MemoryBuffer *	fontFileName,
 				SimpleInputStream *	sisTtf );
 
 extern int psTtcToPt42(		SimpleOutputStream *	sosPf42,
-				const char *		fontFileName,
+				const MemoryBuffer *	fontFileName,
 				int			fontFileIndex,
 				SimpleInputStream *	sisTtf );
 
-extern int psTtfToAfm(		SimpleOutputStream *	sosAfm,
-				const char *		fontFileName,
-				SimpleInputStream *	sisTtf );
-
 extern int psTtfToAfi(		AfmFontInfo *		afi,
-				const char *		fontFileName,
+				const MemoryBuffer *	fontFileName,
 				SimpleInputStream *	sisTtf );
 
 #   endif
