@@ -1,9 +1,4 @@
-#   include	<stdio.h>
-#   include	<string.h>
-#   include	<stdlib.h>
-
 #   include	<sioGeneral.h>
-#   include	<sioEndian.h>
 #   include	"psTtfTableEntry.h"
 
 typedef struct TrueTypeNameRecord
