@@ -1,10 +1,6 @@
 #   ifndef		PSTTF_TABLE_ENTRY_H
 #   define		PSTTF_TABLE_ENTRY_H
 
-#   include	<stdio.h>
-#   include	<string.h>
-#   include	<stdlib.h>
-
 #   include	<sioGeneral.h>
 #   include	<utilMemoryBuffer.h>
 
